<?php

namespace Faker\Provider\pl_PL;

class Text extends \Faker\Provider\Text
{
    /**
     * The Project Gutenberg EBook of Sklepy cynamonowe, by Bruno Schulz
     *
     * Copyright laws are changing all over the world. Be sure to check the
     * copyright laws for your country before downloading or redistributing
     * this or any other Project Gutenberg eBook.
     *
     * This header should be the first thing seen when viewing this Project
     * Gutenberg file.  Please do not remove it.  Do not change or edit the
     * header without written permission.
     *
     * Please read the "legal small print," and other information about the
     * eBook and Project Gutenberg at the bottom of this file.  Included is
     * important information about your specific rights and restrictions in
     * how the file may be used.  You can also find out about how to make a
     * donation to Project Gutenberg, and how to get involved.
     *
     *
     * **Welcome To The World of Free Plain Vanilla Electronic Texts**
     *
     * **eBooks Readable By Both Humans and By Computers, Since 1971**
     *
     * *****These eBooks Were Prepared By Thousands of Volunteers!*****
     *
     *
     * Title: Sklepy cynamonowe
     *
     * Author: Bruno Schulz
     *
     * Release Date: May, 2005 [EBook #8119]
     * [Yes, we are more than one year ahead of schedule]
     * [This file was first posted on June 16, 2003]
     *
     * Edition: 10
     *
     * Language: Polish
     *
     * Character set encoding: Codepage 1250
     *
     * *** START OF THE PROJECT GUTENBERG EBOOK SKLEPY CYNAMONOWE ***
     *
     *
     *
     *
     * Produced by Pawel Sobkowiak - Scanned and proofread by
     * Polska Biblioteka Internetowa
     *
     *
     *
     *
     * BRUNO SCHULZ SKLEPY CYNAMONOWE
     *
     *
     * Spis tresci:
     *
     * SIERPIEŃ NAWIEDZENIE PTAKI MANEKINY TRAKTAT O MANEKINACH ALBO WTÓRA
     * KSIĘGA RODZAJU TRAKTAT O MANEKINACH Ciąg dalszy TRAKTAT O MANEKINACH
     * Dokończenie NEMROD PAN PAN KAROL SKLEPY CYNAMONOWE ULICA KROKODYLI
     * KARAKONY WICHURA NOC WIELKIEGO SEZONU
     *
     * @see http://www.gutenberg.org/cache/epub/8119/pg8119.txt
     *
     * @var string
     */
    protected static $baseText = <<<'EOT'
SIERPIEŃ

1 W lipcu ojciec mój wyjeżdżał do wód i zostawiał mnie z matką i
starszym bratem na pastwę białych od żaru i oszołamiających dni letnich.
Wertowaliśmy, odurzeni światłem, w tej wielkiej księdze wakacji, której
wszystkie karty pałały od blasku i miały na dnie słodki do omdlenia
miąższ złotych gruszek. Adela wracała w świetliste poranki, jak Pomona z
ognia dnia rozżagwionego, wysypując z koszyka barwną urodę słońca - 
lśniące, pełne wody pod przejrzystą skórką czereśnie, tajemnicze, czarne
wiśnie, których woń przekraczała to, co ziszczało się w smaku; morele, w
których miąższu złotym był rdzeń długich popołudni; a obok tej czystej
poezji owoców wyładowywała nabrzmiałe siłą i pożywnością płaty mięsa z
klawiaturą żeber cielęcych, wodorosty jarzyn, niby zabite głowonogi i
meduzy - surowy materiał obiadu o smaku jeszcze nie uformowanym i
jałowym, wegetatywne i telluryczne ingrediencje obiadu o zapachu dzikim
i polnym. Przez ciemne mieszkanie na pierwszym piętrze kamienicy w rynku
przechodziło co dzień na wskroś całe wielkie lato: cisza drgających
słojów powietrznych, kwadraty blasku śniące żarliwy swój sen na
podłodze; melodia katarynki, dobyta z najgłębszej złotej żyły dnia; dwa,
trzy takty refrenu, granego gdzieś na fortepianie, wciąż na nowo,
mdlejące w słońcu na białych trotuarach, zagubione w ogniu dnia
głębokiego. Po sprzątaniu Adela zapuszczała cień na pokoje, zasuwając
płócienne story. Wtedy barwy schodziły o oktawę głębiej, pokój napełniał
się cieniem, jakby pogrążony w światło głębi morskiej, jeszcze mętniej
odbity w zielonych zwierciadłach, a cały upał dnia oddychał na storach,
lekko falujących od marzeń południowej godziny. W sobotnie popołudnia
wychodziłem z matką na spacer. Z półmroku sieni wstępowało się od razu w
słoneczną kąpiel dnia. Przechodnie, brodząc w złocie, mieli oczy
zmrużone od żaru, jakby zalepione miodem, a podciągnięta górna warga
odsłaniała im dziąsła i zęby. I wszyscy brodzący w tym dniu złocistym
mieli ów grymas skwaru, jak gdyby słońce nałożyło swym wyznawcom jedną i
tę samą maskę - złotą maskę bractwa słonecznego; i wszyscy, którzy szli
dziś ulicami, spotykali się, mijali, starcy i młodzi, dzieci i kobiety,
pozdrawiali się w przejściu tą maską, namalowaną grubą, złotą farbą na
twarzy, szczerzyli do siebie ten grymas bakchiczny - barbarzyńską maskę
kultu pogańskiego. Rynek był pusty i żółty od żaru, wymieciony z kurzu
gorącymi wiatrami, jak biblijna pustynia. Cierniste akacje, wyrosłe z
pustki żółtego placu, kipiały nad nim jasnym listowiem, bukietami
szlachetnie uczłonkowanych filigranów zielonych, jak drzewa na starych
gobelinach. Zdawało się, że te drzewa afektują wicher, wzburzając
teatralnie swe korony, ażeby w patetycznych przegięciach ukazać
wytwomość wachlarzy listnych o srebrzystym podbrzuszu, jak futra
szlachetnych lisic. Stare domy, polerowane wiatrami wielu dni, zabawiały
się refleksami wielkiej atmosfery, echami, wspomnieniami barw,
rozproszonymi w głębi kolorowej pogody. Zdawało się, że całe generacje
dni letnich (jak cierpliwi sztukatorzy, obijający stare fasady z pleśni
tynku) obtłukiwały kłamliwą glazurę, wydobywając z dnia na dzień
wyraźniej prawdziwe oblicze domów, fizjonomię losu i życia, które
formowało je od wewnątrz. Teraz okna, oślepione blaskiem pustego placu,
spały; balkony wyznawały niebu swą pustkę; otwarte sienie pachniały
chłodem i winem. Kupka obdartusów, ocalała w kącie rynku przed płomienną
miotłą upału, oblegała kawałek muru, doświadczając go wciąż na nowo
rzutami guzików i monet, jak gdyby z horoskopu tych metalowych krążków
odczytać można było prawdziwą tajemnicę muru, porysowanego hieroglifami
rys i pęknięć. Zresztą rynek był pusty. Oczekiwało się, że przed tę sień
sklepioną z beczkami winiarza podjedzie w cieniu chwiejących się akacyj
osiołek Samarytanina, prowadzony za uzdę, a dwóch pachołków zwlecze
troskliwie chorego męża z rozpalonego siodła, ażeby go po chłodnych
schodach wnieść ostrożnie na pachnące szabasem piętro. Tak wędrowaliśmy
z matką przez dwie słoneczne strony rynku, wodząc nasze załamane cienie
po wszystkich domach, jak po klawiszach. Kwadraty bruku mijały powoli
pod naszymi miękkimi i płaskimi krokami - jedne bladoróżowe jak skóra
ludzka, inne złote i sine, wszystkie płaskie, ciepłe, aksamitne na
słońcu, jak jakieś twarze słoneczne, zadeptane stopami aż do niepoznaki,
do błogiej nicości. Aż wreszcie na rogu ulicy Stryjskiej weszliśmy w
cień apteki. Wielka bania z sokiem malinowym w szerokim oknie aptecznym
symbolizowała chłód balsamów, którym każde cierpienie mogło się tam
ukoić. I po paru jeszcze domach ulica nie mogła już utrzymać nadal
decorum miasta, jak chłop, który wracając do wsi rodzimej, rozdziewa się
po drodze z miejskiej swej elegancji, zamieniając się powoli, w miarę
zbliżania do wsi, w obdartusa wiejskiego. Przedmiejskie domki tonęły
wraz z oknami, zapadnięte w bujnym i zagmatwanym kwitnieniu małych
ogródków. Zapomniane przez wielki dzień, pleniły się bujnie i cicho
wszelkie ziela, kwiaty i chwasty, rade z tej pauzy, którą prześnić mogły
za marginesem czasu, na rubieżach nieskończonego dnia. Ogromny
słonecznik, wydźwignięty na potężnej łodydze i chory na elephantiasis,
czekał w żółtej żałobie ostatnich, smutnych dni żywota, uginając się pod
przerostem potwornej korpulencji. Ale naiwne przedmiejskie dzwonki i
perkalikowe, niewybredne kwiatuszki stały bezradne w swych
nakrochmalonych, różowych i białych koszulkach, bez zrozumienia dla
wielkiej tragedii słonecznika.

2 Splątany gąszcz traw, chwastów, zielska i bodiaków buzuje w ogniu
popołudnia. Huczy rojowiskiem much popołudniowa drzemka ogrodu. Złote
ściernisko krzyczy w słońcu, jak ruda szarańcza; w rzęsistym deszczu
ognia wrzeszczą świerszcze; strąki nasion eksplodują cicho, jak koniki
polne. A ku parkanowi kożuch traw podnosi się wypukłym garbem-pagórem,
jak gdyby ogród obrócił się we śnie na drugą stronę i grube jego,
chłopskie bary oddychają ciszą ziemi. Na tych barach ogrodu niechlujna,
babska bujność sierpnia wyolbrzymiała w głuche zapadliska ogromnych
łopuchów, rozpanoszyła się płatami włochatych blach listnych, wybujałymi
ozorami mięsistej zieleni. Tam te wyłupiaste pałuby łopuchów wybałuszyły
się jak babska szeroko rozsiadłe, na wpół pożarte przez własne oszalałe
spódnice. Tam sprzedawał ogród za darmo najtańsze krupy dzikiego bzu,
śmierdzącą mydłem, grubą kaszę babek, dziką okowitę mięty i wszelką
najgorszą tandetę sierpniową. Ale po drugiej stronie parkanu, za tym
matecznikiem lata, w którym rozrosła się głupota zidiociałych chwastów,
było śmietnisko zarosło dziko bodiakiem. Nikt nie wiedział, że tam
właśnie odprawiał sierpień tego lata swoją wielką pogańską orgię. Na tym
śmietnisku, oparte o parkan i zarośnięte dzikim bzem, stało łóżko
skretyniałej dziewczyny Tłui. Tak nazywaliśmy ją wszyscy. Na kupie
śmieci i odpadków, starych garnków, pantofli, rumowiska i gruzu stało
zielono pomalowane łóżko, podparte zamiast brakującej nogi dwiema
starymi cegłami. Powietrze nad tym rumowiskiem, zdziczałe od żaru, cięte
błyskawicami lśniących much końskich, rozwścieczonych słońcem,
trzeszczało jak od nie widzianych grzechotek, podniecając do szału.
Tłuja siedzi przykucnięta wśród żółtej pościeli i szmat. Wielka jej
głowa jeży się wiechciem czarnych włosów. Twarz jej jest kurczliwa jak
miech harmonii. Co chwila grymas płaczu składa tę harmonię w tysiąc
poprzecznych fałd, a zdziwienie rozciąga ją z powrotem, wygładza fałdy,
odsłania szparki drobnych oczu i wilgotne dziąsła z żółtymi zębami pod
ryjowatą, mięsistą wargą. Mijają godziny pełne żaru i nudy, podczas
których Tłuja gaworzy półgłosem, drzemie, zrzędzi z cicha i chrząka.
Muchy obsiadają nieruchomą gęstym rojem. Ale z nagła ta cała kupa
brudnych gałganów, szmat i strzępów zaczyna poruszać się, jakby ożywiona
chrobotem lęgnących się w niej szczurów. Muchy budzą się spłoszone i
podnoszą wielkim, huczącym rojem, pełnym wściekłego bzykania, błysków i
migotań. I podczas gdy gałgany zsypują się na ziemię i rozbiegają po
śmietnisku jak spłoszone szczury, wygrzebuje się z nich, odwija zwolna
jądro, wyłuszcza się rdzeń śmietniska: na wpół naga i ciemna kretynka
dźwiga się powoli i staje, podobna do bożka pogańskiego, na krótkich
dziecinnych nóżkach, a z napęczniałej napływem złości szyi, z
poczerwieniałej, ciemniejącej od gniewu twarzy, na której jak malowidła
barbarzyńskie wykwitają arabeski nabrzmiałych żył, wyrywa się wrzask
zwierzęcy, wrzask chrapliwy, dobyty ze wszystkich bronchij i piszczałek
tej półzwierzęcej-półboskiej piersi. Bodiaki, spalone słońcem, krzyczą,
łopuchy puchną i pysznią się bezwstydnym mięsem, chwasty ślinią się
błyszczącym jadem, a kretynka, ochrypła od krzyku, w konwulsji dzikiej
uderza mięsistym łonem z wściekłą zapalczywością w pień bzu dzikiego,
który skrzypi cicho pod natarczywością tej rozpustnej chuci, zaklinany
całym tym nędzarskim chórem do wynaturzonej, pogańskiej płodności. Matka
Tłui wynajmuje się gospodyniom do szorowania podłóg. Jest to mała, żółta
jak szafran kobieta i szafranem zaprawia też podłogi, jodłowe stoły,
ławy i szlabany, które w izbach ubogich ludzi zmywa. Raz zaprowadziła
mnie Adela do domu tej starej Maryśki. Była wczesna poranna godzina,
weszliśmy do małej izby niebiesko bielonej, z ubitą polepą glinianą na
podłodze, na której leżało wczesne słońce, jaskrawożółte w tej ciszy
porannej, odmierzanej przeraźliwym szczękiem chłopskiego zegara na
ścianie. W skrzyni na słomie leżała głupia Maryśka, blada jak opłatek i
cicha jak rękawiczka, z której wysunęła się dłoń. I jakby korzystając z
jej snu, gadała cisza, żółta, jaskrawa, zła cisza, monologowała, kłóciła
się, wygadywała głośno i ordynarnie swój maniacki monolog. Czas Maryśki
- czas więziony w jej duszy, wystąpił z niej straszliwie rzeczywisty i
szedł samopas przez izbę, hałaśliwy, huczący, piekielny, rosnący w
jaskrawym milczeniu poranka z głośnego młyna-zegara, jak zła mąka, sypka
mąka, głupia mąka wariatów.

3 W jednym z tych domków, otoczonym sztachetami brązowej barwy, tonącym
w bujnej zieleni ogródka, mieszkała ciotka Agata. Wchodząc do niej,
mijaliśmy w ogrodzie kolorowe szklane kule, tkwiące na tyczkach, różowe,
zielone i fioletowe, w których zaklęte były całe świetlane i jasne
światy, jak te idealne i szczęśliwe obrazy zamknięte w niedościgłej
doskonałości baniek mydlanych. W półciemnej sieni ze starymi
oleodrukami, pożartymi przez pleśń i oślepłymi od starości,
odnajdowaliśmy znany nam zapach. W tej zaufanej starej woni mieściło się
w dziwnie prostej syntezie życie tych ludzi, alembik rasy, gatunek krwi
i sekret ich losu, zawarty niedostrzegalnie w codziennym mijaniu ich
własnego, odrębnego czasu. Stare, mądre drzwi, których ciemne
westchnienia wpuszczały i wypuszczały tych ludzi, milczący świadkowie
wchodzenia i wychodzenia matki, córek i synów - otworzyły się bezgłośnie
jak odrzwia szafy i weszliśmy w ich życie. Siedzieli jakby w cieniu
swego losu i nie bronili się - w pierwszych niezręcznych gestach
wydalinam swoją tajemnicę. Czyż nie byliśmy krwią i losem spokrewnieni z
nimi? Pokój był ciemny i aksamitny od granatowych obić ze złotym
deseniem, lecz echo dnia płomiennego drgało i tutaj jeszcze mosiądzem na
ramach obrazów, na klamkach i listwach złotych, choć przepuszczone przez
gęstą zieleń ogrodu. Spod ściany podniosła się ciotka Agata, wielka i
bujna, o mięsie okrągłym i białym, centkowanym rudą rdzą piegów.
Przysiedliśmy się do nich, jakby na brzeg ich losu, zawstydzeni trochę
tą bezbronnością, z jaką wydali się nam bez zastrzeżeń, i piliśmy wodę z
sokiem różanym, napój przedziwny, w którym znalazłem jakby najgłębszą
esencję tej upalnej soboty. Ciotka narzekała. Był to zasadniczy ton jej
rozmów, głos tego mięsa białego i płodnego, bujającego już jakby poza
granicami osoby, zaledwie luźnie utrzymywanej w skupieniu, w więzach
formy indywidualnej, i nawet w tym skupieniu już zwielokrotnionej,
gotowej rozpaść się, rozgałęzić, rozsypać w rodzinę. Była to płodność
niemal samoródcza, kobiecość pozbawiona hamulców i chorobliwie wybujała.
Zdawało się, że sam aromat męskości, zapach dymu tytoniowego, dowcip
kawalerski mógł dać impuls tej zaognionej kobiecości do rozpustnego
dzieworództwa. I właściwie wszystkie jej skargi na męża, na służbę, jej
troski o dzieci były tylko kapryszeniem i dąsaniem się nie zaspokojonej
płodności, dalszym ciągiem tej opryskliwej, gniewnej i płaczliwej
kokieterii, którą nadaremnie doświadczała męża. Wuj Marek, mały,
zgarbiony, o twarzy wyjałowionej z płci, siedział w swym szarym
bankructwie, pogodzony z losem, w cieniu bezgranicznej pogardy, w którym
zdawał się wypoczywać. W jego szarych oczach tlił się daleki żar ogrodu,
rozpięty w oknie. Czasem próbował słabym ruchem robić jakieś
zastrzeżenia, stawiać opór, ale fala samowystarczalnej kobiecości
odrzucała na bok ten gest bez znaczenia, przechodziła triumfalnie mimo
niego, zalewała szerokim swym strumieniem słabe podrygi męskości. Było
coś tragicznego w tej płodności niechlujnej i nieumiarkowanej, była
nędza kreatury walczącej na granicy nicości i śmierci, był jakiś heroizm
kobiecości triumfującej urodzajnością nawet nad kalectwem natury, nad
insuficjencją mężczyzny. Ale potomstwo ukazywało rację tej paniki
macierzyńskiej, tego szału rodzenia, który wyczerpywał się w płodach
nieudanych, w efemerycznej generacji fantomów bez krwi i twarzy. Weszła
Łucja, średnia, z głową nazbyt rozkwitłą i dojrzałą na dziecięcym i
pulchnym ciele o mięsie białym i delikatnym. Podała mi rączkę lalkowatą,
jakby dopiero pączkującą, i zakwitła od razu całą twarzą, jak piwonia
przelewająca się pełnią różową. Nieszczęśliwa z powodu swych rumieńców,
które bezwstydnie mówiły o sekretach menstruacji, przymykała oczy i
płoniła się jeszcze bardziej pod dotknięciem najobojętniejszego pytania,
gdyż każde zawierało tajną aluzję do jej nadwrażliwego panieństwa. Emil,
najstarszy z kuzynów, z jasnoblond wąsem, z twarzą, z której życie zmyło
jakby wszelki wyraz, spacerował tam i z powrotem po pokoju, z rękami w
kieszeniach fałdzistych spodni. Jego strój elegancki i drogocenny nosił
piętno egzotycznych krajów, z których powrócił. Jego twarz, zwiędła i
zmętniała, zdawała się z dnia na dzień zapominać o sobie, stawać się
białą pustą ścianą z bladą siecią żyłek, w których jak linie na zatartej
mapie plątały się gasnące wspomnienia tego burzliwego i zmarnowanego
życia. Był mistrzem sztuk karcianych, palił długie, szlachetne fajki i
pachniał dziwnie zapachem dalekich krajów. Z wzrokiem wędrującym po
dawnych wspomnieniach opowiadał dziwne anegdoty, które w pewnym punkcie
urywały się nagle, rozprzęgały i rozwiewały w nicość. Wodziłem za nim
tęsknym wzrokiem, pragnąc, by zwrócił na mnie uwagę i wybawił mnie z
udręki nudów. I w samej rzeczy zdawało mi się, że mrugnął na mnie
oczyma, wychodząc do drugiego pokoju. Podążyłem za nim. Siedział nisko
na małej kozetce, z kolanami krzyżującymi się niemal na wysokości głowy,
łysej jak kula bilardowa. Zdawało się, że to ubranie samo leży,
fałdziste, zmięte, przerzucone przez fotel. Twarz jego była jak
tchnienie twarzy - smuga, którą nieznany przechodzień zostawił w
powietrzu. Trzymał w bladych, emaliowanych błękitnie dłoniach portfel, w
którym coś oglądał. Z mgły twarzy wyłoniło się z trudem wypukłe bielmo
bladego oka, wabiąc mnie figlarnym mruganiem. Czułem doń nieprzepartą
sympatię. Wziął mnie między kolana i tasując przed mymi oczyma wprawnymi
dłońmi fotografie, pokazywał wizerunki nagich kobiet i chłopców w
dziwnych pozycjach. Stałem oparty o niego bokiem i patrzyłem na te
delikatne ciała ludzkie dalekimi, niewidzącymi oczyma, gdy fluid
niejasnego wzburzenia, którym nagle zmętniało powietrze, doszedł do mnie
i zbiegł mię dreszczem niepokoju, falą nagłego zrozumienia. Ale
tymczasem ta mgiełka uśmiechu, która się zarysowała pod miękkim i
pięknym jego wąsem, zawiązek pożądania, który napiął się na jego
skroniach pulsującą żyłą, natężenie trzymające przez chwilę jego rysy w
skupieniu - upadły z powrotem w nicość i twarz odeszła w nieobecność,
zapomniała o sobie, rozwiała się,

NAWIEDZENIE 1 Już wówczas miasto nasze popadało coraz bardziej w
chroniczną szarość zmierzchu, porastało na krawędziach liszajem cienia,
puszystą pleśnią i mchem koloru żelaza. Ledwo rozpowity z brunatnych
dymów i mgieł poranka - przechylał się dzień od razu w niskie
bursztynowe popołudnie, stawał się przez chwilę przezroczysty i złoty
jak ciemne piwo, ażeby potem zejść pod wielokrotnie rozczłonkowane,
fantastyczne sklepienia kolorowych i rozległych nocy. Mieszkaliśmy w
rynku, w jednym z tych ciemnych domów o pustych i ślepych fasadach,
które tak trudno od siebie odróżnić. Daje to powód do ciągłych omyłek.
Gdyż wszedłszy raz w niewłaściwą sień na niewłaściwe schody, dostawało
się zazwyczaj w prawdziwy labirynt obcych mieszkań, ganków,
niespodzianych wyjść na obce podwórza i zapominało się o początkowym
celu wyprawy, ażeby po wielu dniach, wracając z manowców dziwnych i
splątanych przygód, o jakimś szarym świcie przypomnieć sobie wśród
wyrzutów sumienia dom rodzinny. Pełne wielkich szaf, głębokich kanap,
bladych luster i tandetnych palm sztucznych mieszkanie nasze coraz
bardziej popadało w stan zaniedbania wskutek opieszałości matki,
przesiadującej w sklepie, i niedbalstwa smukłonogiej Adeli, która nie
nadzorowana przez nikogo, spędzała dnie przed lustrami na rozwlekłej
toalecie, zostawiając wszędzie ślady w postaci wyczesanych włosów,
grzebieni, porzuconych pantofelków i gorsetów. Mieszkanie to nie
posiadało określonej liczby pokojów, gdyż nie pamiętano, ile z nich
wynajęte było obcym lokatorom. Nieraz otwierano przypadkiem którąś z
tych izb zapomnianych i znajdowano ją pustą; lokator dawno się
wyprowadził, a w nietkniętych od miesięcy szufladach dokonywano
niespodzianych odkryć. W dolnych pokojach mieszkali subiekci i nieraz w
nocy budziły nas ich jęki, wydawane pod wpływem zmory sennej. W zimie
była jeszcze na dworze głucha noc, gdy ojciec schodził do tych zimnych i
ciemnych pokojów, płosząc przed sobą świecą stada cieni, ulatujących
bokami po podłodze i ścianach; szedł budzić ciężko chrapiących z
twardego jak kamień snu. W świetle pozostawionej przezeń świecy wywijali
się leniwie z brudnej pościeli, wystawiali, siadając na łóżkach, bose i
brzydkie nogi i z skarpetką w ręce oddawali się jeszcze przez chwilę
rozkoszy ziewania - ziewania przeciągniętego aż do lubieżności, do
bolesnego skurczu podniebienia, jak przy tęgich wymiotach. W kątach
siedziały nieruchomo wielkie karakony, wyogromnione własnym cieniem,
którym obarczała każdego płonąca świeca i który nie odłączał się od nich
i wówczas, gdy któryś z tych płaskich, bezgłowych kadłubów z nagła
zaczynał biec niesamowitym, pajęczym biegiem. W tym czasie ojciec mój
zaczął zapadać na zdrowiu. Bywało już w pierwszych tygodniach tej
wczesnej zimy, że spędzał dnie całe w łóżku, otoczony flaszkami,
pigułkami i księgami handlowymi, które mu przynoszono z kontuaru. Gorzki
zapach choroby osiadał na dnie pokoju, którego tapety gęstwiały
ciemniejszym splotem arabesek. Wieczorami, gdy matka przychodziła ze
sklepu, bywał podniecony i skłonny do sprzeczek, zarzucał jej
niedokładności w prowadzeniu rachunków, dostawał wypieków i zapalał się
do niepoczytalności. Pamiętam, iż raz, obudziwszy się ze snu późno w
nocy, ujrzałem go, jak w koszuli i boso biegał tam i z powrotem po
skórzanej kanapie, dokumentując w ten sposób swą irytację przed bezradną
matką. W inne dni bywał spokojny i skupiony i pogrążał się zupełnie w
swych księgach, zabłąkany głęboko w labiryntach zawiłych obliczeń. Widzę
go w świetle kopcącej lampy, przykucniętego wśród poduszek, pod wielkim
rzeźbionym nadgłowiem łóżka, z ogromnym cieniem od głowy na ścianie,
kiwającego się w bezgłośnej medytacji. Chwilami wynurzał głowę z tych
rachunków, jakby dla zaczerpnięcia tchu, otwierał usta, mlaskał z
niesmakiem językiem, który był suchy i gorzki, i rozglądał się
bezradnie, jakby czegoś szukając. Wówczas bywało, że zbiegał po cichu z
łóżka w kąt pokoju, pod ścianę, na której wisiał zaufany instrument. Był
to rodzaj klepsydry wodnej albo wielkiej fioli szklanej, podzielonej na
uncje i napełnionej ciemnym fluidem. Mój ojciec łączył się z tym
instrumentem długą kiszką gumową, jakby krętą, bolesną pępowiną, i tak
połączony z żałosnym przyrządem - nieruchomiał w skupieniu, a oczy jego
ciemniały, zaś na twarz przybladłą występował wyraz cierpienia czy
jakiejś występnej rozkoszy. Potem znów przychodziły dni cichej skupionej
pracy, przeplatanej samotnymi monologami. Gdy tak siedział w świetle
lampy stołowej, wśród poduszek wielkiego łoża, a pokój ogromniał górą w
cieniu umbry, który go łączył z wielkim żywiołem nocy miejskiej za oknem
- czuł, nie patrząc, że przestrzeń obrasta go pulsującą gęstwiną tapet,
pełną szeptów, syków i seplenień. Słyszał, nie patrząc, tę zmowę pełną
porozumiewawczych mrugnięć perskich oczu, rozwijających się wśród
kwiatów małżowin usznych, które słuchały, i ciemnych ust, które się
uśmiechały. Wówczas pogrążał się pozornie jeszcze bardziej w pracę,
liczył i sumował, bojąc się zdradzić ten gniew, który w nim wzbierał, i
walcząc z pokusą, żeby z nagłym krzykiem nie rzucić się na oślep za
siebie i nie pochwycić pełnych garści tych kędzierzawych arabesek, tych
pęków oczu i uszu, które noc wyroiła ze siebie i które rosły i
zwielokrotniały się, wymajaczając coraz nowe pędy i odnogi z
macierzystego pępka ciemności. I uspokajał się dopiero, gdy z odpływem
nocy tapety więdły, zwijały się, gubiły liście i kwiaty i przerzedzały
się jesiennie, przepuszczając dalekie świtanie. Wtedy wśród świergotu
tapetowych ptaków, w żółtym zimowym świcie zasypiał na parę godzin
gęstym, czarnym snem. Od dni, od tygodni, gdy zdawał się być pogrążonym
w zawiłych konto-korrentach - myśl jego zapuszczała się tajnie w
labirynty własnych wnętrzności. Wstrzymywał oddech i nasłuchiwał. I gdy
wzrok jego wracał zbielały i mętny z tamtych głębin, uspokajał go
uśmiechem. Nie wierzył jeszcze i odrzucał jak absurd te uroszczenia, te
propozycje, które nań napierały. Za dnia były to jakby rozumowania i
perswazje, długie, monotonne rozważania prowadzone półgłosem i pełne
humorystycznych interiudiów, filuternych przekomarzań. Ale nocą
podnosiły się te głosy namiętniej. Żądanie wracało coraz wyraźniej i
doniosłej i słyszeliśmy, jak rozmawiał z Bogiem, prosząc się jak gdyby i
wzbraniając przed czymś, co natarczywie żądało i domagało się. Aż pewnej
nocy podniósł się ten głos groźnie i nieodparcie, żądając, aby mu dał
świadectwo usty i wnętrznościami swymi. I usłyszeliśmy, jak duch weń
wstąpił, jak podnosi się z łóżka, długi i rosnący gniewem proroczym,
dławiąc się hałaśliwymi słowy, które wyrzucał jak mitralieza.
Słyszeliśmy łomot walki i jęk ojca, jęk tytana ze złamanym biodrem,
który jeszcze urąga. Nie widziałem nigdy proroków Starego Testamentu,
ale na widok tego męża, którego gniew boży obalił, rozkraczonego szeroko
na ogromnym porcelanowym urynale, zakrytego wichrem ramion, chmurą
rozpaczliwych łamańców, nad którymi wyżej jeszcze unosił się głos jego,
obcy i twardy - zrozumiałem gniew boży świętych mężów. Był to dialog
groźny jak mowa piorunów. Łamańce rak jego rozrywały niebo na sztuki, a
w szczelinach ukazywała się twarz Jehowy, wzdęta gniewem i plująca
przekleństwa. Nie patrząc widziałem go, groźnego Demiurga, jak leżąc na
ciemnościach jak na Synaju, wsparłszy potężne dłonie na karniszu
firanek, przykładał ogromną twarz do górnych szyb okna, na których
płaszczył się potwornie mięsisty nos jego. Słyszałem jego głos w
przerwach proroczej tyrady mego ojca, słyszałem te potężne warknięcia
wzdętych warg, od których szyby brzęczały, mieszające się z wybuchami
zaklęć, lamentów, gróźb mego ojca. Czasami głosy przycichały i zżymały
się z cicha jak gaworzenie wiatru w nocnym kominie, to znowu wybuchały
wielkim zgiełkliwym hałasem, burzą zmieszanych szlochów i przekleństw. Z
nagła otworzyło się okno ciemnym ziewnięciem i płachta ciemności wionęła
przez pokój. W świetle błyskawicy ujrzałem ojca mego w rozwianej
bieliźnie, jak ze straszliwym przekleństwem wylewał potężnym chlustem w
okno zawartość nocnika w noc szumiącą jak muszla. 2 Mój ojciec powoli
zanikał, wiądł w oczach. Przykucnięty pod wielkimi poduszkami, dziko
nastroszony kępami siwych włosów, rozmawiał z sobą półgłosem, pogrążony
cały w jakieś zawiłe wewnętrzne afery. Zdawać się mogło, że osobowość
jego rozpadła się na wiele pokłóconych i rozbieżnych jaźni, gdyż kłócił
się ze sobą głośno, pertraktował usilnie i namiętnie, przekonywał i
prosił, to znowu zdawał się przewodniczyć zgromadzeniu wielu
interesantów, których usiłował z całym nakładem żarliwości i swady
pogodzić. Ale za każdym razem te hałaśliwe zebrania, pełne gorących
temperamentów, rozpryskiwały się przy końcu, wśród klątw, złorzeczeń i
obelg. Potem przyszedł okres jakiegoś uciszenia, ukojenia wewnętrznego,
błogiej pogody ducha. Znowu wielkie folianty rozłożone były na łóżku, na
stole, na podłodze i jakiś benedyktyński spokój pracy zalegał w świetle
lampy nad białą pościelą łóżka, nad pochyloną siwą głową mego ojca. Ale
gdy matka późnym wieczorem wracała ze sklepu, ojciec ożywiał się,
przywoływał ją do siebie i z dumą pokazywał jej świetne, kolorowe
odbijanki, którymi skrzętnie wylepił stronice księgi głównej.
Zauważyliśmy wówczas wszyscy, że ojciec zaczął z dnia na dzień maleć jak
orzech, który zsycha się wewnątrz łupiny. Zanikowi temu nie towarzyszył
bynajmniej upadek sił. Przeciwnie, stan jego zdrowia, humor, ruchliwość
zdawały się poprawiać. Często śmiał się teraz głośno i szczebiotliwie,
zanosił się wprost od śmiechu, albo też pukał w łóżko i odpowiadał sobie
„proszę” w różnych tonacjach, całymi godzinami. Od czasu do czasu złaził
z łóżka, wspinał się na szafę i przykucnięty pod sufitem porządkował coś
w starych gratach, pełnych rdzy i kurzu. Niekiedy ustawiał sobie dwa
krzesła naprzeciw siebie i wspierając się rękami o poręcze, bujał się
nogami wstecz i naprzód, szukając rozpromienionymi oczyma w naszych
twarzach wyrazów podziwu i zachęty. Z Bogiem, zdaje się, pogodził się
zupełnie. Niekiedy w nocy ukazywała się twarz brodatego Demiurga w oknie
sypialni, oblana ciemną purpurą bengalskiego światła, i patrzyła przez
chwilę dobrotliwie na uśpionego głęboko, którego śpiewne chrapanie
zdawało się wędrować daleko po nieznanych obszarach światów sennych.
Podczas długich, półciemnych popołudni tej późnej zimy ojciec mój
zapadał od czasu do czasu na całe godziny w gęsto zastawione gratami
zakamarki, szukając czegoś zawzięcie. I nieraz bywało podczas obiadu,
gdy zasiadaliśmy wszyscy do stołu, brakło ojca. Wówczas matka musiała
długo wołać „Jakubie!” i stukać łyżką w stół, zanim wylazł z jakiejś
szafy, oblepiony szmatami pajęczyny i kurzu, z wzrokiem nieprzytomnym i
pogrążonym w zawiłych, a jemu tylko wiadomych sprawach, które go
zaprzątały. Czasem wdrapywał się na karnisz i przybierał nieruchomą pozę
symetrycznie do wielkiego wypchanego sępa, który po drugiej stronie okna
zawieszony był na ścianie. W tej nieruchomej, przykucniętej pozie, z
wzrokiem zamglonym i z miną chytrze uśmiechniętą trwał godzinami, ażeby
z nagła przy czyimś wejściu zatrzepotać rękoma jak skrzydłami i zapiać
jak kogut. Przestaliśmy zwracać uwagę na te dziwactwa, w które się z
dnia na dzień głębiej wplątywał. Wyzbyty jakby zupełnie cielesnych
potrzeb, nie przyjmując tygodniami pokarmu, pogrążał się z dniem każdym
głębiej w zawiłe i dziwaczne afery, dla których nie mieliśmy
zrozumienia. Niedosięgły dla naszych perswazji i próśb, odpowiadał
urywkami swego wewnętrznego monologu, którego przebiegu nic z zewnątrz
zmącić nie mogło. Wiecznie zaaferowany, chorobliwie ożywiony, z
wypiekami na suchych policzkach nie zauważał nas i przeoczał.
Przywykliśmy do jego nieszkodliwej obecności, do jego cichego
gaworzenia, do tego dziecinnego, w sobie zatopionego świegotu, którego
trele przebiegały niejako na marginesie naszego czasu. Wtedy już znikał
niekiedy na wiele dni, podziewał się gdzieś w zapadłych zakamarkach
mieszkania i nie można go było znaleźć. Stopniowo te zniknięcia
przestały sprawiać na nas wrażenie, przywykliśmy do nich i kiedy po
wielu dniach znów się pojawiał, o parę cali mniejszy i chudszy, nie
zatrzymywało to na dłużej naszej uwagi. Przestaliśmy po prostu brać go w
rachubę, tak bardzo oddalił się od wszystkiego, co ludzkie i co
rzeczywiste. Węzeł po węźle odluźniał się od nas, punkt po punkcie gubił
związki łączące go ze wspólnotą ludzką. To, co jeszcze z niego
pozostało, to trochę cielesnej powłoki i ta garść bezsensownych dziwactw
- mogły zniknąć pewnego dnia, tak samo nie zauważone jak szara kupka
śmieci, gromadząca się w kącie, którą Adela co dzień wynosiła na
śmietnik.

PTAKI Nadeszły żółte, pełne nudy dni zimowe. Zrudziałą ziemię pokrywał
dziurawy, przetarty, za krótki obrus śniegu. Na wiele dachów nie
starczyło go i stały czarne lub rdzawe, gontowe strzechy i arki kryjące
w sobie zakopcone przestrzenie strychów - czarne, zwęglone katedry,
najeżone żebrami krokwi, płatwi i bantów - ciemne płuca wichrów
zimowych. Każdy świt odkrywał nowe kominy i dymniki, wyrosłe w nocy,
wydęte przez wicher nocny, czarne piszczałki organów diabelskich.
Kominiarze nie mogli opędzić się od wron, które na kształt żywych
czarnych liści obsiadały wieczorem gałęzie drzew pod kościołem, odrywały
się znów, trzepocąc, by wreszcie przylgnąć, każda do właściwego miejsca
na właściwej gałęzi, a o świcie ulatywały wielkimi stadami - tumany
sadzy, płatki kopciu, falujące i fantastyczne, plamiąc migotliwym
krakaniem mętnożółte smugi świtu. Dni stwardniały od zimna i nudy, jak
zeszłoroczne bochenki chleba. Napoczynano je tępymi nożami, bez apetytu,
z leniwą sennością. Ojciec nie wychodził już z domu. Palił w piecach,
studiował nigdy niezgłębioną istotę ognia, wyczuwał słony, metaliczny
posmak i wędzony zapach zimowych płomieni, chłodną pieszczotę
salamander, liżących błyszczącą sadzę w gardzieli komina. Z zamiłowaniem
wykonywał w owych dniach wszystkie reparatury w górnych regionach
pokoju. O każdej porze dnia można go było widzieć, jak - przykucnięty na
szczycie drabiny - majstrował coś przy suficie, przy kamiszach wysokich
okien, przy kulach i łańcuchach lamp wiszących. Zwyczajem malarzy
posługiwał się drabiną jak ogromnymi szczudłami i czuł się dobrze w tej
ptasiej perspektywie, w pobliżu malowanego nieba, arabesek i ptaków
sufitu. Od spraw praktycznego życia oddalał się coraz bardziej. Gdy
matka, pełna troski i zmartwienia z powodu jego stanu, starała się go
wciągnąć w rozmowę o interesach, o płatnościach najbliższego „ultimo”,
słuchał jej z roztargnieniem, pełen niepokoju, z drgawkami w nieobecnej
twarzy. I bywało, że przerywał jej nagle zaklinającym gestem ręki, ażeby
pobiec w kąt pokoju, przylgnąć uchem do szpary w podłodze i z
podniesionymi palcami wskazującymi obu rąk, wyrażającymi najwyższą
ważność badania - nasłuchiwać. Nie rozumieliśmy wówczas jeszcze smutnego
tła tych ekstrawagancji, opłakanego kompleksu, który dojrzewał w głębi.
Matka nie miała nań żadnego wpływu, natomiast wielką czcią i uwagą
darzył Adelę. Sprzątanie pokoju było dlań wielką i ważną ceremonią,
której nie zaniedbywał nigdy być świadkiem, śledząc z mieszaniną strachu
i rozkosznego dreszczu wszystkie manipulacje Adeli. Wszystkim jej
czynnościom przypisywał głębsze, symboliczne znaczenie. Gdy dziewczyna
młodymi i śmiałymi ruchami posuwała szczotkę na długim drążku po
podłodze, było to niemal ponad jego siły. Z oczu jego lały się wówczas
łzy, twarz zanosiła się od cichego śmiechu, a ciałem wstrząsał rozkoszny
spazm orgazmu. Jego wrażliwość na łaskotki dochodziła do szaleństwa.
Wystarczyło, by Adela skierowała doń palec ruchem oznaczającym
łaskotanie, a już w dzikim popłochu uciekał przez wszystkie pokoje,
zatrzaskując za sobą drzwi, by wreszcie w ostatnim paść brzuchem na
łóżko i wić się w konwulsjach śmiechu pod wpływem samego obrazu
wewnętrznego, któremu nie mógł się oprzeć. Dzięki temu miała Adela nad
ojcem władzę niemal nieograniczoną. W tym to czasie zauważyliśmy u ojca
po raz pierwszy namiętne zainteresowanie dla zwierząt. Była to
początkowo namiętność myśliwego i artysty zarazem, była może także
głębsza, zoologiczna sympatia kreatury dla pokrewnych, a tak odmiennych
form życia, eksperymentowanie w nie wypróbowanych rejestrach bytu.
Dopiero w późniejszej fazie wzięła sprawa ten niesamowity, zaplątany,
głęboko grzeszny i przeciwny naturze obrót, którego lepiej nie wywlekać
na światło dzienne. Zaczęło się to od wylęgania jaj ptasich. Z wielkim
nakładem trudu i pieniędzy sprowadzał ojciec z Hamburga, z Holandii, z
afrykańskich stacji zoologicznych zapłodnione jaja ptasie, które dawał
do wylęgania ogromnym kurom belgijskim. Był to proceder nader zajmujący
i dla mnie - to wykluwanie się piskląt, prawdziwych dziwotworów w
kształcie i ubarwieniu. Nie podobna było dopatrzyć się w tych monstrach
o ogromnych, fantastycznych dziobach, które natychmiast po urodzeniu
rozdzierały się szeroko, sycząc żarłocznie czeluściami gardła, w tych
jaszczurach o wątłym, nagim ciele garbusów - przyszłych pawi, bażantów,
głuszców i kondorów. Umieszczony w koszykach, w wacie, smoczy ten pomiot
podnosił na cienkich szyjach ślepe, bielmem zarosle głowy, kwacząc
bezgłośnie z niemych gardzieli. Mój ojciec chodził wzdłuż półek w
zielonym fartuchu, jak ogrodnik wzdłuż inspektów z kaktusami, i wywabiał
z nicości te pęcherze ślepe, pulsujące życiem, te niedołężne brzuchy,
przyjmujące świat zewnętrzny tylko w formie jedzenia, te narośle życia,
pnące się omackiem ku światłu. W parę tygodni później, gdy te ślepe
pączki życia pękły do światła, napełniły się pokoje kolorowym pogwarem,
migotliwym świergotem swych nowych mieszkańców. Obsiadały one karnisze
firanek, gzymsy szaf, gnieździły się w gęstwinie cynowych gałęzi i
arabesek wieloramiennych lamp wiszących. Gdy ojciec studiował wielkie
ornitologiczne kompendia i wertował kolorowe tablice, zdawały się
ulatywać z nich te pierzaste fantazmaty i napełniać pokój kolorowym
trzepotem, płatami purpury, strzępami szafiru, grynszpanu i srebra.
Podczas karmienia tworzyły one na podłodze barwną, falującą grządkę,
dywan żywy, który za czyimś niebacznym wejściem rozpadał się, rozlatywał
w ruchome kwiaty, trzepocące w powietrzu, aby w końcu rozmieścić się w
górnych regionach pokoju. W pamięci pozostał mi szczególnie jeden
kondor, ogromny ptak o szyi nagiej, twarzy pomarszczonej i wybujałej
naroślami. Był to chudy asceta, lama buddyjski, pełen niewzruszonej
godności w całym zachowaniu, kierujący się żelaznym ceremoniałem swego
wielkiego rodu. Gdy siedział naprzeciw ojca, nieruchomy w swej
monumentalnej pozycji odwiecznych bóstw egipskich, z okiem zawleczonym
białawym bielmem, które zasuwał z boku na źrenice, ażeby zamknąć się
zupełnie w kontemplacji swej dostojnej samotności - wydawał się ze swym
kamiennym profilem starszym bratem mego ojca. Ta sama materia ciała,
ścięgien i pomarszczonej twardej skóry, ta sama twarz wyschła i
koścista, te same zrogowaciałe, głębokie oczodoły. Nawet ręce, silne w
węzłach, długie, chude dłonie ojca, z wypukłymi paznokciami, miały swój
analogon w szponach kondora. Nie mogłem się oprzeć wrażeniu, widząc go
tak uśpionego, że mam przed sobą mumię - wyschłą i dlatego pomniejszoną
mumię mego ojca. Sądzę, że i uwagi matki nie uszło to przedziwne
podobieństwo, chociaż nigdy nie poruszaliśmy tego tematu.
Charakterystyczne jest, że kondor używał wspólnego z moim ojcem naczynia
nocnego. Nie poprzestając na wylęganiu coraz nowych egzemplarzy, ojciec
mój urządzał na strychu wesela ptasie, wysyłał swatów, uwiązywał w
lukach i dziurach strychu ponętne, stęsknione narzeczone i osiągnął w
samej rzeczy to, że dach naszego domu, ogromny, dwuspadowy dach gontowy,
stał się prawdziwą gospodą ptasią, arką Noego, do której zlatywały się
wszelkiego rodzaju skrzydlacze z dalekich stron. Nawet długo po
zlikwidowaniu ptasiego gospodarstwa utrzymywała się w świecie ptasim ta
tradycja naszego domu i w okresie wiosennych wędrówek spadały nieraz na
nasz dach całe chmary żurawi, pelikanów, pawi i wszelkiego ptactwa.
Impreza ta wzięła jednak niebawem - po krótkiej świetności - smutny
obrót. Wkrótce okazała się bowiem konieczna translokacja ojca do dwóch
pokojów na poddaszu, które służyły za rupieciarnie. Stamtąd dochodził
już o wczesnym świcie zmieszany klangor głosów ptasich. Drewniane pudła
pokojów na strychu, wspomagane rezonansem przestrzeni dachowej,
dźwięczały całe od szumu, trzepotu, piania, tokowania i gulgotu. Tak
straciliśmy ojca z widoku na przeciąg kilku tygodni. Rzadko tylko
schodził do mieszkania i wtedy mogliśmy zauważyć, że zmniejszył się
jakoby, schudł i skurczył. Niekiedy przez zapomnienie zrywał się z
krzesła przy stole i trzepiąc rękoma jak skrzydłami, wydawał pianie
przeciągłe, a oczy zachodziły mu mgłą bielma. Potem, zawstydzony, śmiał
się razem z nami i starał się ten incydent obrócić w żart. Pewnego razu
w okresie generalnych porządków zjawiła się niespodzianie Adela w
państwie ptasim ojca. Stanąwszy we drzwiach, załamała ręce nad fetorem,
który się unosił w powietrzu, oraz nad kupami kału, zalegającego
podłogi, stoły i meble. Szybko zdecydowana otworzyła okno, po czym przy
pomocy długiej szczotki wprawiła całą masę ptasią w wirowanie. Wzbił się
piekielny tuman piór, skrzydeł i krzyku, w którym Adela, podobna do
szalejącej Menady, zakrytej młyńcem swego tyrsu, tańczyła taniec
zniszczenia. Razem z ptasią gromadą ojciec mój, trzepiąc rękoma, w
przerażeniu próbował wznieść się w powietrze. Zwolna przerzedzał się
tuman skrzydlaty, aż w końcu na pobojowisku została sama Adela,
wyczerpana, dysząca, oraz mój ojciec z miną zafrasowaną i zawstydzoną,
gotów do przyjęcia każdej kapitulacji. W chwilę później schodził mój
ojciec ze schodów swojego dominium - człowiek złamany, król-banita,
który stracił tron i królowanie.

MANEKINY Ta ptasia impreza mego ojca była ostatnim wybuchem kolorowości,
ostatnim i świetnym kontrmarszem fantazji, który ten niepoprawny
improwizator, ten fechtmistrz wyobraźni poprowadził na szańce i okopy
jałowej i pustej zimy. Dziś dopiero rozumiem samotne bohaterstwo, z
jakim sam jeden wydał on wojnę bezbrzeżnemu żywiołowi nudy drętwiącej
miasto. Pozbawiony wszelkiego poparcia, bez uznania z naszej strony
bronił ten mąż przedziwny straconej sprawy poezji. Był on cudownym
młynem, w którego leje sypały się otręby pustych godzin, ażeby w jego
trybach zakwitnąć wszystkimi kolorami i zapachami korzeni Wschodu. Ale
przywykli do świetnego kuglarstwa tego metafizycznego prestidigitatora,
byliśmy skłonni zapoznawać wartość jego suwerennej magii, która nas
ratowała od letargu pustych dni i nocy. Adeli nie spotkał żaden wyrzut
za jej bezmyślny i tępy wandalizm. Przeciwnie, czuliśmy jakieś niskie
zadowolenie, haniebną satysfakcję z ukrócenia tych wybujałości, których
kosztowaliśmy łakomie do syta, ażeby potem uchylić się perfidnie od
odpowiedzialności za nie. A może był w tej zdradzie i tajny pokłon w
stronę zwycięskiej Adeli, której przypisywaliśmy niejasno jakąś misje i
posłannictwo sił wyższego rzędu. Zdradzony przez wszystkich, wycofał się
ojciec bez walki z miejsc swej niedawnej chwały. Bez skrzyżowania szpad
oddał w ręce wroga domenę swej byłej świetności. Dobrowolny banita
usunął się do pustego pokoju na końcu sieni i oszańcował się tam
samotnością. Zapomnieliśmy o nim. Obiegła nas znowu ze wszech stron
żałobna szarość miasta, zakwitając w oknach ciemnym liszajem świtów,
pasożytniczym grzybem zmierzchów, rozrastającym się w puszyste futro
długich nocy zimowych. Tapety pokojów, rozluźnione błogo za tamtych dni
i otwarte dla kolorowych lotów owej skrzydlatej czeredy, zamknęły się
znów w sobie, zgęstniały plącząc się w monotonii gorzkich monologów.
Lampy poczerniały i zwiędły jak stare osty i bodiaki. Wisiały teraz
osowiałe i zgryźliwe, dzwoniąc cicho kryształkami szkiełek, gdy ktoś
przeprawiał się omackiem przez zmierzch pokoju. Na próżno wetknęła Adela
we wszystkie ramiona tych lamp kolorowe świece, nieudolny surogat, blade
wspomnienie świetnych iluminacji, którymi kwitły niedawno wiszące ich
ogrody. Ach! gdzie było to świegotliwe pączkowanie, to owocowanie
pośpieszne i fantastyczne w bukietach tych lamp, z których jak z
pękających czarodziejskich tortów ulatywały skrzydlate fantazmaty,
rozbijające powietrze na talie kart magicznych, rozsypując je w kolorowe
oklaski, sypiące się gęstymi łuskami lazuru, pawiej, papuziej zieleni,
metalicznych połysków, rysując w powietrzu linie i arabeski, migotliwe
ślady lotów i kołowań, rozwijając kolorowe wachlarze trzepotów,
utrzymujące się długo po przelocie w bogatej i błyskotliwej atmosferze,
Jeszcze teraz kryły się w głębi zszarzałej aury echa i możliwości
barwnych rozbłysków, lecz nikt nie nawiercał fletem, nie doświadczał
świdrem zmętniałych słojów powietrznych. Tygodnie te stały pod znakiem
dziwnej senności. Łóżka cały dzień nie zaścielone, zawalone pościelą
zmiętą i wytarzaną od ciężkich snów, stały jak głębokie łodzie gotowe do
odpływu w mokre i zawiłe labirynty jakiejś czarnej, bezgwiezdnej
Wenecji. O głuchym świcie Adela przynosiła nam kawę. Ubieraliśmy się
leniwie w zimnych pokojach, przy świetle świecy odbitej wielokrotnie w
czar-nych szybach okien. Poranki te były pełne bezładnego krzątania się,
rozwlekłego szukania w różnych szufladach i szafach. Po całym mieszkaniu
słychać było kłapanie pantofelków Adeli. Subiekci zapalali latarnie,
brali z rąk matki wielkie klucze sklepowe i wychodzili w gęstą, wirującą
ciemność. Matka nie mogła dojść do ładu z toaletą. Świece dogasały w
lichtarzu. Adela przepadała gdzieś w odległych pokojach lub na strychu,
gdzie rozwieszała bieliznę. Nie można jej się było dowołać. Młody
jeszcze, mętny i brudny ogień w piecu lizał zimne, błyszczące narośle
sadzy w gardzieli komina. Świeca gasła, pokój pogrążał się w ciemności.
Z głowami na obrusie stołu, wśród resztek śniadania zasypialiśmy na wpół
ubrani. Leżąc twarzami na futrzanym brzuchu ciemności, odpływaliśmy na
jego falistym oddechu w bezgwiezdną nicość. Budziło nas głośne
sprzątanie Adeli. Matka nie mogła uporać się z toaletą. Nim skończyła
czesanie, subiekci wracali na obiad. Mrok na rynku przybierał kolor
złotawego dymu. Przez chwilę z tych dymnych miodów, z tych mętnych
bursztynów mogły się rozpowić kolory najpiękniejszego popołudnia. Ale
szczęśliwy moment mijał, amalgamat świtu przekwitał, wezbrany ferment
dnia, już niemal dościgły, opadał z powrotem w bezsilną szarość.
Zasiadaliśmy do stołu, subiekci zacierali czerwone z zimna ręce i nagle
proza ich rozmów sprowadzała od razu pełny dzień, szary i pusty wtorek,
dzień bez tradycji i bez twarzy. Ale gdy pojawiał się na stole półmisek
z rybą w szklistej galarecie, dwie duże ryby leżące bok przy boku, głową
do ogona jak figura zodiakalna, odpoznawaliśmy w nich herb owego dnia,
emblemat kalendarzowy bezimiennego wtorku, i rozbieraliśmy go
pospiesznie między siebie, pełni ulgi, że dzień odzyskał w nim swą
fizjonomię. Subiekci spożywali go z namaszczeniem, z powagą
kalendarzowej ceremonii. Zapach pieprzu rozchodził się po pokoju. A gdy
wytarli bułką ostatek galarety ze swych talerzy, rozważając w myśli
heraldykę następnych dni tygodnia, i na półmisku zostawały tylko głowy z
wygotowanymi oczyma - czuliśmy wszyscy, że dzień został wspólnymi siłami
pokonany i że reszta nie wchodziła już w rachubę. W samej rzeczy z
resztą tą, wydaną na jej łaskę, Adela nie robiła sobie długich
ceregieli. Wśród brzęku garnków i chlustów zimnej wody likwidowała z
energią tych parę godzin do zmierzchu, które matka przesypiała na
otomanie. Tymczasem w jadalni przygotowywano już scenerię wieczoru.
Polda i Paulina, dziewczęta do szycia, rozgospodarowywały się w niej z
rekwizytami swego fachu. Na ich ramionach wniesiona wchodziła do pokoju
milcząca, nieruchoma pani, dama z kłaków i płótna, z czarną drewnianą
gałką zamiast głowy. Ale ustawiona w kącie, między drzwiami a piecem, ta
cicha dama stawała się panią sytuacji. Ze swego kąta, stojąc nieruchomo,
nadzorowała w milczeniu pracę dziewcząt. Pełna krytycyzmu i niełaski
przyjmowała ich starania i umizgi, z jakimi przyklękały przed nią,
przymierzając fragmenty sukni, znaczone białą fastrygą. Obsługiwały z
uwagą i cierpliwością milczący idol, którego nic zadowolić nie mogło.
Ten moloch był nieubłagany, jak tylko kobiece molochy być potrafią, i
odsyłał je wciąż na nowo do pracy, a one, wrzecionowate i smukłe,
podobne do szpuli drewnianych, z których odwijały się nici, i tak
ruchliwe jak one, manipulowały zgrabnymi ruchami nad tą kupą jedwabiu i
sukna, wcinały się szczękającymi nożycami w jej kolorową masę, furkotały
maszyną, depcąc pedał lakierkową, tanią nóżką, a dookoła nich rosła kupa
odpadków, różnokolorowych strzępów i szmatek, jak wyplute łuski i plewy
dookoła dwóch wybrednych i marnotrawnych papug. Krzywe szczęki nożyc
otwierały się ze skrzypieniem, jak dzioby tych kolorowych ptaków.
Dziewczęta deptały nieuważnie po barwnych obrzynkach, brodząc
nieświadomie niby w śmietniku możliwego jakiegoś karnawału, w rupieciami
jakiejś wielkiej nieurzeczywistnionej maskarady. Otrzepywały się ze
szmatek z nerwowym śmiechem, łaskotały oczyma zwierciadła. Ich dusze,
szybkie czarodziejstwo ich rąk było nie w nudnych sukniach, które
zostawały na stole, ale w tych setkach odstrzygnięć, w tych wiórach
lekkomyślnych i płochych, którymi zasypać mogły cale miasto, jak
kolorową fantastyczną śnieżycą. Nagle było im gorąco i otwierały okno,
ażeby w niecierpliwości swej samotni, w głodzie obcych twarzy,
przynajmniej bezimienną twarz zobaczyć, do okna przyciśniętą. Wachlowały
rozpalone swe policzki przed wzbierającą firankami nocą zimową - 
odsłaniały płonące dekolty, pełne nienawiści do siebie i rywalizacji,
gotowe stanąć do walki o tego pierrota, którego by ciemny powiew nocy
przywiał na okno. Ach! jak mało wymagały one od rzeczywistości. Miały
wszystko w sobie, miały nadmiar wszystkiego w sobie. Ach! byłby im
wystarczył pierrot wypchany trocinami, jedno-dwa słowa, na które od
dawna czekały, by móc wpaść w swą rolę dawno przygotowaną, z dawna
tłoczącą się na usta, pełną słodkiej i strasznej goryczy, ponoszącą
dziko, jak stronice romansu połykane nocą wraz ze łzami ronionymi na
wypieki lic. Podczas jednej ze swych wędrówek wieczornych po mieszkaniu,
przedsiębranych pod nieobecność Adeli, natknął się mój ojciec na ten
cichy seans wieczorny. Przez chwilę stał w ciemnych drzwiach przyległego
pokoju, z lampą w ręku, oczarowany sceną pełną gorączki i wypieków, tą
idyllą z pudru, kolorowej bibułki i atropiny, której jako tło pełne
znaczenia podłożona była noc zimowa, oddychająca wśród wzdętych firanek
okna. Nakładając okulary, zbliżył się w paru krokach i obszedł dookoła
dziewczęta, oświecając je podniesioną w ręku lampą. Przeciąg z otwartych
drzwi podniósł firanki u okna, panienki dawały się oglądać, kręcąc się w
biodrach, polśniewając emalią oczu, lakiem skrzypiących pantofelków,
sprzączkami podwiązek pod wzdętą od wiatru sukienką; szmatki jęły umykać
po podłodze, jak szczury, ku uchylonym drzwiom ciemnego pokoju, a ojciec
mój przyglądał się uważnie prychającym osóbkom, szepcąc półgłosem: - 
Genus avium... jeśli się nie mylę, scansores albo pistacci... w
najwyższym stopniu godne uwagi. Przypadkowe to spotkanie stało się
początkiem całej serii seansów, podczas których ojciec mój zdołał rychło
oczarować obie panienki urokiem swej przedziwnej osobistości. Odpłacając
się za pełną galanterii i dowcipu konwersację, którą zapełniał im pustkę
wieczorów - dziewczęta pozwalały zapalonemu badaczowi studiować
strukturę swych szczupłych i tandetnych ciałek. Działo się to w toku
konwersacji, z powagą i wytwornością, która najryzykowniejszym punktom
tych badań odbierała dwuznaczny ich pozór. Odsuwając pończoszkę z kolana
Pauliny i studiując rozmiłowanymi oczyma zwięzłą i szlachetną
konstrukcję przegubu, ojciec mój mówił: - Jakże pełna uroku i jak
szczęśliwa jest forma bytu, którą panie obrały. Jakże piękna i prosta
jest teza, którą dano wam swym życiem ujawnić. Lecz za to z jakim
mistrzostwem, z jaką finezją wywiązują się panie z tego zadania. Gdybym
odrzucając respekt przed Stwórcą, chciał się zabawić w krytykę
stworzenia, wołałbym: - mniej treści, więcej formy! Ach, jakby ulżył
światu ten ubytek treści. Więcej skromności w zamierzeniach, więcej
wstrzemięźliwości w pretensjach - panowie demiurdzy - a świat byłby
doskonalszy! - wołał mój ojciec akurat w momencie, gdy dłoń jego
wyłuskiwała białą łydkę Pauliny z uwięzi pończoszki. W tej chwili Adela
stanęła w otwartych drzwiach jadalni, niosąc tacę z podwieczorkiem. Było
to pierwsze spotkanie dwu tych wrogich potęg od czasu wielkiej rozprawy.
My wszyscy, którzy asystowaliśmy przy tym spotkaniu, przeżyliśmy chwilę
wielkiej trwogi. Było nam nadwyraz przykro być świadkami nowego
upokorzenia i tak już ciężko doświadczonego męża. Mój ojciec powstał z
klęczek bardzo zmieszany, falą po fali zabarwiała się jego twarz coraz
ciemniej napływem wstydu. Ale Adela znalazła się niespodzianie na
wysokości sytuacji. Podeszła z uśmiechem do ojca i dała mu prztyczka w
nos. Na to hasło Polda i Paulina klasnęły rado-śnie w dłonie, zatupotały
nóżkami i uwiesiwszy się z obu stron u ramion ojca, obtańczyły z nim
stół dookoła. W ten sposób, dzięki dobremu sercu dziewcząt, rozwiał się
zarodek przykrego konfliktu w ogólnej wesołości. Oto jest początek
wielce ciekawych i dziwnych prelekcji, które mój ojciec, natchniony
urokiem tego małego i niewinnego audytorium, odbywał w następnych
tygodniach owej wczesnej zimy. Jest godne uwagi, jak w zetknięciu z
niezwykłym tym człowiekiem rzeczy wszystkie cofały się niejako do
korzenia swego bytu, odbudowywały swe zjawisko aż do metafizycznego
jądra, wracały niejako do pierwotnej idei, ażeby w tym punkcie
sprzeniewierzyć się jej i przechylić w te wątpliwe, ryzykowne i
dwuznaczne regiony, które nazwiemy tu krótko regionami wielkiej herezji.
Nasz herezjarcha szedł wśród rzeczy jak magnetyzer, zarażając je i
uwodząc swym niebezpiecznym czarem. Czy mam nazwać i Paulinę jego
ofiarą? Stała się ona w owych dniach jego uczennicą, adeptką jego
teoryj, modelem jego eksperymentów. Tutaj postaram się wyłożyć z
należytą ostrożnością, i unikając zgorszenia, tę nader kacerską
doktrynę, która opętała wówczas na długie miesiące mego ojca i opanowała
wszystkie jego poczynania.

TRAKTAT O MANEKINACH ALBO WTÓRA KSIĘGA RODZAJU Demiurgos - mówił mój
ojciec - nie posiadł monopolu na tworzenie - tworzenie jest przywilejem
wszystkich duchów. Materii dana jest nieskończona płodność,
niewyczerpana moc życiowa i zarazem uwodna siła pokusy, która nas nęci
do formowania. W głębi materii kształtują się niewyraźne uśmiechy,
zawiązują się napięcia, zgęszczają się próby kształtów. Cała materia
faluje od nieskończonych możliwości, które przez nią przechodzą mdłymi
dreszczami. Czekając na ożywcze tchnienie ducha, przelewa się ona w
sobie bez końca, kusi tysiącem słodkich okrąglizn i miękkości, które z
siebie w ślepych rojeniach wymajacza. Pozbawiona własnej inicjatywy,
lubieżnie podatna, po kobiecemu plastyczna, uległa wobec wszystkich
impulsów - stanowi ona teren wyjęty spod prawa, otwarty dla wszelkiego
rodzaju szarlatanerii i dyletantyzmów, domenę wszelkich nadużyć i
wątpliwych manipulacji demiurgicznych. Materia jest najbierniejszą i
najbezbronniejszą istotą w kosmosie. Każdy może ją ugniatać, formować,
każdemu jest posłuszna. Wszystkie organizacje materii są nietrwałe i
luźne, łatwe do uwstecznienia i rozwiązania. Nie ma żadnego zła w
redukcji życia do form innych i nowych. Zabójstwo nie jest grzechem.
Jest ono nieraz koniecznym gwałtem wobec opornych i skostniałych form
bytu, które przestały być zajmujące. W interesie ciekawego i ważnego
eksperymentu może ono nawet stanowić zasługę. Tu jest punkt wyjścia dla
nowej apologii sadyzmu. Mój ojciec był niewyczerpany w gloryfikacji tego
przedziwnego elementu, jakim była materia. - Nie ma materii martwej - 
nauczał - martwota jest jedynie pozorem, za którym ukrywają się nieznane
formy życia. Skala tych form jest nieskończona, a odcienie i niuanse
niewyczerpane. Demiurgos był w posiadaniu ważnych i ciekawych recept
twórczych. Dzięki nim stworzył on mnogość rodzajów, odnawiających się
własną siłą. Nie wiadomo, czy recepty te kiedykolwiek zostaną
zrekonstruowane. Ale jest to niepotrzebne, gdyż jeśliby nawet te
klasyczne metody kreacji okazały się raz na zawsze niedostępne,
pozostają pewne metody illegalne, cały bezmiar metod heretyckich i
występnych. W miarę jak ojciec od tych ogólnych zasad kosmogonii zbliżał
się do terenu swych ciaśniejszych zainteresowań, głos jego zniżał się do
wnikliwego szeptu, wykład stawał się coraz trudniejszy i zawilszy, a
wyniki, do których dochodził, gubiły się w coraz bardziej wątpliwych i
ryzykownych regionach. Gestykulacja jego nabierała ezoterycznej
solenności. Przymykał jedno oko, przykładał dwa palce do czoła, chytrość
jego spojrzenia stawała się wprost niesamowita. Wwiercał się tą
chytrością w swe interlokutorki, gwałcił cynizmem tego spojrzenia
najwstydliwsze, najintymniejsze w nich rezerwy i dosięgał wymykające się
w najgłębszym zakamarku, przypierał do ściany i łaskotał, drapał
ironicznym palcem, póki nie dołaskotał się błysku zrozumienia i śmiechu,
śmiechu przyznania i porozumienia się, którym w końcu musiało się
kapitulować. Dziewczęta siedziały nieruchomo, lampa kopciła, sukno pod
igłą maszyny dawno się zsunęło, a maszyna stukotała pusto, stębnując
czarne, bezgwiezdne sukno, odwijające się z postawu nocy zimowej za
oknem. - Zbyt długo żyliśmy pod terrorem niedościgłej doskonałości
Demiurga - mówił mój ojciec - zbyt długo doskonałość jego tworu
paraliżowała naszą własną twórczość. Nie chcemy z nim konkurować. Nie
mamy ambicji mu dorównać. Chcemy być twórcami we własnej, niższej
sferze, pragniemy dla siebie twórczości, pragniemy rozkoszy twórczej,
pragniemy - jednym słowem - demiurgii. - Nie wiem, w czyim imieniu
proklamował mój ojciec te postulaty, jaka zbiorowość, jaka korporacja,
sekta czy zakon, nadawała swą solidarnością patos jego słowom. Co do
nas, to byliśmy dalecy od wszelkich zakusów demłurgicznych. Lecz ojciec
mój rozwinął tymczasem program tej wtórej demiurgii, obraz tej drugiej
generacji stworzeń, która stanąć miała w otwartej opozycji do panującej
epoki. - Nie zależy nam - mówił on - na tworach o długim oddechu, na
istotach na daleką metę. Nasze kreatury nie będą bohaterami romansów w
wielu tomach. Ich role będą krótkie, lapidarne, ich charaktery - bez
dalszych planów. Często dla jednego gestu, dla jednego słowa podejmiemy
się trudu powołania ich do życia na tę jedną chwilę. Przyznajemy
otwarcie: nie będziemy kładli nacisku na trwałość ani solidność
wykonania, twory nasze będą jak gdyby prowizoryczne, na jeden raz
zrobione. Jeśli będą to ludzie, to damy im na przykład tylko jedną
stronę twarzy, jedną rękę, jedną nogę, tę mianowicie, która im będzie w
ich roli potrzebna. Byłoby pedanterią troszczyć się o ich drugą, nie
wchodzącą w grę nogę. Z tyłu mogą być po prostu zaszyte płótnem lub
pobielone. Naszą ambicję pokładać będziemy w tej dumnej dewizie: dla
każdego gestu inny aktor. Do obsługi każdego słowa, każdego czynu
powołamy do życia innego człowieka. Taki jest nasz smak, to będzie świat
według naszego gustu. Demiurgos kochał się w wytrawnych, doskonałych i
skomplikowanych materiałach, my dajemy pierwszeństwo tandecie. Po prostu
porywa nas, zachwyca taniość, lichota, tandetność materiału. Czy
rozumiecie - pytał mój ojciec - głęboki sens tej słabości, tej pasji do
pstrej bibułki, do papier mâ ché , do lakowej farby, do kłaków i
trociny? To jest - mówił z bolesnym uśmiechem - nasza miłość do materii
jako takiej, do jej puszystości i porowatości, do jej jedynej,
mistycznej konsystencji. Demiurgos, ten wielki mistrz i artysta, czyni
ją niewidzialną, każe jej zniknąć pod grą życia. My, przeciwnie, kochamy
jej zgrzyt, jej oporność, jej pałubiastą niezgrabność. Lubimy pod każdym
gestem, pod każdym ruchem widzieć jej ociężały wysiłek, jej bezwład, jej
słodką niedźwiedziowatość. Dziewczęta siedziały nieruchomo z szklanymi
oczyma. Twarze ich były wyciągnięte i zgłupiałe zasłuchaniem, policzki
podmalowane wypiekami, trudno było w tej chwili ocenić, czy należą do
pierwszej, czy do drugiej generacji stworzenia. - Słowem - konkludował
mój ojciec - chcemy stworzyć po raz wtóry człowieka, na obraz i
podobieństwo manekinu. Tu musimy dla wierności sprawozdawczej opisać
pewien drobny i błahy incydent, który zaszedł w tym punkcie prelekcji i
do którego nie przywiązujemy żadnej wagi. Incydent ten, całkowicie
niezrozumiały i bezsensowny w tym danym szeregu zdarzeń, da się chyba
wytłumaczyć jako pewnego rodzaju automatyzm szczątkowy, bez antecedensów
i bez ciągłości, jako pewnego rodzaju złośliwość obiektu, przeniesiona w
dziedzinę psychiczną. Radzimy czytelnikowi zignorować go z równą
lekkomyślnością, jak my to czynimy. Oto jego przebieg: W chwili gdy mój
ojciec wymawiał słowo „manekin”, Adela spojrzała na zegarek na
bransoletce, po czym porozumiała się spojrzeniem z Poldą. Teraz wysunęła
się wraz z krzesłem o piędź naprzód, podniosła brzeg sukni, wystawiła
powoli stopę, opiętą w czarny jedwab, i wyprężyła ją jak pyszczek węża.
Tak siedziała przez cały czas tej sceny, całkiem sztywno, z wielkimi,
trzepoczącymi oczyma, pogłębionymi lazurem atropiny, z Poldą i Paulina
po obu bokach. Wszystkie trzy patrzyły rozszerzonymi oczami na ojca. Mój
ojciec chrząknął, zamilkł, pochylił się i stał się nagle bardzo
czerwony. W jednej chwili lineatura jego twarzy, dopiero co tak
rozwichrzona i pełna wibracji, zamknęła się na spokorniałych rysach. On
- herezjarcha natchniony, ledwo wypuszczony z wichru uniesienia - złożył
się nagle w sobie, zapadł i zwinął. A może wymieniono go na innego. Ten
inny siedział sztywny, bardzo czerwony, ze spuszczonymi oczyma. Panna
Polda podeszła i pochyliła się nad nim. Klepiąc go lekko po plecach,
mówiła tonem łagodnej zachęty: - Jakub będzie rozsądny, Jakub posłucha,
Jakub nie będzie uparty. No, proszę... Jakub, Jakub... Wypięty
pantofelek Adeli drżał lekko i błyszczał jak języczek węża. Mój ojciec
podniósł się powoli ze spuszczonymi oczyma, postąpił krok naprzód, jak
automat, i osunął się na kolana. Lampa syczała w ciszy, w gęstwinie
tapet biegły tam i z powrotem wymowne spojrzenia, leciały szepty
jadowitych języków, gzygzaki myśli...

TRAKTAT O MANEKINACH Ciąg dalszy Następnego wieczora ojciec podjął z
odnowioną swadą ciemny i zawiły swój temat. Lineatura jego zmarszczek
rozwijała się i zawijała z wyrafinowaną chytrością. W każdej spirali
ukryty był pocisk ironii. Ale czasami inspiracja rozszerzała kręgi jego
zmarszczek, które rosły jakąś ogromną wirującą grozą, uchodząc w
milczących wolutach w głąb nocy zimowej. - Figury panopticum, moje panie
- zaczął on - kalwaryjskie parodie manekinów, ale nawet w tej postaci
strzeżcie się lekko je traktować. Materia nie zna żartów. Jest ona
zawsze pełna tragicznej powagi. Kto ośmiela się myśleć, że można igrać z
materią, że kształtować ją można dla żartu, że żart nie wrasta w nią,
nie wżera się natychmiast jak los, jak przeznaczenie? Czy przeczuwacie
ból, cierpienie głuche, nie wyzwolone, zakute w materię cierpienie tej
pałuby, która nie wie, czemu nią jest, czemu musi trwać w tej gwałtem
narzuconej formie, będącej parodią? Czy pojmujecie potęgę wyrazu, formy,
pozoru, tyrańską samowolę, z jaką rzuca się on na bezbronną kłodę i
opanowuje, jak własna, tyrańska, panosząca się dusza? Nadajecie jakiejś
głowie z kłaków i płótna wyraz gniewu i pozostawiacie ją z tym gniewem,
z tą konwulsją, z tym napięciem raz na zawsze, zamkniętą ze ślepą
złością, dla której nie ma odpływu. Tłum śmieje się z tej parodii.
Płaczcie, moje panie, nad losem własnym, widząc nędzę materii więzionej,
gnębionej materii, która nie wie, kim jest i po co jest, dokąd prowadzi
ten gest, który jej raz na zawsze nadano. Tłum śmieje się. Czy
rozumiecie straszny sadyzm, upajające, demiurgiczne okrucieństwo tego
śmiechu? Bo przecież płakać nam, moje panie, trzeba nad losem własnym na
widok tej nędzy materii, gwałconej materii, na której dopuszczono się
strasznego bezprawia. Stąd płynie, moje panie, straszny smutek
wszystkich błazeńskich golemów, wszystkich pałub, zadumanych tragicznie
nad śmiesznym swym grymasem. Oto jest anarchista Luccheni, morderca
cesarzowej Elżbiety, oto Draga, demoniczna i nieszczęśliwa królowa
Serbii, oto genialny młodzieniec, nadzieja i duma rodu, którego zgubił
nieszczęsny nałóg onanii. O, ironio tych nazw, tych pozorów! Czy jest w
tej pałubie naprawdę coś z królowej Dragi, jej sobowtór, najdalszy bodaj
cień jej istoty? To podobieństwo, ten pozór, ta nazwa uspokaja nas i nie
pozwala nam pytać, kim jest dla siebie samego ten twór nieszczęśliwy. A
jednak to musi być ktoś, moje panie, ktoś anonimowy, ktoś groźny, ktoś
nieszczęśliwy, ktoś, co nie słyszał nigdy w swym głuchym życiu o
królowej Dradze... Czy słyszeliście po nocach straszne wycie tych pałub
woskowych, zamkniętych w budach jarmarcznych, żałosny chór tych kadłubów
z drzewa i porcelany, walących pięściami w ściany swych więzień? W
twarzy mego ojca, rozwichrzonej grozą spraw, które wywołał z ciemności,
utworzył się wir zmarszczek, lej rosnący w głąb, na którego dnie gorzało
groźne oko prorocze. Broda jego zjeżyła się dziwnie, wiechcie i pędzle
włosów, strzelające z brodawek, z pieprzów, z dziurek od nosa,
nastroszyły się na swych korzonkach. Tak stał drętwy, z gorejącymi
oczyma, drżąc od wewnętrznego wzburzenia, jak automat, który zaciął się
i zatrzymał na martwym punkcie. Adela wstała z krzesła i poprosiła nas o
przymknięcie oczu na to, co się za chwilę stanie. Potem podeszła do ojca
i z rękoma na biodrach, przybierając pozór podkreślonej stanowczości,
zażądała bardzo dobitnie... Panienki siedziały sztywno, ze spuszczonymi
oczyma, w dziwnej drętwości...

TRAKTAT O MANEKINACH Dokończenie Któregoś z następnych wieczorów ojciec
mój w te słowa ciągnął dalej swą prelekcję: - Nie o tych
nieporozumieniach ucieleśnionych, nie o tych smutnych parodiach, moje
panie, owocach prostackiej i wulgarnej niepowściągliwości - chciałem
mówić zapowiadając mą rzecz o manekinach. Miałem na myśli coś innego. Tu
ojciec mój zaczął budować przed naszymi oczyma obraz tej wymarzonej
przez niego „generaiio aequivoca”, jakiegoś pokolenia istot na wpół
tylko organicznych, jakiejś pseudowegetacji i pseudofauny, rezultatów
fantastycznej fermentacji materii. Były to twory podobne z pozoru do
istot żywych, do kręgowców, skorupiaków, członkonogów, lecz pozór ten
mylił. Były to w istocie istoty amorfne, bez wewnętrznej struktury,
płody imitatywnej tendencji materii, która obdarzona pamięcią, powtarza
z przyzwyczajenia raz przyjęte kształty. Skala morfologii, której
podlega materia, jest w ogóle ograniczona i pewien zasób form powtarza
się wciąż na różnych kondygnacjach bytu. Istoty te - ruchliwe, wrażliwe
na bodźce, a jednak dalekie od prawdziwego życia - można było otrzymać
zawieszając pewne skomplikowane koloidy w roztworach soli kuchennej.
Koloidy te po kilku dniach formowały się, organizowały w pewne
zagęszczenia substancji przypominającej niższe formy fauny. U istot tak
powstałych można było stwierdzić proces oddychania, przemianę materii,
ale analiza chemiczna nie wykazywała w nich nawet śladu połączeń
białkowych ani w ogóle związków węgla. Wszelako prymitywne te formy były
niczym w porównaniu z bogactwem kształtów i wspaniałości pseudofauny i
flory, która pojawia się niekiedy w pewnych ściśle określonych
środowiskach. Środowiskami tymi są stare mieszkania, przesycone
emanacjami wielu żywotów i zdarzeń - zużyte atmosfery, bogate w
specyficzne ingrediencje marzeń ludzkich - rumowiska, obfitujące w humus
wspomnień, tęsknot, jałowej nudy. Na takiej glebie owa pseudowegetacja
kiełkowała szybko i powierzchownie, pasożytowała obficie i efemerycznie,
pędziła krótkotrwałe generacje, które rozkwitały raptownie i świetnie,
ażeby wnet zgasnąć i zwiędnąć. Tapety muszą być w takich mieszkaniach
już bardzo zużyte i znudzone nieustanną wędrówką po wszystkich
kadencjach rytmów; nic dziwnego, że schodzą na manowce dalekich,
ryzykownych rojeń. Rdzeń mebli, ich substancja musi już być rozluźniona,
zdegenerowana i podległa występnym pokusom: wtedy na tej chorej,
zmęczonej i zdziczałej glebie wykwita, jak piękna wysypka, nalot
fantastyczny, kolorowa, bujająca pleśń. - Wiedzą panie - mówił ojciec
mój - że w starych mieszkaniach bywają pokoje, o których się zapomina.
Nie odwiedzane miesiącami, więdną w opuszczeniu między starymi murami i
zdarza się, że zasklepiają się w sobie, zarastają cegłą i, raz na zawsze
stracone dla naszej pamięci, powoli tracą też swą egzystencję. Drzwi,
prowadzące do nich z jakiegoś podestu tylnych schodów, mogą być tak
dhigo przeoczane przez domowników, aż wrastają, wchodzą w ścianę, która
zaciera ich ślad w fantastycznym rysunku pęknięć i rys. - Wszedłem raz - 
mówił ojciec mój - wczesnym rankiem na schyłku zimy, po wielu miesiącach
nieobecności, do takiego na wpół zapomnianego traktu i zdumiony byłem
wyglądem tych pokojów. Z wszystkich szpar w podłodze, z wszystkich
gzymsów i framug wystrzelały cienkie pędy i napełniały szare powietrze
migotliwą koronką filigranowego listowia, ażurową gęstwiną jakiejś
cieplarni, pełnej szeptów, lśnień, kołysań, jakiejś fałszywej i błogiej
wiosny. Dookoła łóżka, pod wieloramienną lampą, wzdłuż szaf chwiały się
kępy delikatnych drzew, rozpryskiwały w górze w świetliste korony, w
fontanny koronkowego listowia, bijące aż pod malowane niebo sufitu
rozpylonym chlorofilem. W przyspieszonym procesie kwitnienia kiełkowały
w tym listowiu ogromne, białe i różowe kwiaty, pączkowały w oczach,
bujały od środka różowym miąższem i przelewały się przez brzegi, gubiąc
płatki i rozpadając się w prędkim przekwitaniu. - Byłem szczęśliwy - 
mówił mój ojciec - z tego niespodzianego rozkwitu, który napełnił
powietrze migotliwym szelestem, łagodnym szumem, przesypującym się jak
kolorowe confetti przez cienkie rózgi gałązek. Widziałem, jak z drgania
powietrza, z fermentacji zbyt bogatej aury wydziela się i materializuje
to pospieszne kwitnienie, przelewanie się i rozpadanie fantastycznych
oleandrów, które napełniły pokój rzadką, leniwą śnieżycą wielkich,
różowych kiści kwietnych. - Nim zapadł wieczór - kończył ojciec - nie
było już śladu tego świetnego rozkwitu. Cała złudna ta fatamorgana była
tylko mistyfikacją, wypadkiem dziwnej symulacji materii, która podszywa
się pod pozór życia. Ojciec mój był dnia tego dziwnie ożywiony,
spojrzenia jego, chytre, ironiczne spojrzenia, tryskały werwą i humorem.
Potem, nagle poważniejąc, znów rozpatrywał nieskończoną skalę form i
odcieni, jakie przybierała wielokształtna materia. Fascynowały go formy
graniczne, wątpliwe i problematyczne, jak ektoplazma somnambulików,
pseudomateria, emanacja kataleptyczna mózgu, która w pewnych wypadkach
rozrastała się z ust uśpionego na cały stół, napełniała cały pokój, jako
bujająca, rzadka tkanka, astralne ciasto, na pograniczu ciała i ducha. - 
Kto wie - mówił - ile jest cierpiących, okaleczonych, fragmentarycznych
postaci życia, jak sztucznie sklecone, gwoździami na gwałt zbite życie
szaf i stołów, ukrzyżowanego drzewa, cichych męczenników okrutnej
pomysłowości ludzkiej. Straszliwe transplantacje obcych i nienawidzących
się ras drzewa, skucie ich w jedną nieszczęśliwą osobowość. Ile starej,
mądrej męki jest w bejcowanych słojach, żyłach i fladrach naszych
starych, zaufanych szaf. Kto rozpozna w nich stare, zheblowane,
wypolerowane do niepoznaki rysy, uśmiechy, spojrzenia! Twarz mego ojca,
gdy to mówił, rozeszła się zamyśloną lineaturą zmarszczek, stała się
podobna do sęków i słojów starej deski, z której zheblowano wszystkie
wspomnienia. Przez chwilę myśleliśmy, że ojciec popadnie w stan
drętwoty, który nawiedzał go czasem, ale ocknął się nagle, opamiętał i
tak ciągnął dalej: - Dawne, mistyczne plemiona balsamowały swych
umarłych. W ściany ich mieszkań były wprawione, wmurowane ciała, twarze:
w salonie stał ojciec - wypchany, wygarbowana żona-nieboszczka była
dywanem pod stołem. Znałem pewnego kapitana, który miał w swej kajucie
lampę-meluzynę, zrobioną przez malajskich balsamistów z jego
zamordowanej kochanki. Na głowie miała ogromne rogi jelenie. W ciszy
kajuty głowa ta, rozpięta między gałęziami rogów u stropu, powoli
otwierała rzęsy oczu; na rozchylonych ustach lśniła błonka śliny,
pękająca od cichego szeptu. Głowonogi, żółwie i ogromne kraby,
zawieszone na belkach sufitu jako kandelabry i pająki, przebierały w tej
ciszy bez końca nogami, szły i szły na miejscu... Twarz mojego ojca
przybrała naraz wyraz troski i smutku, gdy myśli jego na drogach nie
wiedzieć jakich asocjacji przeszły do nowych przykładów: - Czy mam
przemilczeć - mówił przyciszonym głosem - że brat mój na skutek długiej
i nieuleczalnej choroby zamienił się stopniowo w zwój kiszek gumowych,
że biedna moja kuzynka dniem i nocą nosiła go w poduszkach, nucąc
nieszczęśliwemu stworzeniu nieskończone kołysanki nocy zimowych? Czy
może być coś smutniejszego niż człowiek zamieniony w kiszkę hegarową? Co
za rozczarowanie dla rodziców, co za dezorientacja dla ich uczuć, co za
rozwianie wszystkich nadziei, wiązanych z obiecującym młodzieńcem! A
jednak wierna miłość biednej kuzynki towarzyszyła mu i w tej przemianie.
- Ach! nie mogę już dłużej, nie mogę tego słuchać! - jęknęła Polda
przechylając się na krześle. - Ucisz go, Adelo... Dziewczęta wstały,
Adela podeszła do ojca i wyciągniętym palcem uczyniła ruch zaznaczający
łaskotanie. Ojciec stropił się, zamilkł i zaczął, pełen przerażenia,
cofać się tyłem przed kiwającym się palcem Adeli. Ta szła za nim ciągle,
grożąc mu jadowicie palcem, i wypierała go krok za krokiem z pokoju.
Paulina ziewnęła przeciągając się. Obie z Poldą, wsparte o siebie
ramionami, spojrzały sobie w oczy z uśmiechem.

NEMROD Cały sierpień owego roku przebawiłem się z małym, kapitalnym
pieskiem, który pewnego dnia znalazł się na podłodze naszej kuchni,
niedołężny i piszczący, pachnący jeszcze mlekiem i niemowlęctwem, z nie
uformowanym, okrągławym, drżącym łebkiem, z łapkami jak u kreta
rozkraczonymi na boki i z najdelikatniejszą, mięciutką sierścią. Od
pierwszego wejrzenia zdobyła sobie ta kruszynka życia cały zachwyt, cały
entuzjazm chłopięcej duszy. Z jakiego nieba spadł tak niespodzianie ten
ulubieniec bogów, milszy sercu od najpiękniejszych zabawek? Że też
stare, zgoła nieinteresujące pomywaczki wpadają niekiedy na tak świetne
pomysły i przynoszą z przedmieścia - o całkiem wczesnej,
transcendentalnej porannej godzinie - takiego oto pieska do naszej
kuchni! Ach! było się jeszcze - niestety - nieobecnym, nieurodzonym z
ciemnego łona snu, a już to szczęście ziściło się, już czekało na nas,
niedołężnie leżące na chłodnej podłodze kuchni, nie docenione przez
Adelę i domowników. Dlaczego nie obudzono mnie wcześniej! Talerzyk mleka
na podłodze świadczył o macierzyńskich impulsach Adeli, świadczył
niestety także i o chwilach przeszłości, dla mnie na zawsze straconej, o
rozkoszach przybranego macierzyństwa, w których nie brałem udziału. Ale
przede mną leżała jeszcze cała przyszłość. Jakiż bezmiar doświadczeń,
eksperymentów, odkryć otwierał się teraz! Sekret życia, jego
najistotniejsza tajemnica sprowadzona do tej prostszej, poręczniejszej i
zabawkowej formy odsłaniała się tu nienasyconej ciekawości. Było to
nadwyraz interesujące, mieć na własność taką odrobinkę życia, taką
cząsteczkę wieczystej tajemnicy, w postaci tak zabawnej i nowej,
budzącej nieskończoną ciekawość i respekt sekretny swą obcością,
niespodzianą transpozycją tego samego wątku życia, który i w nas był, na
formę od naszej odmienną, zwierzęcą. Zwierzęta! cel nienasyconej
ciekawości, egzemplifikacje zagadki życia, jakby stworzone po to, by
człowiekowi pokazać człowieka, rozkładając jego bogactwo i komplikację
na tysiąc kalejdoskopowych możliwości, każdą doprowadzoną do jakiegoś
paradoksalnego krańca, do jakiejś wybujałości pełnej charakteru.
Nieobciążone splotem egzotycznych interesów, mącących stosunki
międzyludzkie, otwierało się serce pełne sympatii dla obcych emanacji
wiecznego życia, pełne miłosnej współpracującej ciekawości, która była
zamaskowanym głosem samopoznania. Piesek był aksamitny, ciepły i
pulsujący małym, pospiesznym sercem. Miał dwa miękkie płatki uszu,
niebieskawe, mętne oczka, różowy pyszczek, do którego można było włożyć
palec bez żadnego niebezpieczeństwa, łapki delikatne i niewinne, z
wzruszającą, różową brodaweczką z tyłu, nad stopami przednich nóg.
Właził nimi do miski z mlekiem, żarłoczny i niecierpliwy, chłepcący
napój różowym języczkiem, ażeby po nasyceniu się podnieść żałośnie małą
mordkę z kroplą mleka na brodzie i wycofać się niedołężnie z kąpieli
mlecznej. Chód jego był niezgrabnym toczeniem się, bokiem na ukos w
niezdecydowanym kierunku, po linii trochę pijanej i chwiejnej. Dominantą
jego nastroju była jakaś nieokreślona i zasadnicza żałość, sieroctwo i
bezradność - niezdolność do zapełnienia czymś pustki życia pomiędzy
sensacjami posiłków. Objawiało się to bezplanowością i niekonsekwencją
ruchów, irracjonalnymi napadami nostalgii z żałosnym skomleniem i
niemożnością znalezienia sobie miejsca. Nawet jeszcze w głębi snu, w
którym potrzebę oparcia się i przytulenia zaspokajać musiał używając do
tego własnej swej osoby, zwiniętej w kłębek drżący - towarzyszyło mu
poczucie osamotnienia i bezdomności. Ach, życie - młode i wątłe życie,
wypuszczone z zaufanej ciemności, z przytulnego ciepła łona
macierzystego w wielki i obcy, świetlany świat, jakże kurczy się ono i
cofa, jak wzdraga się zaakceptować tę imprezę, którą mu proponują - 
pełne awersji i zniechęcenia! Lecz zwolna mały Nemrod (otrzymał był to
dumne i wojownicze imię) zaczyna smakować w życiu. Wyłączne opanowanie
obrazem macierzystej prajedni ustępuje urokowi wielości. Świat zaczyna
nań nastawiać pułapki: nieznany a czarujący smak różnych pokarmów,
czworobok porannego słońca na podłodze, na którym tak dobrze jest
położyć się, ruchy własnych członków, własne łapki, ogonek, figlarnie
wyzywający do zabawy z samym sobą, pieszczoty ręki ludzkiej, pod którymi
zwolna dojrzewa pewna swawolność, wesołość rozpierająca ciało i rodząca
potrzebę zgoła nowych, gwałtownych i ryzykownych ruchów - wszystko to
przekupuje, przekonywa i zachęca do przyjęcia, do pogodzenia się z
eksperymentem życia. I jeszcze jedno. Nemrod zaczyna rozumieć, że to, co
mu się tu podsuwa, mimo pozorów nowości jest w gruncie rzeczy czymś, co
już było - było wiele razy - nieskończenie wiele razy. Jego ciało
poznaje sytuacje, wrażenia i przedmioty. W gruncie rzeczy to wszystko
nie dziwi go zbytnio. W obliczu każdej nowej sytuacji daje nura w swoją
pamięć, w głęboką pamięć ciała, i szuka omackiem, gorączkowo - i bywa,
że znajduje w sobie odpowiednią reakcję już gotową: mądrość pokoleń,
złożoną w jego plazmie, w jego nerwach. Znajduje jakieś czyny, decyzje,
o których sam nie wiedział, że już w nim dojrzały, że czekały na to, by
wyskoczyć. Sceneria jego młodego życia, kuchnia z wonnymi cebrami, ze
ścierkami o skomplikowanej i intrygującej woni, z kłapaniem pantofli
Adeli, z jej hałaśliwym krzątaniem się - nie straszy go więcej. Przywykł
uważać ją za swoją domenę, zadomowił się w niej i począł rozwijać w
stosunku do niej niejasne poczucie przynależności, ojczyzny. Chyba że
niespodzianie spadał nań kataklizm w postaci szorowania podłogi - 
obalenie praw natury, chlusty ciepłego ługu, podmywające wszystkie
meble, i groźny szurgot szczotek Adeli. Ale niebezpieczeństwo mija,
szczotka uspokojona i nieruchoma leży cicho w kącie, schnąca podłoga
pachnie miło mokrym drzewem. Nemrod, przywrócony znowu do swych
normalnych praw i do swobody na terenie własnym, czuje żywą ochotę
chwytać zębami stary koc na podłodze i targać nim z całej siły na prawo
i lewo. Pacyfikacja żywiołów napełnia go niewymowną radością. Wtem staje
jak wryty: przed nim, o jakie trzy kroki pieskie, posuwa się czarna
maszkara, potwór sunący szybko na pręcikach wielu pogmatwanych nóg. Do
głębi wstrząśnięty Nemrod posuwa wzrokiem za skośnym kursem błyszczącego
owada, śledząc w napięciu ten płaski, bezgłowy i ślepy kadłub, niesiony
niesamowitą ruchliwością pajęczych nóg. Coś w nim na ten widok wzbiera,
coś dojrzewa, pęcznieje, czego sam jeszcze nie rozumie, niby jakiś gniew
albo strach, lecz raczej przyjemny i połączony z dreszczem siły,
samopoczucia, agresywności. I nagle opada na przednie łapki i wyrzuca z
siebie głos, jeszcze jemu samemu nie znany, obcy, całkiem niepodobny do
zwykłego kwilenia. Wyrzuca go z siebie raz, i jeszcze raz, i jeszcze,
cienkim dyszkantem, który się co chwila wykoleja. Ale nadaremnie
apostrofuje owada w tym nowym, z nagłego natchnienia zrodzonym języku. W
kategoriach umysłu karakoniego nie ma miejsca na tę tyradę i owad odbywa
dalej swą skośną turę ku kątowi pokoju, wśród ruchów uświęconych
odwiecznym karakonim rytuałem. Wszelako uczucia nienawiści nie mają
jeszcze trwałości i mocy w duszy pieska. Nowoobudzona radość życia
przeistacza każde uczucie w wesołość. Nemrod szczeka jeszcze, lecz sens
tego szczekania zmienił się niepostrzeżenie, stało się ono swoją własną
parodią - pragnąc w gruncie rzeczy wysłowić niewymowną udatność tej
świetnej imprezy życia, pełnej pikanterii, niespodzianych dreszczyków i
point.

PAN W kącie między tylnymi ścianami szop i przybudówek był zaułek
podwórza, najdalsza, ostatnia odnoga, zamknięta między komorę, wychodek
i tylną ścianę kurnika - głucha zatoka, poza którą nie było już wyjścia.
Był to najdalszy przylądek, Gibraltar tego podwórza, bijący rozpaczliwie
głową w ślepy parkan z poziomych desek, zamykającą i ostateczną ścianę
tego świata. Spod jego omszonych dyli wyciekała strużka czarnej,
śmierdzącej wody, żyła gnijącego, tłustego błota, nigdy nie wysychająca
- jedyna droga, która poprzez granice parkanu wyprowadzała w świat. Ale
rozpacz smrodliwego zaułka tak długo biła głową w tę zaporę, aż
rozluźniła jedną z poziomych, potężnych desek. My, chłopcy, dokonaliśmy
reszty i wyważyli, wysunęli ciężką omszałą deskę z osady. Tak zrobiliśmy
wyłom, otworzyliśmy okno na słońce. Stanąwszy nogą na desce, rzuconej
jak most przez kałużę, mógł więzień podwórza w poziomej pozycji
przecisnąć się przez szparę, która wypuszczała go w nowy, przewiewny i
rozległy świat. Był tam wielki, zdziczały stary ogród. Wysokie grusze,
rozłożyste jabłonie rosły tu z rzadka potężnymi grupami, obsypane
srebrnym szelestem, kipiącą siatką białawych połysków. Bujna, zmieszana,
nie koszona trawa pokrywała puszystym kożuchem falisty teren. Były tam
zwykłe, trawiaste źdźbła łąkowe z pierzastymi kitami kłosów; były
delikatne filigrany dzikich pietruszek i marchwi; pomarszczone i
szorstkie listki bluszczyków i ślepych pokrzyw, pachnące miętą;
łykowate, błyszczące babki, nakrapiane rdzą, wystrzelające kiśćmi
grubej, czerwonej kaszy. Wszystko to, splątane i puszyste, przepojone
było łagodnym powietrzem, podbite błękitnym wiatrem i napuszczone
niebem. Gdy się leżało w trawie, było się przykrytym całą błękitną
geografią obłoków i płynących kontynentów, oddychało się całą rozległą
mapą niebios. Od tego obcowania z powietrzem liście i pędy pokryły się
delikatnymi włoskami, miękkim nalotem puchu, szorstką szczeciną haczków,
jak gdyby dla chwytania i zatrzymywania przepływów tlenu. Ten nalot
delikatny i białawy spokrewniał liście z atmosferą, dawał im srebrzysty,
szary połysk fal powietrznych, cienistych zadumań między dwoma błyskami
słońca. A jedna z tych roślin, żółta i pełna mlecznego soku w bladych
łodygach, nadęta powietrzem, pędziła ze swych pustych pędów już samo
powietrze, sam puch w kształcie pierzastych kul mleczowych rozsypywanych
przez powiew i wsiąkających bezgłośnie w błękitną ciszę. Ogród był
rozległy i rozgałęziony kilku odnogami i miał różne strefy i klimaty. W
jednej stronie był otwarty, pełen mleka niebios i powietrza, i tam
podścielał niebu co najmiększą, najdelikatniejszą, najpuszystszą zieleń.
Ale w miarę jak opadał w głąb długiej odnogi i zanurzał się w cień
między tylną ścianę opuszczonej fabryki wody sodowej, wyraźnie
pochmurniał, stawał się opryskliwy i niedbały, zapuszczał się dziko i
niechlujnie, srożył się pokrzywami, zjeżał bodiakami, parszywiał
chwastem wszelkim, aż w samym końcu między ścianami, w szerokiej
prostokątnej zatoce tracił wszelką miarę i wpadał w szał. Tam to nie był
już sad, tylko paroksyzm szaleństwa, wybuch wściekłości, cyniczny
bezwstyd i rozpusta. Tam, rozbestwione, dając upust swej pasji,
panoszyły się puste, zdziczałe kapusty łopuchów - ogromne wiedźmy,
rozdziewające się w biały dzień ze swych szerokich spódnic, zrzucając je
z siebie, spódnica za spódnicą, aż ich wzdęte, szelestne, dziurawe
łachmany oszalałymi płatami grzebały pod sobą kłótliwe to plemię
bękarcie. A żarłoczne spódnice puchły i rozpychały się, piętrzyły się
jedne na drugich, rozpierały i nakrywały wzajem, rosnąc razem wzdętą
masą blach listnych, aż pod niski okap stodoły. Tam to było, gdziem go
ujrzał jedyny raz w życiu, o nieprzytomnej od żaru godzinie południa.
Była to chwila, kiedy czas, oszalały i dziki, wyłamuje się z kieratu
zdarzeń i jak zbiegły włóczęga pędzi z krzykiem na przełaj przez pola.
Wtedy lato, pozbawione kontroli, rośnie bez miary i rachuby na całej
przestrzeni, rośnie z dzikim impetem na wszystkich punktach, w
dwójnasób, w trójnasób, w inny jakiś, wyrodny czas, w nieznaną dymensję,
w obłęd. O tej godzinie opanowywał mnie szał łowienia motyli, pasja
ścigania tych migocących plamek, tych błędnych, białych płatków,
trzęsących się w rozognionym powietrzu niedołężnym gzygzakiem. I
zdarzyło się wówczas, że któraś z tych jaskrawych plamek rozpadła się w
locie na dwie, potem na trzy - i ten drgający, oślepiająco biały
trójpunkt wiódł mnie, jak błędny ognik, przez szał bodiaków, palących
się w słońcu. Dopiero na granicy łopuchów zatrzymałem się, nie śmiejąc
się pogrążyć w to głuche zapadlisko. Wtedy nagle ujrzałem go. Zanurzony
po pachy w łopuchach, kucał przede mną. Widziałem jego grube bary w
brudnej koszuli i niechlujny strzęp surduta. Przyczajony jak do skoku,
siedział tak - z barami jakby wielkim ciężarem zgarbionymi. Ciało jego
dyszało z natężenia, a z miedzianej, błyszczącej w słońcu twarzy lał się
pot. Nieruchomy, zdawał się ciężko pracować, mocować się bez ruchu z
jakimś ogromnym brzemieniem. Stałem, przygwożdżony jego wzrokiem, który
mnie ujął jakby w kleszcze. Była to twarz włóczęgi lub pijaka. Wiecheć
brudnych kłaków wichrzył się nad czołem wysokim i wypukłym jak buła
kamienna, utoczona przez rzekę. Ale czoło to było skręcone w głębokie
bruzdy. Nie wiadomo, czy ból, czy palący żar słońca, czy nadludzkie
natężenie wkręciło się tak w tę twarz i napięło rysy do pęknięcia.
Czarne oczy wbiły się we mnie z natężeniem najwyższej rozpaczy czy bólu.
Te oczy patrzyły na mnie i nie patrzyły, widziały mnie i nie widziały
wcale. Były to pękające gałki, wytężone najwyższym uniesieniem bólu albo
dziką rozkoszą natchnienia. I nagle z tych rysów, naciągniętych do
pęknięcia, wyboczył się jakiś straszny, załamany cierpieniem grymas i
ten grymas rósł, brał w siebie tamten obłęd i natchnienie, pęczniał nim,
wybaczał się coraz bardziej, aż wyłamał się ryczącym, charczącym kaszlem
śmiechu. Do głębi wstrząśnięty, widziałem, jak hucząc śmiechem z
potężnych piersi, dźwignął się powoli z kucek i zgarbiony jak goryl, z
rękoma w opadających łachmanach spodni, uciekał, człapiąc przez łopocące
blachy łopuchów, wielkimi skokami - Pan bez fletu, cofający się w
popłochu do swych ojczystych kniei.

PAN KAROL Po południu w sobotę mój wuj, Karol, wdowiec słomiany,
wybierał się pieszo do letniska, oddalonego o godzinę drogi od miasta,
do żony i dzieci, które tam na wywczasach bawiły. Od czasu wyjazdu żony
mieszkanie było nie sprzątane, łóżko nie zaścielane nigdy. Pan Karol
przychodził do mieszkania późną nocą, sponiewierany, spustoszony przez
nocne pohulanki, przez które go wlokły te dni upalne i puste. Zmięta,
chłodna, dziko rozrzucona pościel była dlań wówczas jakąś błogą
przystanią, wyspą zbawczą, do której przypadał ostatkiem sił jak
rozbitek, miotany wiele dni i nocy przez wzburzone morze. Omackiem, w
ciemności zapadał się gdzieś między białawe chmury, pasma i zwały
chłodnego pierza i spał tak w niewiadomym kierunku, na wspak, głową na
dół, wbity ciemieniem w puszysty miąższ pościeli, jak gdyby chciał we
śnie przewiercić, przewędrować na wskroś te rosnące nocą, potężne masywy
pierzyn. Walczył we śnie z tą pościelą, jak pływak z wodą, ugniatał ją i
miesił ciałem, jak ogromną dzieżę ciasta, w którą się zapadał, i budził
się o szarym świcie zdyszany, oblany potem, wyrzucony na brzeg tego
stosu pościeli, którego zmóc nie mógł w ciężkich zapasach nocnych. Tak
na wpół wyrzucony z toni snu, wisiał przez chwilę nieprzytomny na
krawędzi nocy, chwytając piersiami powietrze, a pościel rosła dokoła
niego, puchła i nakisała - i zarastała go znowu zwałem ciężkiego,
białawego ciasta. Spał tak do późnego przedpołudnia, podczas gdy
poduszki układały się w wielką, białą, płaską równinę, po której
wędrował uspokojony sen jego. Tymi białymi gościńcami powracał powoli do
siebie, do dnia, do jawy - i wreszcie otwierał oczy, jak śpiący pasażer,
gdy pociąg zatrzymuje się na stacji. W pokoju panował odstały półmrok z
osadem wielu dni samotności i ciszy. Tylko okno kipiało od rannego
rojowiska much i story płonęły jaskrawo. Pan Karol wyziewał ze swego
ciała, z głębi jam cielesnych, resztki dnia wczorajszego. To ziewanie
chwytało go tak konwulsyjnie, jak gdyby chciało go odwrócić na nice. Tak
wyrzucał z siebie ten piasek, te ciężary - nie strawione restancje dnia
wczorajszego. Ulżywszy sobie w ten sposób, i swobodniejszy, wciągał do
notesu wydatki, kalkulował, obliczał i marzył. Potem leżał długo
nieruchomy, z szklanymi oczyma, które były koloru wody, wypukłe i
wilgotne. W wodnistym półmroku pokoju, rozjaśnionym refleksem dnia
upalnego za storami, oczy jego jak maleńkie lusterka odbijały wszystkie
błyszczące przedmioty: białe plamy słońca w szparach okna, złoty
prostokąt stor, i powtarzały, jak kropla wody, cały pokój z ciszą
dywanów i pustych krzeseł. Tymczasem dzień za storami huczał coraz
płomienniej bzykaniem much oszalałych od słońca. Okno nie mogło
pomieścić tego białego pożaru i story omdlewały od jasnych falowań.
Wtedy wywlekał się z pościeli i siedział jeszcze jakiś czas na łóżku,
stękając bezwiednie. Jego trzydziestokilkoletnie ciało zaczynało
skłaniać się do korpulencji. W tym organizmie, nabrzmiewającym
tłuszczem, znękanym od nadużyć płciowych, ale wciąż wzbierającym bujnymi
sokami, zdawał się teraz zwolna dojrzewać w tej ciszy jego przyszły los.
Gdy tak siedział w bezmyślnym, wegetatywnym osłupieniu, cały zamieniony
w krążenie, w respirację, w głębokie pulsowanie soków, rosła w głębi
jego ciała, spoconego i pokrytego włosem w rozlicznych miejscach, jakaś
niewiadoma, nie sformułowana przyszłość, niby potworna narośl,
wyrastająca fantastycznie w nieznaną dymensję. Nie przerażał się jej,
gdyż czuł już swoją tożsamość z tym niewiadomym a ogromnym, które miało
nadejść, i rósł razem z nim bez sprzeciwu, w dziwnej zgodzie, zdrętwiały
spokojną grozą, odpoznając przyszłego siebie w tych kolosalnych
wykwitach, w tych fantastycznych spiętrzeniach, które przed jego
wzrokiem wewnętrznym dojrzewały. Jedno jego oko lekko wtedy zbaczało na
zewnątrz, jak gdyby odchodziło w inny wymiar. Potem z tych bezmyślnych
otumanieni z tych zatraconych dali powracał znów do siebie i do chwili;
widział swe stopy na dywanie, tłuste i delikatne jak u kobiety, i powoli
wyjmował złote spinki z mankietów dziennej koszuli. Potem szedł do
kuchni i znajdował tam w cienistym kącie wiaderko z wodą, krążek
cichego, czujnego zwierciadła, które nań tam czekało - jedyna żywa i
wiedząca istota w tym pustym mieszkaniu. Nalewał do miednicy wody i
kosztował skórą jej młodej i odstałej, słodkawej mokrości. Długo i
starannie robił toaletę, nie spiesząc się i włączając pauzy między
poszczególne manipulacje. To mieszkanie, puste i zapuszczone, nie
uznawało go, te meble i ściany śledziły za nim z milczącą krytyką. Czuł
się, wchodząc w ich ciszę, jak intruz w tym podwodnym, zatopionym
królestwie, w którym płynął inny, odrębny czas. Otwierając własne
szuflady, miał uczucie złodzieja i chodził mimo woli na palcach, bojąc
się obudzić hałaśliwe i nadmierne echo, czekające drażliwie na
najlżejszą przyczynę, by wybuchnąć. A gdy wreszcie, idąc cicho od szafy
do szafy, znajdował kawałek po kawałku wszystko potrzebne i kończył
toaletę wśród tych mebli, które tolerowały go w milczeniu, z nieobecną
miną, i wreszcie był gotów, to stojąc na odejściu z kapeluszem w ręku,
czuł się zażenowany, że i w ostatniej chwili nie mógł znaleźć słowa,
które by rozwiązało to wrogie milczenie, i odchodził ku drzwiom
zrezygnowany, zwolna, ze spuszczoną głową - gdy w przeciwną stronę
oddalał się tymczasem bez pośpiechu - w głąb zwierciadła - ktoś
odwrócony na zawsze plecami - przez pustą amfiladę pokojów, które nie
istniały.

SKLEPY CYNAMONOWE W okresie najkrótszych, sennych dni zimowych, ujętych
z obu stron, od poranku i od wieczora, w futrzane krawędzie zmierzchów,
gdy miasto rozgałęziało się coraz głębiej w labirynty zimowych nocy, z
trudem przywoływane przez krótki świt do opamiętania, do powrotu - 
ojciec mój był już zatracony, zaprzedany, zaprzysiężony tamtej sferze.
Twarz jego i głowa zarastały wówczas bujnie i dziko siwym włosem,
sterczącym nieregularnie wiechciami, szczecinami, długimi pędzlami,
strzelającymi z brodawek, z brwi, z dziurek od nosa - co nadawało jego
fizjonomii wygląd starego, nastroszonego lisa. Węch jego i słuch
zaostrzał się niepomiernie i znać było po grze jego milczącej i napiętej
twarzy, że za pośrednictwem tych zmysłów pozostaje on w ciągłym
kontakcie z niewidzialnym światem ciemnych zakamarków, dziur mysich,
zmurszałych przestrzeni pustych pod podłogą i kanałów kominowych.
Wszystkie chroboty, trzaski nocne, tajne, skrzypiące życie podłogi miały
w nim nieomylnego i czujnego dostrzegacza, szpiega i współspiskowca.
Absorbowało go to w tym stopniu, że pogrążał się zupełnie w tej
niedostępnej dla nas sferze, z której nie próbował zdawać nam sprawy.
Nieraz musiał strzepywać palcami i śmiać się cicho do siebie samego, gdy
te wybryki niewidzialnej sfery stawały się zbyt absurdalne; porozumiewał
się wówczas spojrzeniem z naszym kotem, który również wtajemniczony w
ten świat, podnosił swą cyniczną, zimną, porysowaną pręgami twarz,
mrużąc z nudów i obojętności skośne szparki oczu. Zdarzało się podczas
obiadu, że wśród jedzenia odkładał nagle nóż i widelec i z serwetą
zawiązaną pod szyją podnosił się kocim ruchem, skradał na brzuścach
palców do drzwi sąsiedniego, pustego pokoju i z największą ostrożnością
zaglądał przez dziurkę od klucza. Potem wracał do stołu, jakby
zawstydzony, z zakłopotanym uśmiechem, wśród mruknięć i niewyraźnych
mamrotań, odnoszących się do wewnętrznego monologu, w którym był
pogrążony. Ażeby mu sprawić pewną dystrakcję i oderwać go od
chorobliwych dociekań, wyciągała go matka na wieczorne spacery, na które
szedł, milcząc, bez oporu, ale i bez przekonania, roztargniony i
nieobecny duchem. Raz nawet poszliśmy do teatru. Znaleźliśmy się znowu w
tej wielkiej, źle oświetlonej i brudnej sali, pełnej sennego gwaru
ludzkiego i bezładnego zamętu. Ale gdy przebrnęliśmy przez ciżbę ludzką,
wynurzyła się przed nami olbrzymia bladomebieska kurtyna, jak niebo
jakiegoś innego firmamentu. Wielkie, malowane maski różowe, z wydętymi
policzkami, nurzały się w ogromnym płóciennym przestworzu. To sztuczne
niebo szerzyło się i płynęło wzdłuż i w poprzek, wzbierając ogromnym
tchem patosu i wielkich gestów, atmosferą tego świata sztucznego i
pełnego blasku, który budował się tam, na dudniących rusztowaniach
sceny. Dreszcz płynący przez wielkie oblicze tego nieba, oddech
ogromnego płótna, od którego rosły i ożywały maski, zdradzał
iluzoryczność tego firmamentu, sprawiał to drganie rzeczywistości, które
w chwilach metafizycznych odczuwamy jako migotanie tajemnicy. Maski
trzepotały czerwonymi powiekami, kolorowe wargi szeptały coś bezgłośnie
i wiedziałem, że przyjdzie chwila, kiedy napięcie tajemnicy dojdzie do
zenitu i wtedy wezbrane niebo kurtyny pęknie naprawdę, uniesie się i
ukaże rzeczy niesłychane i olśniewające. Lecz nie było mi dane doczekać
tej chwili, albowiem tymczasem ojciec zaczął zdradzać pewne oznaki
zaniepokojenia, chwytał się za kieszenie i wreszcie oświadczył, że
zapomniał portfelu z pieniędzmi i ważnymi dokumentami. Po krótkiej
naradzie z matką, w której uczciwość Adeli została poddana pospiesznej,
ryczałtowej ocenie, zaproponowano mi, żebym wyruszył do domu na
poszukiwanie portfelu. Zdaniem matki do rozpoczęcia widowiska było
jeszcze wiele czasu i przy mojej zwinności mogłem na czas powrócić.
Wyszedłem w noc zimową, kolorową od iluminacji nieba. Była to jedna z
tych jasnych nocy, w których firmament gwiezdny jest tak rozległy i
rozgałęziony, jakby rozpadł się, rozłamał i podzielił na labirynt
odrębnych niebios, wystarczających do obdzielenia całego miesiąca nocy
zimowych i do nakrycia swymi srebrnymi i malowanymi kloszami wszystkich
ich nocnych zjawisk, przygód, awantur i karnawałów. Jest lekkomyślnością
nie do darowania wysyłać w taką noc młodego chłopca z misją ważną i
pilną, albowiem w jej półświetle zwielokrotniają się, plączą i
wymieniają jedne z drugimi ulice. Otwierają się w głębi miasta, żeby tak
rzec, ulice podwójne, ulice sobowtóry, ulice kłamliwe i zwodne.
Oczarowana i zmylona wyobraźnia wytwarza złudne plany miasta, rzekomo
dawno znane i wiadome, w których te ulice mają swe miejsce i nazwę, a
noc w niewyczerpanej swej płodności nie ma nic lepszego do roboty, jak
dostarczać wciąż nowych i urojonych konfiguracji. Te kuszenia nocy
zimowych zaczynają się zazwyczaj niewinnie od chętki skrócenia sobie
drogi, użycia niezwykłego lub prędszego przejścia. Powstają ponętne
kombinacje przecięcia zawiłej wędrówki jakąś nie wypróbowaną przecznicą.
Ale tym razem zaczęło się inaczej. Uszedłszy parę kroków, spostrzegłem,
że jestem bez płaszcza. Chciałem zawrócić, lecz po chwili wydało mi się
to niepotrzebną stratą czasu, gdyż noc nie była wcale zimna, przeciwnie
- pożyłkowana strugami dziwnego ciepła, tchnieniami jakiejś fałszywej
wiosny. Śnieg skurczył się w baranki białe, w niewinne i słodkie runo,
które pachniało fiołkami. W takie same baranki rozpuściło się niebo, w
którym księżyc dwoił się i troił, demonstrując w tym zwielokrotnieniu
wszystkie swe fazy i pozycje. Niebo obnażało tego dnia wewnętrzną swą
konstrukcję w wielu jakby anatomicznych preparatach, pokazujących
spirale i słoje światła, przekroje seledynowych brył nocy, plazmę
przestworzy, tkankę rojeń nocnych. W taką noc nie podobna iść Podwalem
ani żadną inną z ciemnych ulic, które są odwrotną stroną, niejako
podszewką czterech linij rynku, i nie przypomnieć sobie, że o tej późnej
porze bywają czasem jeszcze otwarte niektóre z owych osobliwych a tyle
nęcących sklepów, o których zapomina się w dnie zwyczajne. Nazywam je
sklepami cynamonowymi dla ciemnych boazeryj tej barwy, którymi są
wyłożone. Te prawdziwie szlachetne handle, w późną noc otwarte, były
zawsze przedmiotem moich gorących marzeń. Słabo oświetlone, ciemne i
uroczyste ich wnętrza pachniały głębokim zapachem farb, laku, kadzidła,
aromatem dalekich krajów i rzadkich materiałów. Mogłeś tam znaleźć ognie
bengalskie, szkatułki czarodziejskie, marki krajów dawno zaginionych,
chińskie odbijanki, indygo, kalafonium z Malabaru, jaja owadów
egzotycznych, papug, tukanów, żywe salamandry i bazyliszki, korzeń
Mandragory, norymberskie mechanizmy, homunculusy w doniczkach,
mikroskopy i lunety, a nade wszystko rzadkie i osobliwe książki, stare
folianty pełne przedziwnych rycin i oszołamiających historyj. Pamiętam
tych starych i pełnych godności kupców, którzy obsługiwali klientów ze
spuszczonymi oczyma, w dyskretnym milczeniu, i pełni byli mądrości i
wyrozumienia dla ich najtajniejszych życzeń. Ale nade wszystko była tam
jedna księgarnia, w której raz oglądałem rzadkie i zakazane druki,
publikacje tajnych klubów, zdejmując zasłonę z tajemnic dręczących i
upojnych. Tak rzadko zdarzała się sposobność odwiedzania tych sklepów - 
i w dodatku z małą, lecz wystarczającą sumą pieniędzy w kieszeni. Nie
można było pominąć tej okazji mimo ważności misji powierzonej naszej
gorliwości. Trzeba się było zapuścić według mego obliczenia w boczną
uliczkę, minąć dwie albo trzy przecznice, ażeby osiągnąć ulicę nocnych
sklepów. To oddalało mnie od celu, ale można było nadrobić spóźnienie,
wracając drogą na Żupy Solne. Uskrzydlony pragnieniem zwiedzenia sklepów
cynamonowych, skręciłem w wiadomą mi ulicę i leciałem więcej, aniżeli
szedłem, bacząc, by nie zmylić drogi. Tak minąłem już trzecią czy
czwartą przecznicę, a upragnionej ulicy wciąż nie było. W dodatku nawet
konfiguracja ulic nie odpowiadała oczekiwanemu obrazowi. Sklepów ani
śladu. Szedłem ulicą, której domy nie miały nigdzie bramy wchodowej,
tylko okna szczelnie zamknięte, ślepe odblaskiem księżyca. Po drugiej
stronie tych domów musi prowadzić właściwa ulica, od której te domy są
dostępne - myślałem sobie. Z niepokojem przyspieszałem kroku, rezygnując
w duchu z myśli zwiedzenia sklepów. Byle tylko wydostać się stąd prędko
w znane okolice miasta. Zbliżałem się do wylotu, pełen niepokoju, gdzie
też ona mnie wyprowadzi. Wyszedłem na szeroki, rzadko zabudowany
gościniec, bardzo długi i prosty. Owiał mnie od razu oddech szerokiej
przestrzeni. Stały tam przy ulicy albo w głębi ogrodów malownicze wille,
ozdobne budynki bogaczy. W przerwach między nimi widniały parki i mury
sadów. Obraz przypominał z daleka ulicę Leszniańską w jej dolnych i
rzadko zwiedzanych okolicach. Światło księżyca, rozpuszczone w
tysiącznych barankach, w łuskach srebrnych na niebie, było blade i tak
jasne jak w dzień - tylko parki i ogrody czerniały w tym srebrnym
krajobrazie. Przyjrzawszy się bacznie jednemu z budynków, doszedłem do
przekonania, że mam przed sobą tylną i nigdy nie widzianą stronę gmachu
gimnazjalnego. Właśnie dochodziłem do bramy, która ku memu zdziwieniu
była otwarta, sień oświetlona. Wszedłem i znalazłem się na czerwonym
chodniku korytarza. Miałem nadzieję, że zdołam nie spostrzeżony
przekraść się przez budynek i wyjść przednią bramą, skracając sobie
znakomicie drogę. Przypomniałem sobie, że o tej późnej godzinie musi się
w sali profesora Arendta odbywać jedna z lekcyj nadobowiązkowych,
prowadzona w późną noc, na które zbieraliśmy się zimową porą, płonąc
szlachetnym zapałem do ćwiczeń rysunkowych, jakim natchnął nas ten
znakomity nauczyciel. Mała gromadka pilnych gubiła się prawie w wielkiej
ciemnej sali, na której ścianach ogromniały i łamały się cienie naszych
głów, rzucane od dwóch małych świeczek płonących w szyjkach butelek.
Prawdę mówiąc, niewieleśmy podczas tych godzin rysowali i profesor nie
stawiał zbyt ścisłych wymagań. Niektórzy przynosili sobie z domu
poduszki i układali się na ławkach do powierzchownej drzemki. I tylko
najpilniejsi rysowali pod samą świecą, w złotym kręgu jej blasku.
Czekaliśmy zazwyczaj długo na przyjście profesora, nudząc się wśród
sennych rozmów. Wreszcie otwierały się drzwi jego pokoju i wchodził - 
mały, z piękną brodą, pełen ezoterycznych uśmiechów, dyskretnych
przemilczeń i aromatu tajemnicy. Szybko zaciskał za sobą drzwi gabinetu,
przez które w momencie otworzenia tłoczyła się za jego głową ciżba
gipsowych cieni, fragmentów klasycznych, bolesnych Niobid, Danaid i
Tantalidów, cały smutny i jałowy Olimp, więdnący od lat w tym muzeum
gipsów. Zmierzch tego pokoju mętniał i za dnia i przelewał się sennie od
gipsowych marzeń, pustych spojrzeń, blednących owali i zamyśleń
odchodzących w nicość. Lubiliśmy nieraz podsłuchiwać pod drzwiami - 
ciszy, pełnej westchnień i szeptów tego kruszejącego w pajęczynach
rumowiska, tego rozkładającego się w nudzie i monotonii zmierzchu bogów.
Profesor przechadzał się dostojnie, pełen namaszczenia, wzdłuż pustych
ławek, wśród których rozrzuceni małymi grupkami, rysowaliśmy coś w
szarym odblasku nocy zimowej. Było zacisznie i sennie. Gdzieniegdzie
koledzy moi układali się do snu. Świeczki powoli dogasały w butelkach.
Profesor pogrążał się w głęboką witrynę, pełną starych foliałów,
staromodnych ilustracyj, sztychów i druków. Pokazywał nam wśród
ezoterycznych gestów stare litografie wieczornych pejzaży, gęstwiny
nocne, aleje zimowych parków, czerniejące na białych drogach
księżycowych. Wśród sennych rozmów upływał niespostrzeżenie czas i biegł
nierównomiernie, robiąc niejako węzły w upływie godzin, połykając kędyś
całe puste interwały trwania, Niespostrzeżenie, bez przejścia,
odnajdywaliśmy naszą czeredę już w drodze powrotnej na białej od śniegu
ścieżce szpaleru, flankowanej czarną, suchą gęstwiną krzaków. Szliśmy
wzdłuż tego włochatego brzegu ciemności, ocierając się o niedźwiedzie
futro krzaków, trzaskających pod naszymi nogami w jasną noc
bezksiężycową, w mleczny, fałszywy dzień, daleko po północy. Rozprószona
biel tego światła, mżąca ze śniegu, z bladego powietrza, z mlecznych
przestworzy, była jak szary papier sztychu, na którym głęboką czernią
plątały się kreski i szrafirunki gęstych zarośli. Noc powtarzała teraz
głęboko po północy te serie nokturnów, sztychów nocnych profesora
Arendta, kontynuowała jego fantazje. W tej czarnej gęstwinie parku, we
włochatej sierści zarośli, w masie kruchego chrustu były miejscami
nisze, gniazda najgłębszej puszystej czarności, pełne plątaniny,
sekretnych gestów, bezładnej rozmowy na migi. Było w tych gniazdach
zacisznie i ciepło. Siadaliśmy tam na letnim miękkim śniegu w naszych
włochatych płaszczach, zajadając orzechy, których pełna była leszczynowa
ta gęstwina w ową wiosenną zimę. Przez zarośla przewijały się bezgłośnie
kuny, łasice i ichneumony, futrzane, węszące zwierzątka, śmierdzące
kożuchem, wydłużone, na niskich łapkach. Podejrzewaliśmy, że były między
nimi okazy gabinetu szkolnego, które choć wypatroszone i łysiejące,
uczuwały w tę białą noc w swym pustym wnętrzu głos starego instynktu,
głos rui, i wracały do matecznika na krótki, złudny żywot. Ale powoli
fosforescencja wiosennego śniegu mętniała i gasła i nadchodziła czarna i
gęsta oćma przed świtem. Niektórzy z nas zasypiali w ciepłym śniegu,
inni domacywali się w gęstwinie bram swych domów, wchodzili omackiem do
ciemnych wnętrzy, w sen rodziców i braci, w dalszy ciąg głębokiego
chrapania, które doganiali na swych spóźnionych drogach. Te nocne seanse
pełne były dla mnie tajemnego uroku, nie mogłem i teraz pominąć
sposobności, by nie zaglądnąć na moment do sali rysunkowej,
postanawiając, że nie pozwolę się tam zatrzymać dłużej nad krótką
chwilkę. Ale wstępując po tylnych, cedrowych schodach, pełnych
dźwięcznego rezonansu, poznałem, że znajduję się w obcej, nigdy nie
widzianej stronie gmachu. Najlżejszy szmer nie przerywał tu solennej
ciszy. Korytarze były w tym skrzydle obszerniejsze, wysłane pluszowym
dywanem i pełne wytworności. Małe, ciemno płonące lampy świeciły na ich
zagięciach. Minąwszy jedno takie kolano, znalazłem się na korytarzu
jeszcze większym, strojnym w przepych pałacowy. Jedna jego ściana
otwierała się szerokimi, szklanymi arkadami do wnętrza mieszkania.
Zaczynała się tu przed oczyma długa amfilada pokojów, biegnących w głąb
i urządzonych z olśniewającą wspaniałością. Szpalerem obić jedwabnych,
luster złoconych, kosztownych mebli i kryształowych pająków biegł wzrok
w puszysty miąższ tych zbytkownych wnętrzy, pełnych kolorowego wirowania
i migotliwych arabesek, plączących się girland i pączkujących kwiatów.
Głęboka cisza tych pustych salonów pełna była tylko tajnych spojrzeń,
które oddawały sobie zwierciadła, i popłochu arabesek, biegnących wysoko
fryzami wzdłuż ścian i gubiących się w sztukateriach białych sufitów. Z
podziwem i czcią stałem przed tym przepychem, domyślałem się, że nocna
moja eskapada zaprowadziła mnie niespodzianie w skrzydło dyrektora,
przed jego prywatne mieszkanie. Stałem przygwożdżony ciekawością, z
bijącym sercem, gotów do ucieczki za najlżejszym szmerem. Jakże mógłbym,
przyłapany, usprawiedliwić to moje nocne szpiegowanie, moje zuchwałe
wścibstwo? W którymś z głębokich pluszowych foteli mogła, nie
dostrzeżona i cicha, siedzieć córeczka dyrektora i podnieść nagle na
mnie oczy znad książki - czarne, sybilińskie, spokojne oczy, których
spojrzenia nikt z nas wytrzymać nie umiał. Ale cofnąć się w połowie
drogi, nie dokonawszy powziętego planu, poczytałbym był sobie za
tchórzostwo. Zresztą głęboka cisza panowała dookoła w pełnych przepychu
wnętrzach, oświetlonych przyćmionym światłem nie określonej pory. Przez
arkady korytarza widziałem na drugim końcu wielkiego salonu duże,
oszklone drzwi, prowadzące na taras. Było tak cicho wokoło, że nabrałem
odwagi. Nie wydawało mi się to połączone ze zbyt wielkim ryzykiem, zejść
z paru stopni, prowadzących do poziomu sali, w kilku susach przebiegnąć
wielki, kosztowny dywan i znaleźć się na tarasie, z którego bez trudu
dostać się mogłem na dobrze mi znaną ulicę. Uczyniłem tak. Zeszedłszy na
parkiety salonu, pod wielkie palmy, wystrzelające tam z wazonów aż do
arabesek sufitu, spostrzegłem, że znajduję się już właściwie na gruncie
neutralnym, gdyż salon nie miał wcale przedniej ściany. Był on rodzajem
wielkiej loggii, łączącej się przy pomocy paru stopni z placem miejskim.
Była to niejako odnoga tego placu i niektóre meble stały już na bruku.
Zbiegłem z kilku kamiennych schodów i znalazłem się znów na ulicy.
Konstelacje stały już stromo na głowie, wszystkie gwiazdy przekręciły
się na drugą stronę, ale księżyc, zagrzebany w pierzyny obłoczków, które
rozświetlał swą niewidzialną obecnością, zdawał się mieć przed sobą
jeszcze nieskończoną drogę i, zatopiony w swych zawiłych procederach
niebieskich, nie myślał o świcie. Na ulicy czerniało kilka dorożek,
rozjechanych i rozklekotanych jak kalekie, drzemiące kraby czy karakony.
Woźnica nachylił się z wysokiego kozła. Miał twarz drobną, czerwoną i
dobroduszną. - Pojedziemy, paniczu? - zapytał. Powóz zadygotał we
wszystkich stawach i przegubach swego wieloczłonkowego ciała i ruszył na
lekkich obręczach. Ale kto w taką noc powierza się kaprysom
nieobliczalnego dorożkarza? Wśród klekotu szprych, wśród dudnienia pudła
i budy nie mogłem porozumieć się z nim co do celu drogi. Kiwał na
wszystko niedbale i pobłażliwie głową i podśpiewywał sobie, jadąc drogą
okrężną przez miasto. Przed jakimś szynkiem stała grupa dorożkarzy,
kiwając nań przyjaźnie rękami. Odpowiedział im coś radośnie, po czym nie
zatrzymując pojazdu, rzucił mi lejce na kolana, spuścił się z kozła i
przyłączył do gromady kolegów. Koń, stary mądry koń dorożkarski,
oglądnął się pobieżnie i pojechał dalej jednostajnym, dorożkarskim
kłusem. Właściwie koń ten budził zaufanie - wydawał się mądrzejszy od
woźnicy. Ale powozić nie umiałem - trzeba się było zdać na jego wolę.
Wjechaliśmy na podmiejską ulicę ujętą z obu stron w ogrody. Ogrody te
przechodziły zwolna, w miarę posuwania się, w parki wielkodrzewne, a te
w lasy. Nie zapomnę nigdy tej jazdy świetlistej w najjaśniejszą noc
zimową. Kolorowa mapa niebios wyogromniała w kopułę niezmierną, na
której spiętrzyły się fantastyczne lądy, oceany i morza, porysowane
liniami wirów i prądów gwiezdnych, świetlistymi liniami geografii
niebieskiej. Powietrze stało się lekkie do oddychania i świetlane jak
gaza srebrna. Pachniało fiołkami. Spod wełnianego jak białe karakuły
śniegu wychylały się anemony drżące, z iskrą światła księżycowego w
delikatnym kielichu. Las cały zdawał się iluminować tysiącznymi
światłami, gwiazdami, które rzęsiście ronił grudniowy firmament.
Powietrze dyszało jakąś tajną wiosną, niewypowiedzianą czystością śniegu
i fiołków. Wjechaliśmy w teren pagórkowaty. Linie wzgórzy, włochatych
nagimi rózgami drzew, podnosiły się jak błogie westchnienia w niebo.
Ujrzałem na tych szczęśliwych zboczach całe grupy wędrowców,
zbierających wśród mchu i krzaków opadłe i mokre od śniegu gwiazdy.
Droga stała się stroma, koń poślizgiwał się i z trudem ciągnął pojazd,
grający wszystkimi przegubami. Byłem szczęśliwy. Pierś moja wchłaniała
tę błogą wiosnę powietrza, świeżość gwiazd i śniegu. Przed piersią konia
zbierał się wał białej piany śnieżnej, coraz wyższy i wyższy. Z trudem
przekopywał się koń przez czystą i świeżą jego masę. Wreszcie ustał.
Wyszedłem z dorożki. Dyszał ciężko ze zwieszoną głową. Przytuliłem jego
łeb do piersi, w jego wielkich czarnych oczach lśniły łzy. Wtedy
ujrzałem na jego brzuchu okrągłą czarną ranę. - -Dlaczego mi nie
powiedziałeś? - szepnąłem ze łzami. - Drogi mój - to dla ciebie - rzekł
i stał się bardzo mały, jak konik z drzewa. Opuściłem go. Czułem się
dziwnie lekki i szczęśliwy. Zastanawiałem się, czy czekać na małą
kolejkę lokalną, która tu zajeżdżała, czy też pieszo wrócić do miasta.
Zacząłem schodzić stromą serpentyną wśród lasu, początkowo idąc krokiem
lekkim, elastycznym, potem, nabierając rozpędu, przeszedłem w posuwisty
szczęśliwy bieg, który zmienił się wnet w jazdę jak na nartach. Mogłem
dowoli regulować szybkość, kierować jazdą przy pomocy lekkich zwrotów
ciała. W pobliżu miasta zahamowałem ten bieg tryumfalny, zmieniając go
na przyzwoity krok spacerowy. Księżyc stał jeszcze ciągle wysoko.
Transformacje nieba, metamorfozy jego wielokrotnych sklepień w coraz to
kunsztowniejsze konfiguracje nie miały końca. Jak srebrne astrolabium
otwierało niebo w tę noc czarodziejską mechanizm wnętrza i ukazywało w
nieskończonych ewolucjach złocistą matematykę swych kół i trybów. Na
rynku spotkałem ludzi zażywających przechadzki. Wszyscy, oczarowani
widowiskiem tej nocy, mieli twarze wzniesione i srebrne od magii nieba.
Troska o portfel opuściła mnie zupełnie. Ojciec, pogrążony w swych
dziwactwach, zapewne zapomniał już o zgubie, o matkę nie dbałem. W taką
noc, jedyną w roku, przychodzą szczęśliwe myśli, natchnienia, wieszcze
tknięcia palca bożego. Pełen pomysłów i inspiracji, chciałem skierować
się do domu, gdy zaszli mi drogę koledzy z książkami pod pachą. Zbyt
wcześnie wyszli do szkoły, obudzeni jasnością tej nocy, która nie
chciała się skończyć. Poszliśmy gromadą na spacer stromo spadającą
ulicą, z której wiał powiew fiołków, niepewni, czy to jeszcze magia nocy
srebrzyła się na śniegu, czy też świt już wstawał...

ULICA KROKODYLI Mój ojciec przechowywał w dolnej szufladzie swego
głębokiego biurka starą i piękną mapę naszego miasta. Był to cały
wolumen in folio pergaminowych kart, które pierwotnie spojone skrawkami
płótna, tworzyły ogromną mapę ścienną w kształcie panoramy z ptasiej
perspektywy. Zawieszona na ścianie, zajmowała niemal przestrzeń całego
pokoju i otwierała daleki widok na całą dolinę Tyśmienicy, wijącej się
falisto bladozłotą wstęgą, na całe pojezierze szeroko rozlanych moczarów
i stawów, na pofałdowane przedgórza, ciągnące się ku południowi, naprzód
z rzadka, potem coraz tłumniejszymi pasmami, szachownicą okrągławych
wzgórzy, coraz mniejszych i coraz bledszych, w miarę jak odchodziły ku
złotawej i dymnej mgle horyzontu. Z tej zwiędłej dali peryferii
wynurzało się miasto i rosło ku przodowi, naprzód jeszcze w nie
zróżnicowanych kompleksach, w zwartych blokach i masach domów,
poprzecinanych głębokimi parowami ulic, by bliżej jeszcze wyodrębnić się
w pojedyncze kamienice, sztychowane z ostrą wyrazistością widoków
oglądanych przez lunetę. Na tych bliższych planach wydobył sztycharz
cały zawikłany i wieloraki zgiełk ulic i zaułków, ostrą wyrazistość
gzymsów, architrawów, archiwolt i pilastrów, świecących w późnym i
ciemnym złocie pochmurnego popołudnia, które pogrąża wszystkie załomy i
framugi w głębokiej sepii cienia. Bryły i pryzmy tego cienia wcinały
się, jak plastry ciemnego miodu, w wąwozy ulic, zatapiały w swej
ciepłej, soczystej masie tu całą połowę ulicy, tam wyłom między domami,
dramatyzowały i orkiestrowały ponurą romantyką cieni tę wieloraką
polifonię architektoniczną. Na tym planie, wykonanym w stylu barokowych
prospektów, okolica Ulicy Krokodylej świeciła pustą bielą, jaką na
kartach geograficznych zwykło się oznaczać okolice podbiegunowe, krainy
niezbadane i niepewnej egzystencji. Tylko linie kilku ulic wrysowane tam
były czarnymi kreskami i opatrzone nazwami w prostym, nieozdobnym
piśmie, w odróżnieniu od szlachetnej antykwy innych napisów. Widocznie
kartograf wzbraniał się uznać przynależność tej dzielnicy do zespołu
miasta i zastrzeżenie swe wyraził w tym odrębnym i postponującym
wykonaniu. Aby zrozumieć tę rezerwę, musimy już teraz zwrócić uwagę na
dwuznaczny i wątpliwy charakter tej dzielnicy, tak bardzo odbiegający od
zasadniczego tonu całego miasta. Był to dystrykt przemysłowo-handlowy z
podkreślonym jaskrawo charakterem trzeźwej użytkowości. Duch czasu,
mechanizm ekonomiki, nie oszczędził i naszego miasta i zapuścił korzenie
na skrawku jego peryferii, gdzie rozwinął się w pasożytniczą dzielnicę.
Kiedy w starym mieście panował wciąż jeszcze nocny, pokątny handel,
pełen solennej ceremonialności, w tej nowej dzielnicy rozwinęły się od
razu nowoczesne, trzeźwe formy komercjalizmu. Pseudoamerykanizm,
zaszczepiony na starym, zmurszałym gruncie miasta, wystrzelił tu bujną,
lecz pustą i bezbarwną wegetacją tandetnej, lichej pretensjonalności.
Widziało się tam tanie, marnie budowane kamienice o karykaturalnych
fasadach, oblepione monstrualnymi sztukateriami z popękanego gipsu.
Stare, krzywe domki podmiejskie otrzymały szybko sklecone portale, które
dopiero bliższe przyjrzenie demaskowało jako nędzne imitacje
wielkomiejskich urządzeń. Wadliwe, mętne i brudne szyby, łamiące w
falistych refleksach ciemne odbicie ulicy, nie heblowane drzewo portali,
szara atmosfera jałowych tych wnętrzy, osiadających pajęczyną i kłakami
kurzu na wysokich półkach i wzdłuż odartych i kruszących się ścian,
wyciskały tu, na sklepach, piętno dzikiego Klondike'u. Tak ciągnęły się
jeden za drugim, magazyny krawców, konfekcje, składy porcelany,
drogerie, zakłady fryzjerskie. Szare ich, wielkie szyby wystawowe nosiły
ukośnie lub w półkolu biegnące napisy ze złoconych plastycznych liter:
CONFISERIE, MANUCURE, KING OF ENGLAND. Rdzenni mieszkańcy miasta
trzymali się z dala od tej okolicy, zamieszkiwanej przez szumowiny,
przez gmin, przez kreatury bez charakteru, bez gęstości, przez istną
lichotę moralną, tę tandetną odmianę człowieka, która rodzi się w takich
efemerycznych środowiskach. Ale w dniach upadku, w godzinach niskiej
pokusy zdarzało się, że ten lub ów z mieszkańców miasta zabłąkiwał się
na wpół przypadkiem w tę wątpliwą dzielnicę. Najlepsi nie byli czasem
wolni od pokusy dobrowolnej degradacji, zniwelowania granic i
hierarchii, pławienia się w tym płytkim błocie wspólnoty, łatwej
intymności, brudnego zmieszania. Dzielnica ta była eldoradem takich
dezerterów moralnych, takich zbiegów spod sztandaru godności własnej.
Wszystko zdawało się tam podejrzane i dwuznaczne, wszystko zapraszało
sekretnym mrugnięciem, cynicznie artykułowanym gestem, wyraźnie
przymrużonym perskim okiem - do nieczystych nadziei, wszystko wyzwalało
z pęt niską naturę. Mało kto, nie uprzedzony, spostrzegał dziwną
osobliwość tej dzielnicy: brak barw, jak gdyby w tym tandetnym, w
pośpiechu wyrosłym mieście nie można było sobie pozwolić na luksus
kolorów. Wszystko tam było szare jak na jednobarwnych fotografiach, jak
w ilustrowanych prospektach. Podobieństwo to wychodziło poza zwykłą
metaforę, gdyż chwilami, wędrując po tej części miasta, miało się w
istocie wrażenie, że wertuje się w jakimś prospekcie, w nudnych
rubrykach komercjalnych ogłoszeń, wśród których zagnieździły się
pasożytniczo podejrzane anonse, drażliwe notatki, wątpliwe ilustracje; i
wędrówki te były równie jałowe i bez rezultatu jak ekscytacje fantazji,
pędzonej przez szpalty i kolumny pornograficznych druków. Wchodziło się
do jakiegoś krawca, żeby zamówić ubranie - ubranie o taniej elegancji,
tak charakterystycznej dla tej dzielnicy. Lokal był wielki i pusty,
bardzo wysoki i bezbarwny. Ogromne wielopiętrowe półki wznoszą się jedne
nad drugimi w nie określoną wysokość tej hali. Kondygnacje pustych półek
wyprowadzają wzrok w górę aż pod sufit, który może być niebem - lichym,
bezbarwnym, odrapanym niebem tej dzielnicy. Natomiast dalsze magazyny,
które widać przez otwarte drzwi, pełne są aż pod sufit pudeł i kartonów,
piętrzących się ogromną kartoteką, która rozpada się w górze, pod
zagmatwanym niebem strychu w kubaturę pustki, w jałowy budulec nicości.
Przez wielkie szare okna, kratkowane wielokrotnie jak arkusze papieru
kancelaryjnego, nie wchodzi światło, gdyż przestrzeń sklepu już
napełniona jest, jak wodą, indyferentną szarą poświatą, która nie rzuca
cienia i nie akcentuje niczego. Wnet nawija się jakiś smukły
młodzieniec, zadziwiająco usłużny, giętki i nieodporny, ażeby dogodzić
naszym życzeniom i zalać nas tanią i łatwą wymową subiekta. Ale gdy,
gadając, rozwija ogromne postawy sukna, przymierza, fałduje i drapuje
niekończącą się strugę materiału, przepływającą przez jego ręce,
formując z jego fal iluzoryczne surduty i spodnie, cała ta manipulacja
wydaje się czymś nieistotnym, pozorem, komedią, ironicznie zarzuconą
zasłoną na prawdziwy sens sprawy. Panienki sklepowe, smukłe i czarne,
każda z jakąś skazą piękności (charakterystyczną dla tej dzielnicy
wybrakowanych artykułów), wchodzą i wychodzą, stają w drzwiach
magazynów, sondując oczyma, czy rzecz wiadoma (powierzona doświadczonym
rękom subiekta) dojrzewa do punktu właściwego. Subiekt przymila się i
kryguje i chwilami robi wrażenie transwestyty. Chciałoby się go ująć pod
miękko zarysowaną brodę lub uszczyp-nąć w upudrowany blady policzek, gdy
z porozumiewawczym półspojrzeniem dyskretnie zwraca uwagę na markę
ochronną towaru, markę o przejrzystej symbolice. Zwolna sprawa wyboru
ubrania schodzi na plan dalszy. Ten miękki do efeminacji i zepsuty
młodzieniec, pełen zrozumienia dla najintymniejszych poruszeń klienta,
przesuwa teraz przed jego oczyma osobliwe marki ochronne, całą
bibliotekę znaków ochronnych, gabinet kolekcjonerski wyrafinowanego
zbieracza. Pokazywało się wówczas, że magazyn konfekcji był tylko
fasadą, za którą kryła się antykwarnia, zbiór wysoce dwuznacznych
wydawnictw i druków prywatnych. Usłużny subiekt otwiera dalsze składy,
wypełnione aż pod sufit książkami, rycinami, fotografiami. Te winiety,
te ryciny przechodzą stokrotnie najśmielsze nasze marzenia. Takich
kulminacyj zepsucia, takich wymyślności wyuzdania nie przeczuwaliśmy
nigdy. Panienki sklepowe przesuwają się coraz częściej pomiędzy
szeregami książek, szare i papierowe, ale pełne pigmentu w zepsutych
twarzach, ciemnego pigmentu brunetek o lśniącej i tłustej czarności,
która zaczajona w oczach, z nagła wybiegała z nich zygzakiem lśniącego
karakoniego biegu. Ale i w spalonych rumieńcach, w pikantnych stygmatach
pieprzyków, we wstydliwych znamionach ciemnego puszku zdradzała się rasa
zapiekłej, czarnej krwi. Ten barwik o nazbyt intensywnej mocy, ta mokka
gęsta i aromatyczna zdawała się plamić książki, które brały one do
oliwkowej dłoni, ich dotknięcia zdawały się je farbować i zostawiać w
powietrzu ciemny deszcz piegów, smugę tabaki, jak purchawka o
podniecającej, animalnej woni. Tymczasem powszechna rozwiązłość zrzucała
coraz bardziej hamulce pozorów. Subiekt, wyczerpawszy swą natarczywą
aktywność, przechodził powoli do kobiecej bierności. Leży teraz na
jednej z wielu kanap, porozstawianych wśród rejonów książek, w jedwabnej
pidżamie, odsłaniającej kobiecy dekolt. Panienki demonstrują, jedna
przed drugą, figury i pozycje rycin okładkowych, inne zasypiają już na
prowizorycznych posłaniach. Nacisk na klienta rozluźniał się.
Wypuszczano go z kręgu natarczywego zainteresowania, pozostawiano sobie
samemu. Subiektki, zajęte rozmową, nie zwracały nań więcej uwagi.
Odwrócone do niego tyłem lub bokiem, przystawały w aroganckim kontra
poście, przestępowały z nogi na nogę, grając kokieteryjnym obuwiem,
przepuszczały z góry na dół po smukłym ciele wężową grę członków,
atakując nią spoza swej niedbałej nieodpowiedzialności podnieconego
widza, którego ignorowały. Tak cofano się, wsuwano w głąb z
wyrachowaniem, otwierając wolną przestrzeń dla aktywności gościa.
Skorzystajmy z tego momentu nieuwagi, ażeby wymknąć się nieprzewidzianym
konsekwencjom tej niewinnej wizyty i wydostać się na ulicę. Nikt nas nie
zatrzymuje. Przez korytarze książek, pomiędzy długimi regałami czasopism
i druków wydostajemy się ze sklepu i oto jesteśmy w tym miejscu Ulicy
Krokodylej, gdzie z wyniesionego jej punktu widać niemal całą długość
tego szerokiego traktu aż do dalekich, nie wykończonych zabudowań dworca
kolejowego. Jest to szary dzień, jak zawsze w tej okolicy, i cała
sceneria wydaje się chwilami fotografią z ilustrowanej gazety, tak
szare, tak płaskie są domy, ludzie i pojazdy. Ta rzeczywistość jest
cienka jak papier i wszystkimi szparami zdradza swą imitatywność.
Chwilami ma się wrażenie, że tylko na małym skrawku przed nami układa
się wszystko przykładnie w ten pointowany obraz bulwaru
wielkomiejskiego, gdy tymczasem już na bokach rozwiązuje się i rozprzęga
ta zaimprowizowana maskarada i, niezdolna wytrwać w swej roli, rozpada
się za nami w gips i pakuły, w rupieciarnię jakiegoś ogromnego pustego
teatru. Napięcie pozy, sztuczna powaga maski, ironiczny patos drży na
tym naskórku. Ale dalecy jesteśmy od chęci demaskowania widowiska. Wbrew
lepszej wiedzy czujemy się wciągnięci w tandetny czar dzielnicy. Zresztą
nie brak w obrazie miasta i pewnych cech autoparodii. Rzędy małych,
parterowych domków podmiejskich zmieniają się z wielopiętrowymi
kamienicami, które zbudowane jak z kartonu, są konglomeratem szyldów,
ślepych okien biurowych, szklistoszarych wystaw, reklam i numerów. Pod
domami płynie rzeka tłumu. Ulica jest szeroka jak bulwar wielkomiejski,
ale jezdnia, jak place wiejskie, zrobiona jest z ubitej gliny, pełna
wybojów, kałuży i trawy. Ruch uliczny dzielnicy służy do porównań w tym
mieście, mieszkańcy mówią o nim z dumą i porozumiewawczym błyskiem w
oku. Szary, bezosobisty ten tłum jest nader przejęty swą rolą i pełen
gorliwości w demonstrowaniu wielkomiejskiego pozoru. Wszelako, mimo
zaaferowania i interesowności, ma się wrażenie błędnej, monotonnej,
bezcelowej wędrówki, jakiegoś sennego korowodu marionetek. Atmosfera
dziwnej błahości przenika tę całą scenerię. Tłum płynie monotonnie i,
rzecz dziwna, widzi się go zawsze jakby niewyraźnie, figury przepływają
w splątanym, łagodnym zgiełku, nie dochodząc do zupełnej wyrazistości.
Czasem tylko wyławiamy z tego gwaru wielu głów jakieś ciemne, żywe
spojrzenie, jakiś czarny melonik nasunięty głęboko na głowę, jakieś pół
twarzy rozdarte uśmiechem, z ustami, które właśnie coś powiedziały,
jakąś nogę wysuniętą w kroku i tak już zastygłą na zawsze. Osobliwością
dzielnicy są dorożki bez woźniców, biegnące samopas po ulicach. Nie
jakoby nie było tu dorożkarzy, ale wmieszani w tłum i zajęci tysiącem
spraw, nie troszczą się o swe dorożki. W tej dzielnicy pozoru i pustego
gestu nie przywiązuje się zbytniej wagi do ścisłego celu jazdy i
pasażerowie powierzają się tym błędnym pojazdom z lekkomyślnością, która
cechuje tu wszystko. Nieraz można ich widzieć na niebezpiecznych
zakrętach, wychylonych daleko z połamanej budy, jak z lejcami w dłoniach
przeprowadzają z natężeniem trudny manewr wymijania. Mamy w tej
dzielnicy także tramwaje. Ambicja rajców miejskich święci tu najwyższy
swój triumf. Ale pożałowania godny jest widok tych wozów, zrobionych z
papier mâché, o ścianach powyginanych i zmiętych od wieloletniego
użytku. Często brak im zupełnie przedniej ściany tak, że widzieć można w
przejeździe pasażerów, siedzących sztywnie i zachowujących się z wielką
godnością. Tramwaje te popychane są przez tragarzy miejskich.
Najdziwniejszą atoli rzeczą jest komunikacja kolejowa na Ulicy
Krokodylej. Czasami, w nieregularnych porach dnia, gdzieś ku końcowi
tygodnia można zauważyć tłum ludzi czekających na zakręcie ulicy na
pociąg. Nie jest się nigdy pewnym, czy przyjedzie i gdzie stanie, i
zdarza się często, że ludzie ustawiają się w dwóch różnych punktach, nie
mogąc uzgodnić swych poglądów na miejsce przystanku. Czekają długo i
stoją czarnym milczącym tłumem wzdłuż ledwo zarysowanych śladów toru, z
twarzami w profilu, jak szereg bladych masek z papieru, wyciętych w
fantastyczną linię zapatrzenia. I wreszcie niespodzianie zajeżdża, już
wjechał z bocznej uliczki, skąd go oczekiwano, niski jak wąż,
miniaturowy, z małą, sapiącą, krępą lokomotywą. Wjechał w ten czarny
szpaler i ulica staje się ciemna od tego ciągu wozów, siejących pył
węglowy. Ciemne sapanie parowozu i powiew dziwnej powagi, pełnej smutku,
tłumiony pośpiech i zdenerwowanie zamieniają ulicę na chwilę w halę
dworca kolejowego w szybko zapadającym zmierzchu zimowym. Plagą naszego
miasta jest ażiotaż biletów kolejowych i przekupstwo. W ostatniej
chwili, gdy pociąg już stoi na stacji, toczą się w nerwowym pośpiechu
pertraktacje z przekupnymi urzędnikami linii żelaznej. Zanim te
negocjacje się kończą, pociąg rusza, odprowadzany przez wolno sunący,
rozczarowany tłum, który odprowadza go daleko, ażeby się wreszcie
rozproszyć. Ulica, zacieśniona na chwilę do tego zaimprowizowanego
dworca, pełnego zmierzchu i tchnienia dalekich dróg - rozwidnia się
znowu, rozszerza i przepuszcza znów swym korytem beztroski monotonny
tłum spacerowiczów, który wędruje wśród gwaru rozmów wzdłuż wystaw
sklepowych, tych brudnych, szarych czworoboków, pełnych tandetnych
towarów, wielkich woskowych manekinów i lalek fryzjerskich. Wyzywająco
ubrane, w długich koronkowych sukniach przechodzą prostytutki. Mogą to
być zresztą żony fryzjerów lub kapelmistrzów kawiarnianych. Idą
drapieżnym, posuwistym krokiem i mają w niedobrych, zepsutych twarzach
nieznaczną skazę, która je przekreśla: zezują czarnym, krzywym zezem lub
mają usta rozdarte, lub brak im koniuszka nosa. Mieszkańcy miasta dumni
są z tego odoru zepsucia, którym tchnie Ulica Krokodyli. Nie mamy
potrzeby niczego sobie odmawiać - myślą z dumą - stać nas i na prawdziwą
wielkomiejską rozpustę. Twierdzą oni, że każda kobieta w tej dzielnicy
jest kokotą. W istocie wystarczy zwrócić uwagę na którąś - a natychmiast
spotyka się to uporczywe, lepkie spojrzenie, które nas zmraża rozkoszną
pewnością. Nawet dziewczęta szkolne noszą tu w pewien charakterystyczny
sposób kokardy, stawiają swoistą manierą smukłe nogi i mają tę nieczystą
skazę w spojrzeniu, w której leży preformowane przyszłe zepsucie. A
jednak - a jednak czy mamy zdradzić ostatnią tajemnicę tej dzielnicy,
troskliwie ukrywany sekret Ulicy Krokodyli? Kilkakrotnie w trakcie
naszego sprawozdania stawialiśmy pewne znaki ostrzegawcze, dawaliśmy w
delikatny sposób wyraz naszym zastrzeżeniom. Uważny czytelnik nie będzie
nie przygotowany na ten ostateczny obrót sprawy. Mówiliśmy o
imitatywnym, iluzorycznym charakterze tej dzielnicy, ale słowa te mają
zbyt ostateczne i stanowcze znaczenie, by określić połowiczny i
niezdecydowany charakter jej rzeczywistości. Język nasz nie posiada
określeń, które by dozowały niejako stopień realności, definiowały jej
giętkość. Powiedzmy bez ogródek: fatalnością tej dzielnicy jest, że nic
w niej nie dochodzi do skutku, nic nie odbiega od swego definitivum,
wszystkie ruchy rozpoczęte zawisają w powietrzu, wszystkie gesty
wyczerpują się przedwcześnie i nie mogą przekroczyć pewnego martwego
punktu. Mogliśmy już zauważyć wielką bujność i rozrzutność - w
intencjach, w projektach i antycypacjach, która cechuje tę dzielnicę.
Cała ona nie jest niczym innym jak fermentacją pragnień, przedwcześnie
wybujałą i dlatego bezsilną i pustą. W atmosferze nadmiernej łatwości
kiełkuje tutaj każda najlżejsza zachcianka, przelotne napięcie puchnie i
rośnie w pustą, wydętą narośl, wystrzela szara i lekka wegetacja
puszystych chwastów, bezbarwnych włochatych maków, zrobiona z nieważkiej
tkanki majaku i haszyszu. Nad całą dzielnicą unosi się leniwy i
rozwiązły fluid grzechu i domy, sklepy, ludzie wydają się niekiedy
dreszczem na jej gorączkującym ciele, gęsią skórką na jej febrycznych
marzeniach. Nigdzie, jak tu, nie czujemy się tak zagrożeni
możliwościami, wstrząśnięci bliskością spełnienia, pobladli i bezwładni
rozkosznym truchleniem ziszczenia. Lecz na tym się też kończy.
Przekroczywszy pewien punkt napięcia, przypływ zatrzymuje się i cofa,
atmosfera gaśnie i przekwita, możliwości więdną i rozpadają się w
nicość, oszalałe szare maki ekscytacji rozsypują się w popiół. Będziemy
wiecznie żałowali, żeśmy wtedy wyszli na chwilę z magazynu konfekcji
podejrzanej konduity. Nigdy nie trafimy już doń z powrotem. Będziemy
błądzili od szyldu do szyldu i mylili się setki razy. Zwiedzimy
dziesiątki magazynów, trafimy do całkiem podobnych, będziemy wędrowali
przez szpalery książek, wertowali czasopisma i druki, konferowali długo
i zawile z panienkami o nadmiernym pigmencie i skażonej piękności, które
nie potrafią zrozumieć naszych życzeń. Będziemy się wikłali w
nieporozumieniach, aż cała nasza gorączka i podniecenie ulotni się w
niepotrzebnym wysiłku, w straconej na próżno gonitwie. Nasze nadzieje
były nieporozumieniem, dwuznaczny wygląd lokalu i służby- pozorem,
konfekcja była prawdziwą konfekcją, a subiekt nie miał żadnych ukrytych
intencyj. Świat kobiecy Ulicy Krokodylej odznacza się całkiem miernym
zepsuciem, zagłuszonym grubymi warstwami przesądów moralnych i banalnej
pospolitości. W tym mieście taniego materiału ludzkiego brak także
wybujałości instynktu, brak niezwykłych i ciemnych namiętności. Ulica
Krokodyli była koncesją naszego miasta na rzecz nowoczesności i zepsucia
wielkomiejskiego. Widocznie nie stać nas było na nic innego jak na
papierową imitację, jak na fotomontaż złożony z wycinków zleżałych,
zeszłorocznych gazet.

KARAKONY Było to w okresie szarych dni, które nastąpiły po świetnej
kolorowości genialnej epoki mego ojca. Były to długie tygodnie depresji,
ciężkie tygodnie bez niedziel i świąt, przy zamkniętym niebie i w
zubożałym krajobrazie. Ojca już wówczas nie było. Górne pokoje
wysprzątano i wynajęto pewnej telefonistce. Z całego ptasiego
gospodarstwa pozostał nam jedyny egzemplarz, wypchany kondor, stojący na
półce w salonie. W chłodnym półmroku zamkniętych firanek stał on tam,
jak za życia, na jednej nodze, w pozie buddyjskiego mędrca, a gorzka
jego, wyschła twarz ascety skamieniała w wyraz ostatecznej obojętności i
abnegacji. Oczy wypadły, a przez wypłakane, łzawe orbity sypały się
trociny. Tylko rogowate egipskie narośle na nagim potężnym dziobie i na
łysej szyi, narośle i gruzły spłowiałobłękitnej barwy nadawały tej
starczej głowie coś dostojnie hieratycznego. Pierzasty habit jego był
już w wielu miejscach przeżarty przez mole i gubił miękkie, szare
pierze, które Adela raz w tygodniu wymiatała wraz z bezimiennym kurzem
pokoju. W wyłysiałych miejscach widać było workowe, grube płótno, z
którego wyłaziły kłaki konopne. Miałem ukryty żal do matki za łatwość, z
jaką przeszła do porządku dziennego nad stratą ojca. Nigdy go nie
kochała - myślałem - a ponieważ ojciec nie był zakorzeniony w sercu
żadnej kobiety, przeto nie mógł też wróść w żadną realność i unosił się
wiecznie na peryferii życia, w półrealnych regionach, na krawędziach
rzeczywistosci. Nawet na uczciwą obywatelską śmierć nie zasłużył sobie - 
myślałem - wszystko u niego musiało, być dziwaczne i wątpliwe.
Postanowiłem w stosownej chwili zaskoczyć matkę otwartą rozmową. Owego
dnia (był ciężki dzień zimowy i od rana już sypał się miękki puch
zmierzchu) matka miała migrenę i leżała na sofie samotnie w salonie. W
tym rzadko odwiedzanym, paradnym pokoju panował od czasu zniknięcia ojca
wzorowy porządek, pielęgnowany woskiem i szczotkami przez Adelę. Meble
przykryte były pokrowcami; wszystkie sprzęty poddały się żelaznej
dyscyplinie, jaką Adela roztoczyła nad tym pokojem. Tylko pęk piór
pawich, stojących w wazie na komodzie, nie dał się utrzymać w ryzach.
Był to element swawolny, niebezpieczny, o nieuchwytnej rewolucyjności,
jak rozhukana klasa gimnazjastek, pełna dewocji w oczy, a rozpustnej
swawoli poza oczyma. Świdrowały te oczy dzień cały i wierciły dziury w
ścianach, mrugały, tłoczyły się, trzepocąc rzęsami, z palcem przy
ustach, jedne przez drugie, pełne chichotu i psoty. Napełniały pokój
świergotem i szeptem, rozsypywały się, jak motyle, dookoła
wieloramiennej lampy, uderzały tłumem barwnym w matowe, starcze dziurki
od kluczy. Nawet w obecności matki, leżącej z zawiązaną głową na sofie,
nie mogły się powstrzymać, robiły perskie oczko, dawały sobie znaki,
mówiły niemym, kolorowym alfabetem, pełnym sekretnych znaczeń. Irytowało
mnie to szydercze porozumienie, ta migotliwa zmowa poza mymi plecami. Z
kolanami przyciśniętymi do sofy matki, badając dwoma palcami, jakby w
zamyśleniu, delikatną materię jej szlafroka, rzekłem niby mimochodem: - 
Chciałem cię już od dawna zapytać: prawda, że to jest on? - I chociaż
nie wskazałem nawet spojrzeniem na kondora, matka odgadła od razu,
zmieszała się bardzo i spuściła oczy. Dałem umyślnie upłynąć chwili,
żeby wykosztować jej zmieszanie, po czym z całym spokojem, opanowując
wzbierający gniew, spytałem: - Jaki sens mają w takim razie te wszystkie
plotki i kłamstwa, które rozsiewasz o ojcu? Lecz jej rysy, które w
pierwszej chwili rozpadły się były w panice, zaczęły się znowu
porządkować. - Jakie kłamstwa? - spytała mrugając oczyma, które były
puste, nalane ciemnym błękitem, bez białka. - Znam je od Adeli - rzekłem
- ale wiem, że pochodzą od ciebie; chcę wiedzieć prawdę. Usta jej drżały
lekko, źrenice, unikając mego wzroku, powędrowały w kąt oka. - Nie
kłamałam - rzekła, a usta- jej napęczniały i stały się małe zarazem.
Uczułem, że mnie kokietuje jak kobieta mężczyznę. - Z tymi karakonami to
prawda - sam przecież pamiętasz... - Zmieszałem się. Pamiętałem w
istocie tę inwazję karakonów, ten zalew czarnego rojowiska, które
napełniało ciemność nocną, pajęczą bieganiną. Wszystkie szpary pełne
były drgających wąsów, każda szczelina mogła wystrzelić z nagła
karakonem, z każdego pęknięcia podłogi mogła zlęgnąć się ta czarna
błyskawica, lecąca oszalałym zygzakiem po podłodze. Ach, ten dziki obłęd
popłochu, pisany błyszczącą, czarną linią na tablicy podłogi. Ach, te
krzyki grozy ojca, skaczącego z krzesła na krzesło z dzirytem w ręku.
Nie przyjmując jadła ani napoju, z wypiekami gorączki na twarzy, z
konwulsją wstrętu wrytą dookoła ust, ojciec mój zdziczał zupełnie. Jasne
było, że tego napięcia nienawiści żaden organizm długo wytrzymać nie
może. Straszliwa odraza zamieniała jego twarz w stężałą maskę tragiczną,
w której tylko źrenice, ukryte za dolną powieką, leżały na czatach,
napięte jak cięciwy, w wiecznej podejrzliwości. Z dzikim wrzaskiem
zrywał się nagle z siedzenia, leciał na oślep w kąt pokoju i już
podnosił dziryt, na którym utkwiony ogromny karakon przebierał
rozpaczliwie gmatwaniną swych nóg. Adela przychodziła wówczas blademu ze
zgrozy z pomocą i odbierała lancę wraz z utkwionym trofeum, ażeby ją
utopić w cebrzyku. Już wówczas jednak nie umiałbym był powiedzieć, czy
obrazy te zaszczepiły mi opowiadania Adeli, czy też sam byłem ich
świadkiem. Ojciec mój nie posiadał już wtedy tej siły odpornej, która
zdrowych ludzi broni od fascynacji wstrętu. Zamiast odgraniczyć się do
straszliwej siły atrakcyjnej tej fascynacji, ojciec mój, wydany na łup
szału, wplątywał się w nią coraz bardziej. Smutne skutki nie dały długo
na siebie czekać. Wnet pojawiły się pierwsze podejrzane znaki, które
napełniły nas przerażeniem i smutkiem. Zachowanie ojca zmieniło się.
Szał jego, euforia jego podniecenia przygasła. W ruchach i mimice jęły
się zdradzać znaki złego sumienia. Zaczął nas unikać. Krył się dzień
cały po kątach, w szafach, pod pierzyną. .Widziałem go nieraz, jak w
zamyśleniu oglądał własne ręce, badał konsystencję skóry, paznokci, na
których występować zaczęły czarne plamy, jak łuski karakona. W dzień
opierał się jeszcze ostatkami sił, walczył, ale w nocy fascynacja
uderzała nań potężnymi arakami. Widziałem go późną nocą, w świetle
świecy stojącej na podłodze. Mój ojciec leżał na ziemi nagi, popstrzony
czarnymi plamami totemu, pokreślony liniami żeber, fantastycznym
rysunkiem przeświecającej na zewnątrz anatomii, leżał na czworakach,
opętany fascynacją awersji, która go wciągała w głąb swych zawiłych
dróg. Mój ojciec poruszał się wieloczłonkowym, skomplikowanym ruchem
dziwnego rytuału, w którym ze zgrozą poznałem imitację ceremoniału
karakoniego. Od tego czasu wyrzekliśmy się ojca. Podobieństwo do
karakona występowało z dniem każdym wyraźniej - mój ojciec zamieniał się
w karakona. Zaczęliśmy się przyzwyczajać do tego. Widywaliśmy go coraz
rzadziej, całymi tygodniami znikał gdzieś na swych karakonich drogach - 
przestaliśmy go odróżniać, zlał się w zupełności z tym czarnym
niesamowitym plemieniem. Kto mógł powiedzieć, czy żył gdzieś jeszcze w
jakiejś szparze podłogi, czy przebiegał nocami pokoje, zaplątany w afery
karakonie, czy też był może między tymi martwymi owadami, które Adela co
rana znaj-dowała brzuchem do góry leżące i najeżone nogami i które ze
wstrętem brała na śmietniczkę i wyrzucała? - A jednak - powiedziałem
zdetonowany - jestem pewny, że ten kondor to on. - Matka spojrzała na
mnie spod rzęs: - Nie dręcz mnie, drogi - mówiłam ci już przecież, że
ojciec podróżuje jako komiwojażer po kraju - przecież wiesz, że czasem w
nocy przyjeżdża do domu, ażeby przed świtem jeszcze dalej odjechać.

WICHURA Tej długiej i pustej zimy obrodziła ciemność w naszym mieście
ogromnym, stokrotnym urodzajem. Zbyt długo snadź nie sprzątano na
strychach i w rupieciarniach, stłaczano garnki na garnkach i flaszki na
flaszkach, pozwalano narastać bez końca pustym bateriom butelek. Tam, w
tych spalonych, wielkobelkowych lasach strychów i dachów ciemność
zaczęła się wyradzać i dziko fermentować. Tam zaczęły się te czarne
sejmy garnków, te wiecowania gadatliwe i puste, te bełkotliwe
flaszkowania, bulgoty butli i baniek. Aż pewnej nocy wezbrały pod
gontowymi przestworami falangi garnków i flaszek i popłynęły wielkim
stłoczonym ludem na miasto. Strychy, wystrychnięte ze strychów,
rozprzestrzeniały się jedne z drugich i wystrzelały czarnymi szpalerami,
a przez przestronne ich echa przebiegały kawalkady tramów i belek,
lansady drewnianych kozłów, klękających na jodłowe kolana, ażeby
wypadłszy na wolność, napełnić przestwory nocy galopem krokwi i
zgiełkiem płatwi i bantów. Wtedy to wylały się te czarne rzeki, wędrówki
beczek i konwi, i płynęły przez noce. Czarne ich, połyskliwe, gwarne
zbiegowiska oblegały miasto. Nocami mrowił się ten ciemny zgiełk naczyń
i napierał jak armie rozgadanych ryb, niepowstrzymany najazd pyskujących
skopców i bredzących cebrów. Dudniąc dnami, piętrzyły się wiadra, beczki
i konwie, dyndały się gliniane stągwie zdunów, stare kapeluchy i
cylindry dandysów gramoliły się jedna na drugie, rosnąc w niebo
kolumnami, które się rozpadały. I wszystkie kołatały niezgrabnie kołkami
drewnianych języków, mełły nieudolnie w drewnianych gębach bełkot klątw
i obelg, bluźniąc błotem na całej przestrzeni nocy. Aż dobluźniły się,
doklęły swego. Przywołane rechotem naczyń, rozplotkowanym od brzegu do
brzegu, nadeszły wreszcie karawany, nadciągnęły potężne tabory wichru i
stanęły nad nocą. Ogromne obozowisko, czarny ruchomy amfiteatr zstępować
zaczął w potężnych kręgach ku miastu. I wybuchła ciemność ogromną
wzburzoną wichurą i szalała przez trzy dni i trzy noce... - Nie
pójdziesz dziś do szkoły - rzekła rano matka - jest straszna wichura na
dworze. - W pokoju unosił się delikatny welon dymu, pachnący żywicą. Piec
wył i gwizdał, jak gdyby uwiązana w nim była cała sfora psów czy
demonów. Wielki bohomaz, wymalowany na jego pękatym brzuchu, wykrzywiał
się kolorowym grymasem i fantastyczniał wzdętymi policzkami. Pobiegłem
boso do okna. Niebo wydmuchane było wzdłuż i wszerz wiatrami.
Srebrzystobiałe i przestronne, porysowane było w linie sił, natężone do
pęknięcia, w srogie bruzdy, jakby zastygłe żyły cyny i ołowiu.
Podzielone na pola energetyczne i drżące od napięć, pełne było utajonej
dynamiki. Rysowały się w nim diagramy wichury, która sama niewidoczna i
nieuchwytna, ładowała krajobraz potęgą. Nie widziało się jej. Poznawało
się ją po domach, po dachach, w które wjeżdżała jej furia. Jeden po
drugim strychy zdawały się rosnąć i wybuchać szaleństwem, gdy wstępowała
w nie jej siła. Ogałacała place, zostawiała za sobą na ulicach białą
pustkę, zamiatała całe połacie rynku do czysta. Ledwie tu i ówdzie giął
się pod nią i trzepotał, uczepiony węgła domu, samotny człowiek. Cały
plac rynkowy zdawał się wybrzuszać i lśnić pustą łysiną pod jej
potężnymi przelotami. Na niebie wydmuchał wiatr zimne i martwe kolory,
grynszpanowe, żółte i liliowe smugi, dalekie sklepienia i arkady swego
labiryntu. Dachy stały pod tymi niebami czarne i krzywe, pełne
niecierpliwości i oczekiwania. Te, w które wstąpił wicher, wstawały w
natchnieniu, przerastały sąsiednie domy i prorokowały pod rozwichrzonym
niebem. Potem opadały i gasły nie mogąc dłużej zatrzymać potężnego tchu,
który leciał dalej i napełniał cały przestwór zgiełkiem i przerażeniem.
I znów inne domy wstawały z krzykiem, w paroksyzmie jasnowidzenia, i
zwiastowały. Ogromne buki koło kościoła stały z wniesionymi rękami, jak
świadkowie wstrząsających objawień, i krzyczały, krzyczały. Dalej, za
dachami rynku, widziałem dalekie mury ogniowe, nagie ściany szczytowe
przedmieścia. Wspinały się jeden nad drugi i rosły, zesztywniałe z
przerażenia i osłupiałe. Daleki, zimny, czerwony odblask zabarwiał je
późnymi kolorami. Nie jedliśmy tego dnia obiadu, bo ogień w kuchni
wracał kłębami dymu do izby. W pokojach było zimno i pachniało wiatrem.
Około drugiej po południu wybuchł na przedmieściu pożar i rozszerzał się
gwałtownie. Matka z Adelą zaczęły pakować pościel, futra i kosztowności.
Nadeszła noc. Wicher wzmógł się na sile i gwałtowności, rozrósł się
niepomiernie i objął cały przestwór. Już teraz nie nawiedzał domów i
dachów, ale wybudował nad miastem wielopiętrowy, wielokrotny przestwór,
czarny labirynt, rosnący w nieskończonych kondygnacjach. Z tego
labiryntu wystrzelał całymi galeriami pokojów, wyprowadzał piorunem
skrzydła i trakty, toczył z hukiem długie amfilady, a potem dawał się
zapadać tym wyimaginowanym piętrom, sklepieniom i kazamatom i wzbijał
się jeszcze wyżej, kształtując sam bezforemny bezmiar swym natchnieniem.
Pokój drżał z lekka, obrazy na ścianach brzęczały. Szyby lśniły się
tłustym odblaskiem lampy. Firanki na oknie wisiały wzdęte i pełne
tchnienia tej burzliwej nocy. Przypomnieliśmy sobie, że ojca od rana nie
widziano. Wczesnym rankiem, domyślaliśmy się, musiał udać się do sklepu,
gdzie go zaskóczyła wichura, odcinając mu powrót. - Cały dzień nic nie
jadł - biadała matka. Starszy subiekt Teodor podjął się wyprawić w noc i
wichurę, żeby zanieść mu posiłek. Brat mój przyłączył się do wyprawy.
Okutani w wielkie niedźwiedzie futra, obciążyli kieszenie żelazkami i
moździerzami, balastem, który miał zapobiec porwaniu ich przez wichurę.
Ostrożnie otworzono drzwi prowadzące w noc. Zaledwie subiekt i brat mój
z wzdętymi płaszczami wkroczyli jedną nogą w ciemność, noc ich połknęła
zaraz na progu domu. Wicher zmył momentalnie ślad ich wyjścia. Nie widać
było przez okno nawet latarki, którą ze sobą zabrali. Pochłonąwszy ich,
wicher na chwilę przycichł. Adela z matką próbowały na nowo rozpalić
ogień pod kuchnią. Zapałki gasły, przez drzwiczki dmuchało popiołem i
sadzą. Staliśmy pod drzwiami i nasłuchiwali. W lamentach wichru dawały
się słyszeć wszelkie głosy, perswazje, nawoływania i gawędy. Zdawało się
nam, że słyszymy wołanie o pomoc ojca zabłąkanego w wichurze, to znowu,
że brat z Teodorem gwarzą beztrosko pod drzwiami. Wrażenie było tak
łudzące, że Adela otworzyła drzwi i w samej rzeczy ujrzała Teodora i
brata mego, wynurzających się z trudem z wichury, w której tkwili po
pachy. Weszli zdyszani do sieni, zaciskając z wysiłkiem drzwi za sobą.
Przez chwilę musieli wesprzeć się o odrzwia, tak silnie szturmował
wicher do bramy. Wreszcie zasunęli rygiel i wiatr pognał dalej.
Opowiadali bezładnie o nocy, o wichurze. Ich futra, nasiąkłe wiatrem,
pachniały teraz powietrzem. Trzepotali powiekami w świetle; ich oczy,
pełne jeszcze nocy, broczyły ciemnością za każdym uderzeniem powiek. Nie
mogli dojść do sklepu, zgubili drogę i ledwo trafili z powrotem. Nie
poznawali miasta, wszystkie ulice były jak przestawione. Matka
podejrzewała, że kłamali. W istocie cała ta scena sprawiała wrażenie,
jakby przez ten kwadrans stali w ciemności pod oknem, nie oddalając się
wcale. A może naprawdę nie było już miasta i rynku, a wicher i noc
otaczały nasz dom tylko ciemnymi kulisami, pełnymi wycia, świstu i
jęków. Może nie było wcale tych ogromnych i żałosnych przestrzeni, które
nam wicher sugerował, może nie było wcale tych opłakanych labiryntów,
tych wielookiennych traktów i korytarzy, na których grał wicher, jak na
długich czarnych fletach. Coraz bardziej umacniało się w nas
przekonanie, że cała ta burza była tylko donkiszoterią nocną, imitującą
na wąskiej przestrzeni kulis tragiczne bezmiary, kosmiczną bezdomność i
sieroctwo wichury. Coraz częściej otwierały się teraz drzwi sieni i
wpuszczały okutanego w opończe i szale gościa. Zziajany sąsiad lub
znajomy wywijał się powoli z chustek, płaszczy i wyrzucał z siebie
zdyszanym głosem opowiadania, urywane bezładne słowa, które
fantastycznie powiększały, kłamliwie przesadzały bezmiar nocy.
Siedzieliśmy wszyscy w jasno oświetlonej kuchni. Za ogniskiem kuchennym
i czarnym, szerokim okapem komina prowadziło parę stopni do drzwi
strychu. Na tych schodkach siedział starszy subiekt Teodor i
nasłuchiwał, jak strych grał od wichru. Słyszał, jak w pauzach wichury
miechy żeber strychowych składały się w fałdy i dach wiotczał i zwisał
jak ogromne płuca, z których uciekł oddech, to znowu nabierał tchu,
nastawiał się palisadami krokwi, rósł jak sklepienia gotyckie,
rozprzestrzeniał się lasem belek, pełnym stokrotnego echa, i huczał jak
pudło ogromnych basów. Ale potem zapominaliśmy o wichurze, Adela tłukła
cynamon w dźwięcznym moździerzu. Ciotka Perazja przyszła w odwiedziny.
Drobna, ruchliwa i pełna zabiegliwości, z koronką czarnego szala na
głowie, zaczęła krzątać się po kuchni, pomagając Adeli. Adela oskubała
koguta. Ciotka Perazja zapaliła pod okapem komina garść papierów i
szerokie płaty płomienia wzlatywały z nich w czarną czeluść. Adela,
trzymając koguta za szyję, uniosła go nad płomień, ażeby opalić na nim
resztę pierza. Kogut zatrzepotał nagle w ogniu skrzydłami, zapiał i
spłonął. Wtedy ciotka Perazja zaczęła się kłócić, kląć i złorzeczyć.
Trzęsąc się ze złości, wygrażała rękami Adeli i matce. Nie rozumiałem, o
co jej chodzi, a ona zacietrzewiała się coraz bardziej w gniewie i stała
się jednym pękiem gestykulacji i złorzeczeń. Zdawało się, że w
paroksyzmie złości rozgestykuluje się na części, że rozpadnie się,
podzieli, rozbiegnie w sto pająków, rozgałęzi się po podłodze czarnym,
migotliwym pękiem oszalałych karakonach biegów. Zamiast tego zaczęła
raptownie maleć, kurczyć się, wciąż roztrzęsiona i rozsypująca się
przekleństwami. Z nagła podreptała, zgarbiona i mała, w kąt kuchni,
gdzie leżały drwa na opał i, klnąc i kaszląc, zaczęła gorączkowo
przebierać wśród dźwięcznych drewien, aż znalazła dwie cienkie, żółte
drzazgi. Pochwyciła je latającymi ze wzburzenia rękami, przymierzyła do
nóg, po czym wspięła się na nie, jak na szczudła, i zaczęła na tych
żółtych kulach chodzić, stukocąc po deskach, biegać tam i z powrotem
wzdłuż skośnej linii podłogi, coraz szybciej i szybciej, potem wbiegła
na ławkę jodłową, kuśtykając na dudniących deskach, a stamtąd na półkę z
talerzami, dźwięczną, drewnianą półkę obiegającą ściany kuchni, i biegła
po niej, kolankując na szczudłowych kulach, by wreszcie gdzieś w kącie,
malejąc coraz bardziej, sczernieć, zwinąć się jak zwiędły, spalony
papier, zetlić się w płatek popiołu, skruszyć w proch i w nicość.
Staliśmy wszyscy bezradni wobec tej szalejącej furii złości, która sama
siebie trawiła i pożerała. Z ubolewaniem patrzyliśmy na smutny przebieg
tego paroksyzmu i z pewną ulgą wróciliśmy do naszych zajęć, gdy żałosny
ten proces dobiegł swego naturalnego końca. Adela zadzwoniła znowu
moździerzem, tłukąc cynamon, matka ciągnęła dalej przerwaną rozmowę, a
subiekt Teodor, nasłuchując proroctw strychowych, stroił śmieszne
grymasy, podnosił wysoko brwi i śmiał się do siebie.

NOC WIELKIEGO SEZONU Każdy wie, że w szeregu zwykłych, normalnych lat
rodzi niekiedy zdziwaczały czas ze swego łona lata inne, lata osobliwe,
lata wyrodne, którym - jak szósty, mały palec u ręki - wyrasta kędyś
trzynasty, fałszywy miesiąc. Mówimy fałszywy, gdyż rzadko dochodzi on do
pełnego rozwoju. Jak dzieci późno spłodzone, pozostaje on w tyle ze
wzrostem, miesiąc garbusek, odrośl w połowie uwiędła i raczej domyślna
niż rzeczywista. Winna jest temu starcza niepowściągliwość lata, jego
rozpustna i późna żywotność. Bywa czasem, że sierpień minie, a stary
gruby pień lata rodzi z przyzwyczajenia jeszcze dalej, pędzi ze swego
próchna te dni-dziczki, dni-chwasty, jałowe i idiotyczne, dorzuca na
dokładkę, za darmo, dni-kaczany, puste i niejadalne - dni białe,
zdziwione i niepotrzebne. Wyrastają one, nieregularne i nierówne, nie
wykształcone i zrośnięte z sobą, jak palce potworkowatej ręki,
pączkujące i zwinięte w figę. Inni porównywają te dni do apokryfów,
wsuniętych potajemnie między rozdziały wielkiej księgi roku, do
palimpsestów, skrycie włączonych pomiędzy jej stronice, albo do tych
białych nie zadrukowanych kartek, na których oczy, naczytane do syta i
pełne treści, broczyć mogą obrazami i gubić kolory na tych pustych
stronicach, coraz bladziej i bladziej, ażeby wypocząć na ich nicości,
zanim wciągnięte zostaną w labirynty nowych przygód i rozdziałów. Ach,
ten stary, pożółkły romans roku, ta wielka, rozpadająca się księga
kalendarza! Leży ona sobie zapomniana gdzieś w archiwach czasu, a treść
jej rośnie dalej między okładkami, pęcznieje bez ustanku od gadulstwa
miesięcy, od szybkiego samorództwa blagi, od bajania i marzeń, które się
w niej mnożą. Ach, i spisując te nasze opowiadania, szeregując te
historie o moim ojcu na zużytym marginesie jej tekstu, czy nie oddaję
się tajnej nadziei, że wrosną one kiedyś niepostrzeżenie między zżółkłe
kartki tej najwspanialszej, rozsypującej się księgi, że wejdą w wielki
szelest jej stronic, który je pochłonie? To, o czym tu mówić będziemy,
działo się tedy w owym trzynastym, nadliczbowym i niejako fałszywym
miesiącu tego roku, na tych kilkunastu pustych kartkach wielkiej kroniki
kalendarza. Ranki były podówczas dziwnie cierpkie i orzeźwiające. Po
uspokojonym i chłodniejszym tempie czasu, po nowym całkiem zapachu
powietrza, po odmiennej konsystencji światła poznać było, że weszło się
w inną serię dni, w nową okolicę Bożego Roku. Głos drżał pod tymi nowymi
niebami dźwięcznie i świeżo jak w nowym jeszcze i pustym mieszkaniu,
pełnym zapachu lakieru, farb, rzeczy zaczętych i nie wypróbowanych. Z
dziwnym wzruszeniem próbowało się nowego echa, napoczynało się je z
ciekawością, jak w chłodny i trzeźwy poranek babkę do kawy w przeddzień
podróży. Ojciec mój siedział znowu w tylnym kontuarze sklepu, w małej,
sklepionej izbie, pokratkowanej jak ul w wielokomórkowe registratury i
łuszczącej się bez końca warstwami papieru, listów i faktur. Z szelestu
arkuszy, z nieskończonego kartkowania papierów wyrastała kratkowana i
pusta egzystencja tego pokoju, z nieustannego przekładania plików
odnawiała się w powietrzu z niezliczonych nagłówków firmowych apoteoza w
formie miasta fabrycznego, widzianego z lotu ptaka, najeżonego dymiącymi
kominami, otoczonego rzędami medali i ujętego w wywijasy i zakręty
pompatycznych et i Comp. Tam siedział ojciec, jak w ptaszarni, na
wysokim stołku, a gołębniki registratur szeleściły plikami papierów i
wszystkie gniazda i dziuple pełne były świergotu cyfr. Głąb wielkiego
sklepu ciemniała i wzbogacała się z dnia na dzień zapasami sukna,
szewiotów, aksamitów i kortów. W ciemnych półkach, tych spichrzach i
lamusach chłodnej, pilśniowej barwności, procentowała stokrotnie ciemna,
odstała korowość rzeczy, mnożył się i sycił potężny kapitał jesieni. Tam
rósł i ciemniał ten kapitał i rozsiadał się coraz szerzej na półkach,
jak na galeriach jakiegoś wielkiego teatru, uzupełniając się jeszcze i
pomnażając każdego rana nowymi ładunkami towaru, który w skrzyniach i
pakach wraz z rannym chłodem wnosili na niedźwiedzich barach stękający,
brodaci tragarze w oparach świeżości jesiennej i wódki. Subiekci
wyładowywali te nowe zapasy sycących bławatnych kolorów i wypełniali
nimi, kitowali starannie wszystkie szpary i luki wysokich szaf. Był to
rejestr olbrzymi wszelakich kolorów jesieni, ułożony warstwami,
usortowany odcieniami, idący w dół i w górę, jak po dźwięcznych
schodach, po gamach wszystkich oktaw barwnych. Zaczynał się u dołu i
próbował jękliwie i nieśmiało altowych spełzłości i półtonów,
przechodził potem do spłowiałych popiołów dali, do gobelinowych błękitów
i rosnąc ku górze coraz szerszymi akordami, dochodził do ciemnych
granatów, do indyga lasów dalekich i do pluszu parków szumiących, ażeby
potem poprzez wszystkie ochry, sangwiny, rudości i sepie wejść w
szelestny cień więdnących ogrodów i dojść do ciemnego zapachu grzybów,
do tchnienia próchna w głębiach nocy jesiennej i do głuchego
akompaniamentu najciemniejszych basów. Ojciec mój szedł wzdłuż tych
arsenałów sukiennej jesieni i uspokajał i uciszał te masy, ich
wzbierającą moc, spokojną potęgę Pory. Chciał jak najdłużej utrzymać w
całości te rezerwy zamagazynowanej barwności. Bał się łamać, wymieniać
na gotówkę ten fundusz żelazny jesieni. Ale wiedział, czuł, że przyjdzie
czas i wicher jesienny, pustoszący i ciepły wicher, powieje nad tymi
szafami i wtedy puszczą one i nic nie zdoła powstrzymać ich wylewu, tych
strumieni kolorowości, którymi wybuchną na miasto całe. Przychodziła
pora Wielkiego Sezonu. Ożywiały się ulice. O szóstej godzinie po
południu miasto zakwitało gorączką, domy dostawały wypieków, a ludzie
wędrowali ożywieni jakimś wewnętrznym ogniem, naszminkowani i ubarwieni
jaskrawo, z oczyma błyszczącymi jakąś odświętną, piękną i złą febrą. Na
bocznych uliczkach, w cichych zaułkach, uchodzących już w wieczorną
dzielnicę, miasto było puste. Tylko dzieci bawiły się na placykach pod
balkonami, bawiły się bez tchu, hałaśliwie i niedorzecznie. Przykładały
małe pęcherzyki do ust, ażeby wydmuchać je i naindyczyć się nagle
jaskrawo w wielkie, gulgocące, rozpluskane narośle albo wykogucić się w
głupią kogucią maskę, czerwoną i piejącą, w kolorowe jesienne maszkary
fantastyczne i absurdalne. Zdawało się, że tak nadęte i piejące wzniosą
się w powietrze długimi kolorowymi łańcuchami i jak jesienne klucze
ptaków przeciągać będą nad miastem - fantastyczne flotylle z bibułki i
pogody jesiennej. Albo woziły się wśród krzyków na małych zgiełkliwych
wózkach, grających kolorowym turkotem kółek, szprych i dyszli. Wózki
zjeżdżały naładowane ich krzykiem i staczały się w dół ulicy aż do nisko
rozlanej, żółtej rzeczki wieczornej, gdzie rozpadały się na gruz
krążków, kołków i patyczków. I podczas gdy zabawy dzieci stawały się
coraz bardziej hałaśliwe i splątane, wypieki miasta ciemniały i
zakwitały purpurą, nagle świat cały zaczynał więdnąć i czernieć i szybko
wydzielał się zeń majaczliwy zmierzch, którym zarażały się wszystkie
rzeczy. Zdradliwie i jadowicie szerzyła się ta zaraza zmierzchu wokoło,
szła od rzeczy do rzeczy, a czego dotknęła, to wnet butwiało, czerniało,
rozpadało się w próchno. Ludzie uciekali przed zmierzchem w cichym
popłochu i naraz dosięgał ich ten trąd, i wysypywał się ciemną wysypką
na czole, i tracili twarze, które odpadały wielkimi, bezkształtnymi
plamami, i szli dalej, już bez rysów, bez oczu, gubiąc po drodze maskę
po masce, tak że zmierzch roił się od tych larw porzuconych, sypiących
się za ich ucieczką. Potem zaczynało wszystko zarastać czarną,
próchniejącą korą, łuszczącą się wielkimi płatami, chorymi strupami
ciemności. A gdy w dole wszystko rozprzęgło się i szło wniwecz w tej
cichej zamieszce, w panice prędkiego rozkładu, w górze utrzymywał się i
rósł coraz wyżej milczący alarm zorzy, drgający świergotem miliona
cichych dzwonków, wzbierających wzlotem miliona cichych skowronków
lecących razem w jedną wielką, srebrną nieskończoność. Potem była już
nagle noc - wielka noc, rosnąca jeszcze podmuchami wiatru, które ją
rozszerzały. W jej wielokrotnym labiryncie wyłupane były gniazda jasne:
sklepy - wielkie, kolorowe latarnie, pełne spiętrzonego towaru i zgiełku
kupujących. Przez jasne szyby tych latani można było śledzić zgiełkliwy
i pełen dziwacznego ceremoniału obrzęd zakupów jesiennych. Ta wielka,
fałdzista noc jesienna, rosnąca cieniami, roszerzona wiatrami, kryła w
swych ciemnych fałdach jasne kieszenie, woreczki z kolorowym
drobiazgiem, z pstrym towarem czekoladek, keksów, kolonialnej
pstrokacizny. Te budki i kramiki, sklecone z pudełek po cukrach,
wytapetowane jaskrawo reklamami czekolad, pełne mydełek, wesołej
tandety, złoconych błahostek, cynfolii, trąbek, andrutów i kolorowych
miętówek, były stacjami lekkomyślności, grzechotkami beztroski,
rozsianymi na wiszarach ogromnej, labiryntowej, rozłopotanej wiatrami
nocy. Wielkie i ciemne tłumy płynęły w ciemności, w hałaśliwym
zmieszaniu, w szurgocie tysięcy nóg, w gwarze tysięcy ust - rojna,
splątana wędrówka, ciągnąca arteriami jesiennego miasta. Tak płynęła ta
rzeka, pełna gwaru, ciemnych spojrzeń, chytrych łypnięć, pokawałkowana
rozmową, posiekana gawędą, wielka miazga plotek, śmiechów i zgiełku.
Zdawało się, że to ruszyły tłumami jesienne, suche makówki sypiące
makiem - głowygrzechotki, ludzie-kołatki. Mój ojciec chodził
zdenerwowany i kolorowy od wypieków, z błyszczącymi oczyma, w jasno
oświetlonym sklepie, i nasłuchiwał. Przez szyby wystawy i portalu
dochodził tu z daleka szum miasta, stłumiony gwar płynącej ciżby. Nad
ciszą sklepu płonęła jasno lampa naftowa, zwisająca z wielkiego
sklepienia, i wypierała najmniejszy ślad cienia z wszystkich szpar i
zakamarków. Pusta, wielka podłoga trzaskała w ciszy i liczyła w tym
świetle wzdłuż i wszerz swe błyszczące kwadraty, szachownicę wielkich
tafli, które rozmawiały ze sobą w ciszy trzaskami, odpowiadały sobie to
tu, to tam głośnym pęknięciem. Za to sukna leżały ciche, bez głosu, w
swej pilśniowej puszystości i podawały sobie wzdłuż ścian spojrzenia za
plecami ojca, wymieniały od szafy do szafy ciche znaki porozumiewawcze.
Ojciec nasłuchiwał. Jego ucho zdawało się w tej ciszy nocnej wydłużać i
rozgałęziać poza okno: fantastyczny koralowiec, czerwony polip falujący
w mętach nocy. Nasłuchiwał i słyszał. Słyszał z rosnącym niepokojem
daleki przypływ tłumów, które nadciągały. Rozglądał się z przerażeniem
po pustym sklepie. Szukał subiektów. Ale ci ciemni i rudzi aniołowie
dokądś odlecieli. Pozostał on sam tylko, w trwodze przed tłuma-mi, które
wnet miały zalać ciszę sklepu plądrującą hałaśliwą rzeszą i rozebrać
między siebie, rozlicytować całą tę bogatą jesień, od lat zbieraną w
wielkim zacisznym spichlerzu. Gdzie byli subiekci? Gdzie były te
urodziwe cheruby, mające bronić ciemnych, sukiennych szańców? Ojciec
podejrzewał bolesną myślą, że oto grzeszą gdzieś w głębi domu z córami
ludzi. Stojąc nieruchomy i pełen troski, z błyszczącymi oczyma w jasnej
ciszy sklepu, czuł wewnętrznym słuchem, co działo się w głębi domu, w
tylnych komorach wielkiej kolorowej tej latarni. Dom otwierał się przed
nim, izba za izbą, komora za komorą, jak dom z kart, i widział gonitwę
subiektów za Adelą przez wszystkie puste i jasno oświetlone pokoje,
schodami na dół, schodami do góry, aż wymknęła się im i wpadła do jasnej
kuchni, gdzie zabarykadowała się kuchennym kredensem. Tam stała
zdyszana, błyszcząca i rozbawiona, trzepocąca z uśmiechem wielkimi
rzęsami. Subiekci chichotali, przykucnięci pode drzwiami. Okno kuchni
otwarte było na wielką, czarną noc, pełną rojeń i splątania. Czarne,
uchylone szyby płonęły refleksem dalekiej iluminacji. Błyszczące garnki
i butle stały nieruchomo dokoła i lśniły w ciszy tłustą polewą. Adela
wychylała ostrożnie przez okno swą kolorową, uszminkowaną twarz z
trzepoczącymi oczyma. Szukała subiektów na ciemnym podwórzu, pewna ich
zasadzki. I oto ujrzała ich, jak wędrowali ostrożnie, gęsiego, po wąskim
gzymsie podokiennym wzdłuż ściany piętra, czerwonej odblaskiem dalekiej
iluminacji, i skradali się do okna. Ojciec krzyknął z gniewu i rozpaczy,
ale w tej chwili gwar głosów stał się całkiem bliski i nagle jasne okna
sklepu zaludniły się bliskimi twarzami, wykrzywionymi śmiechem,
rozgadanymi twarzami, które płaszczyły nosy na lśniących szybach. Ojciec
stał się purpurowy ze wzburzenia i wskoczył na ladę. I kiedy tłum
szturmem zdobywał tę twierdzę i wkraczał hałaśliwą ciżbą do sklepu,
ojciec mój jednym skokiem wspiął się na półki z suknem i, uwisły wysoko
nad tłumem, dął z całej siły w wielki puzon z rogu i trąbił na alarm.
Ale sklepienie nie napełniło się szumem aniołów, śpieszących na pomoc, a
zamiast tego każdemu jękowi trąby odpowiadał wielki, roześmiany chór
tłumu. - Jakubie, handlować! Jakubie, sprzedawać! - wołali wszyscy, a
wołanie to, wciąż powtarzane, rytmizowało się w chórze i przechodziło
powoli w melodię refrenu, śpiewaną przez wszystkie gardła. Wtedy mój
ojciec dał za wygraną, zeskoczył z wysokiego gzymsu i ruszył z krzykiem
ku barykadom sukna. Wyolbrzymiony gniewem, z głową spęczniałą w pięść
purpurową, wbiegł, jak walczący prorok, na szańce sukienne i jął
przeciwko nim szaleć. Wpierał się całym ciałem w potężne bale wełny i
wyważał je z osady, podsuwał się pod ogromne postawy sukna i unosił je
na ladę z głuchym łomotem. Bale leciały rozwijając się z łopotem w
powietrzu w ogromne chorągwie, półki wybuchały zewsząd wybuchami
draperii, wodospadami sukna, jak pod uderzeniem Mojżeszowej laski. Tak
wylewały się zapasy szaf, wymiotowały gwałtownie, płynęły szerokimi
rzekami. Wypływała barwna treść półek, rosła, mnożyła się i zalewała
wszystkie lady i stoły. Ściany sklepu znikły pod potężnymi formacjami
tej sukiennej kosmogonii, pod tymi pasmami górskimi, piętrzącymi się w
potężnych masywach. Otwierały się szerokie doliny wśród zboczy górskich
i wśród szerokiego patosu wyżyn grzmiały linie kontynentów. Przestrzeń
sklepu rozszerzyła się w panoramę jesiennego krajobrazu, pełną jezior i
dali, a na tle tej scenerii ojciec wędrował wśród fałd i dolin
fantastycznego Kanaanu, wędrował wielkimi krokami, z rękoma
rozkrzyżowanymi proroczo w chmurach, i kształtował kraj uderzeniami
natchnienia. A u dołu, u stóp tego Synaju, wyrosłego z gniewu ojca,
gestykulował lud, złorzeczył i czcił Baala, i handlował. Nabierali pełne
ręce miękkich fałd, drapowali się w kolorowe sukna, owijali się w
zaimprowizowane domina i płaszcze i gadali bezładnie a obficie. Mój
ojciec wyrastał nagle nad tymi grupami kupczących wydłużonych gniewem, i
gromił z wysoka bałwochwalców potężnym słowem. Potem, ponoszony
rozpaczą, wspinał się na wysokie galerie szaf, biegł obłędnie po bantach
półek, po dudniących deskach ogołoconych rusztowań, ścigany przez obrazy
bezwstydnej rozpusty, którą przeczuwał za plecami w głębi domu. Subiekci
dosięgli właśnie żelaznego balkonu na wysokości okna i wczepieni w
balustradę, pochwycili wpół Adelę i wyciągnęli ją przez okno,
trzepocącą. oczyma i wlokącą za sobą smukłe nogi w jedwabnych
pończochach. Gdy ojciec mój, przerażony ohydą grzechu, wrastał gniewem
swych gestów w grozę krajobrazu, w dole beztroski lud Baala oddawał się
wyuzdanej wesołości. Jakaś parodystyczna pasja, jakaś zaraza śmiechu
opanowała tę gawiedź. Jakże można było żądać powagi od nich, od tego
ludu kołatek i dziadków do orzechów! Jak można było żądać zrozumienia
dla wielkich trosk ojca od tych młynków, mielących bezustannie kolorową
miazgę słów! Głusi na gromy proroczego gniewu, przykucali ci handlarze w
jedwabnych bekieszach małymi kupkami dookoła sfałdowanych gór materii,
rozstrząsając gadatliwie wśród śmiechu zalety towaru. Ta czarna giełda
roznosiła na swych prędkich językach szlachetną substancję krajobrazu,
rozdrabniała ją siekaniną gadania i połykała niemal. Gdzie indziej stały
grupy Żydów w kolorowych chałatach, w wielkich futrzanych kołpakach
przed wysokimi wodospadami jasnych materii. Byli to mężowie Wielkiego
Zgromadzenia, dostojni i pełni namaszczenia panowie, gładzący długie,
pielęgnowane brody i prowadzący wstrzemięźliwe i dyplomatyczne rozmowy.
Ale i w tej ceremonialnej konwersacji, w spojrzeniach, które wymieniali
był błysk uśmiechniętej ironii. Wśród tych grup przewijał się pospolity
lud, bezpostaciowy tłum, gawiedź bez twarzy i indywidualności. Wypełniał
on niejako luki w krajobrazie, wyścielał tło dzwonkami i grzechotkami
bezmyślnego gadania. Był to element błazeński, roztańczony tłum
poliszynelów i arlekinów, który - sam bez poważnych intencyj handlowych
- doprowadzał do absurdu gdzieniegdzie nawiązujące się tansakcje swymi
błazeńskimi figlami. Stopniowo jednak, znudzony błaznowaniem, wesoły ten
ludek rozpraszał się w dalszych okolicach krajobrazu i tam powoli gubił
się wśród skalnych załomów i dolin. Prawdopodobnie jeden po drugim
zapadały się te wesołki gdzieś w szczeliny i fałdy terenu, jak dzieci
zmęczone zabawą po kątach i zakamarkach mieszkania w noc balową.
Tymczasem ojcowie miasta, mężowie Wielkiego Synhedrionu, przechadzali
się w grupach pełnych powagi i godności i prowadzili ciche, głębokie
dysputy. Rozszedłszy się po całym, owym wielkim górzystym kraju,
wędrowali po dwóch, po trzech na dalekich i krętych drogach. Małe i
ciemne ich sylwety zaludniały całą tę pustynną wyżynę, nad którą zwisło
ciężkie i ciemne niebo, sfałdowane i chmurne, poorane w długie
równoległe bruzdy, w srebrne i białe skiby, ukazujące w głębi coraz
dalsze pokłady swego uwarstwienia. Światło lampy stwarzało sztuczny
dzień w owej krainie - dzień dziwny, dzień bez świtu i wieczoru. Ojciec
mój uspokajał się powoli. Gniew jego układał się i zastygał w pokładach
i warstwach krajobrazu. Siedział teraz na galeriach wysokich półek i
patrzył w jesienniejący, rozległy kraj. Widział, jak na dalekich
jeziorach odbywał się połów ryb. W maleńkich łupinkach łódek siedziało
po dwóch rybaków, zapuszczając sieci w wodę. Na brzegach chłopcy
dźwigali na głowach kosze, pełne trzepocącego się, srebrnego połowu.
Wówczas to dostrzegł, jak grupy wędrowców w oddali zadzierały głowy ku
niebu, wskazując coś wzniesionymi rękami. I wnet zaroiło się niebo jakąś
kolorową wysypką, osypało się falującymi plamami, które rosły,
dojrzewały i wnet napełniły przestworze dziwnym ludem ptaków, krążących
i kołujących w wielkich, krzyżujących się spiralach. Całe niebo
wypełniło się ich wzniosłym lotem, łopotem skrzydeł, majestatycznymi
liniami cichych bujań. Niektóre z nich jak ogromne bociany płynęły
nieruchomo na spokojnie rozpostartych skrzydłach, inne, podobne do
kolorowych pióropuszów, do barbarzyńskich trofeów, trzepotały ciężko i
niezgrabnie, ażeby utrzymać się na falach ciepłej aury; inne wreszcie,
nieudolne konglomeraty skrzydeł, potężnych nóg i oskubanych szyj,
przypominały źle wypchane sępy i kondory, z których wysypują się
trociny. Były między nimi ptaki dwugłowe, ptaki wieloskrzydłe, były też
i kaleki, kulejące w powietrzu jednoskrzydłym, niedołężnym lotem. Niebo
stało się podobne do starego fresku, pełnego dziwolągów i fantastycznych
zwierząt, które krążyły, wymijały się i znów wracały w kolorowych
elipsach. Mój ojciec podniósł się na bantach, oblany nagłym blaskiem,
wyciągnął ręce, przyzywając ptaki starym zaklęciem. Poznał je, pełen
wzruszenia. Było to dalekie, zapomniane potomstwo tej ptasiej generacji,
którą ongi Adela rozpędziła na wszystkie strony nieba. Wracało teraz,
zwyrodniałe i wybujałe, to sztuczne potomstwo, to zdegenerowane plemię
ptasie, zmarniałe wewnętrznie. Wystrzelone głupio wzrostem, wyogromnione
niedorzecznie, było wewnątrz puste i bez życia. Cała żywotność tych
ptaków przeszła w upierzenie, wybujała w fantastyczność. Było to jakby
muzeum wycofanych rodzajów, rupieciarnia Raju ptasiego. Niektóre latały
na wznak, miały ciężkie, niezgrabne dzioby, podobne do kłódek i zamków,
obciążone kolorowymi naroślami, i były ślepe. Jakże wzruszył ojca ten
powrót niespodziany, jakże zdumiewał się nad instynktem ptasim, nad tym
przywiązaniem do Mistrza, które wygnany ów ród piastował jak legendę w
duszy, ażeby wreszcie po wielu generacjach, w ostatnim dniu przed
wygaśnięciem plemienia pociągnąć z powrotem w pradawną ojczyznę. Ale te
papierowe, ślepe ptaki nie mogły już poznać ojca. Na darmo wołał na nie
dawnym zaklęciem, zapomnianą mową ptasią, nie słyszały go i nie
widziały. Nagle zagwizdały kamienie w powietrzu. To wesołki, głupie i
bezmyślne plemię, jęły celować pociskami w fantastyczne niebo ptasie. Na
darmo ojciec ostrzegał, na darmo groził zaklinającymi gestami, nie
dosłyszano go, nie dostrzeżono. I ptaki spadały. Ugodzone pociskiem,
obwisały ciężko i więdły już w powietrzu. Nim doleciały do ziemi, były
już bezforemną kupą pierza. W mgnieniu oka pokryła się wyżyna tą dziwną,
fantastyczną padliną. Zanim ojciec dobiegł do miejsca rzezi, cały ten
świetny ród ptasi już leżał martwy, rozciągnięty na skałach. Teraz
dopiero, z bliska, mógł ojciec obserwować całą lichotę tej zubożałej
generacji, całą śmieszność jej tandetnej anatomii. Były to ogromne
wiechcie piór, wypchane byle jak starym ścierwem. U wielu nie można było
wyróżnić głowy, gdyż pałkowata ta część ciała nie nosiła żadnych znamion
duszy. Niektóre pokryte były kudłatą, zlepioną sierścią, jak żubry, i
śmierdziały wstrętnie. Inne przypominały garbate, łyse, zdechłe
wielbłądy. Inne wreszcie były najwidoczniej z pewnego rodzaju papieru,
puste w środku, a świetnie kolorowe na zewnątrz. Niektóre okazywały się
z bliska niczym innym jak wielkimi pawimi ogonami, kolorowymi
wachlarzami, w które niepojętym sposobem tchnięto jakiś pozór życia.
Widziałem smutny powrót mego ojca. Sztuczny dzień zabarwiał się już
powoli kolorami zwyczajnego poranka. W spustoszałym sklepie najwyższe
półki syciły się barwami rannego nieba. Wśród fragmentów zgasłego
pejzażu, wśród zburzonych kulis nocnej scenerii - ojciec widział
wstających ze snu subiektów. Podnosili się spomiędzy bali sukna i
ziewali do słońca. W kuchni, na piętrze, Adela, ciepła od snu i ze
zmierzwionymi włosami, mełła kawę na młynku, przyciskając go do białej
piersi, od której ziarna nabierały blasku i gorąca. Kot mył się w
EOT;

    /*
    End of the Project Gutenberg EBook of Sklepy cynamonowe, by Bruno Schulz

    *** END OF THE PROJECT GUTENBERG EBOOK SKLEPY CYNAMONOWE ***

    This file should be named sklep10.txt or sklep10.zip
    Corrected EDITIONS of our eBooks get a new NUMBER, sklep11.txt
    VERSIONS based on separate sources get new LETTER, sklep10a.txt

    Produced by Pawel Sobkowiak - Scanned and proofread by
    Polska Biblioteka Internetowa

    Project Gutenberg eBooks are often created from several printed
    editions, all of which are confirmed as Public Domain in the US
    unless a copyright notice is included.  Thus, we usually do not
    keep eBooks in compliance with any particular paper edition.

    We are now trying to release all our eBooks one year in advance
    of the official release dates, leaving time for better editing.
    Please be encouraged to tell us about any error or corrections,
    even years after the official publication date.

    Please note neither this listing nor its contents are final til
    midnight of the last day of the month of any such announcement.
    The official release date of all Project Gutenberg eBooks is at
    Midnight, Central Time, of the last day of the stated month.  A
    preliminary version may often be posted for suggestion, comment
    and editing by those who wish to do so.

    Most people start at our Web sites at:
    http://gutenberg.net or
    http://promo.net/pg

    These Web sites include award-winning information about Project
    Gutenberg, including how to donate, how to help produce our new
    eBooks, and how to subscribe to our email newsletter (free!).

    Those of you who want to download any eBook before announcement
    can get to them as follows, and just download by date.  This is
    also a good way to get them instantly upon announcement, as the
    indexes our cataloguers produce obviously take a while after an
    announcement goes out in the Project Gutenberg Newsletter.

    http://www.ibiblio.org/gutenberg/etext03 or
    ftp://ftp.ibiblio.org/pub/docs/books/gutenberg/etext03

    Or /etext02, 01, 00, 99, 98, 97, 96, 95, 94, 93, 92, 92, 91 or 90

    Just search by the first five letters of the filename you want,
    as it appears in our Newsletters.

    Information about Project Gutenberg (one page)

    We produce about two million dollars for each hour we work.  The
    time it takes us, a rather conservative estimate, is fifty hours
    to get any eBook selected, entered, proofread, edited, copyright
    searched and analyzed, the copyright letters written, etc.   Our
    projected audience is one hundred million readers.  If the value
    per text is nominally estimated at one dollar then we produce $2
    million dollars per hour in 2002 as we release over 100 new text
    files per month:  1240 more eBooks in 2001 for a total of 4000+
    We are already on our way to trying for 2000 more eBooks in 2002
    If they reach just 1-2% of the world's population then the total
    will reach over half a trillion eBooks given away by year's end.

    The Goal of Project Gutenberg is to Give Away 1 Trillion eBooks!
    This is ten thousand titles each to one hundred million readers,
    which is only about 4% of the present number of computer users.

    Here is the briefest record of our progress (* means estimated):

    eBooks Year Month

        1  1971 July
       10  1991 January
      100  1994 January
     1000  1997 August
     1500  1998 October
     2000  1999 December
     2500  2000 December
     3000  2001 November
     4000  2001 October/November
     6000  2002 December*
     9000  2003 November*
    10000  2004 January*

    The Project Gutenberg Literary Archive Foundation has been created
    to secure a future for Project Gutenberg into the next millennium.

    We need your donations more than ever!

    As of February, 2002, contributions are being solicited from people
    and organizations in: Alabama, Alaska, Arkansas, Connecticut,
    Delaware, District of Columbia, Florida, Georgia, Hawaii, Illinois,
    Indiana, Iowa, Kansas, Kentucky, Louisiana, Maine, Massachusetts,
    Michigan, Mississippi, Missouri, Montana, Nebraska, Nevada, New
    Hampshire, New Jersey, New Mexico, New York, North Carolina, Ohio,
    Oklahoma, Oregon, Pennsylvania, Rhode Island, South Carolina, South
    Dakota, Tennessee, Texas, Utah, Vermont, Virginia, Washington, West
    Virginia, Wisconsin, and Wyoming.

    We have filed in all 50 states now, but these are the only ones
    that have responded.

    As the requirements for other states are met, additions to this list
    will be made and fund raising will begin in the additional states.
    Please feel free to ask to check the status of your state.

    In answer to various questions we have received on this:

    We are constantly working on finishing the paperwork to legally
    request donations in all 50 states.  If your state is not listed and
    you would like to know if we have added it since the list you have,
    just ask.

    While we cannot solicit donations from people in states where we are
    not yet registered, we know of no prohibition against accepting
    donations from donors in these states who approach us with an offer to
    donate.

    International donations are accepted, but we don't know ANYTHING about
    how to make them tax-deductible, or even if they CAN be made
    deductible, and don't have the staff to handle it even if there are
    ways.

    Donations by check or money order may be sent to:

    Project Gutenberg Literary Archive Foundation
    PMB 113
    1739 University Ave.
    Oxford, MS 38655-4109

    Contact us if you want to arrange for a wire transfer or payment
    method other than by check or money order.

    The Project Gutenberg Literary Archive Foundation has been approved by
    the US Internal Revenue Service as a 501(c)(3) organization with EIN
    [Employee Identification Number] 64-622154.  Donations are
    tax-deductible to the maximum extent permitted by law.  As fund-raising
    requirements for other states are met, additions to this list will be
    made and fund-raising will begin in the additional states.

    We need your donations more than ever!

    You can get up to date donation information online at:

    http://www.gutenberg.net/donation.html

    ***

    If you can't reach Project Gutenberg,
    you can always email directly to:

    Michael S. Hart <hart@pobox.com>

    Prof. Hart will answer or forward your message.

    We would prefer to send you information by email.


    **The Legal Small Print**


    (Three Pages)

    ***START**THE SMALL PRINT!**FOR PUBLIC DOMAIN EBOOKS**START***
    Why is this "Small Print!" statement here? You know: lawyers.
    They tell us you might sue us if there is something wrong with
    your copy of this eBook, even if you got it for free from
    someone other than us, and even if what's wrong is not our
    fault. So, among other things, this "Small Print!" statement
    disclaims most of our liability to you. It also tells you how
    you may distribute copies of this eBook if you want to.

    *BEFORE!* YOU USE OR READ THIS EBOOK
    By using or reading any part of this PROJECT GUTENBERG-tm
    eBook, you indicate that you understand, agree to and accept
    this "Small Print!" statement. If you do not, you can receive
    a refund of the money (if any) you paid for this eBook by
    sending a request within 30 days of receiving it to the person
    you got it from. If you received this eBook on a physical
    medium (such as a disk), you must return it with your request.

    ABOUT PROJECT GUTENBERG-TM EBOOKS
    This PROJECT GUTENBERG-tm eBook, like most PROJECT GUTENBERG-tm eBooks,
    is a "public domain" work distributed by Professor Michael S. Hart
    through the Project Gutenberg Association (the "Project").
    Among other things, this means that no one owns a United States copyright
    on or for this work, so the Project (and you!) can copy and
    distribute it in the United States without permission and
    without paying copyright royalties. Special rules, set forth
    below, apply if you wish to copy and distribute this eBook
    under the "PROJECT GUTENBERG" trademark.

    Please do not use the "PROJECT GUTENBERG" trademark to market
    any commercial products without permission.

    To create these eBooks, the Project expends considerable
    efforts to identify, transcribe and proofread public domain
    works. Despite these efforts, the Project's eBooks and any
    medium they may be on may contain "Defects". Among other
    things, Defects may take the form of incomplete, inaccurate or
    corrupt data, transcription errors, a copyright or other
    intellectual property infringement, a defective or damaged
    disk or other eBook medium, a computer virus, or computer
    codes that damage or cannot be read by your equipment.

    LIMITED WARRANTY; DISCLAIMER OF DAMAGES
    But for the "Right of Replacement or Refund" described below,
    [1] Michael Hart and the Foundation (and any other party you may
    receive this eBook from as a PROJECT GUTENBERG-tm eBook) disclaims
    all liability to you for damages, costs and expenses, including
    legal fees, and [2] YOU HAVE NO REMEDIES FOR NEGLIGENCE OR
    UNDER STRICT LIABILITY, OR FOR BREACH OF WARRANTY OR CONTRACT,
    INCLUDING BUT NOT LIMITED TO INDIRECT, CONSEQUENTIAL, PUNITIVE
    OR INCIDENTAL DAMAGES, EVEN IF YOU GIVE NOTICE OF THE
    POSSIBILITY OF SUCH DAMAGES.

    If you discover a Defect in this eBook within 90 days of
    receiving it, you can receive a refund of the money (if any)
    you paid for it by sending an explanatory note within that
    time to the person you received it from. If you received it
    on a physical medium, you must return it with your note, and
    such person may choose to alternatively give you a replacement
    copy. If you received it electronically, such person may
    choose to alternatively give you a second opportunity to
    receive it electronically.

    THIS EBOOK IS OTHERWISE PROVIDED TO YOU "AS-IS". NO OTHER
    WARRANTIES OF ANY KIND, EXPRESS OR IMPLIED, ARE MADE TO YOU AS
    TO THE EBOOK OR ANY MEDIUM IT MAY BE ON, INCLUDING BUT NOT
    LIMITED TO WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A
    PARTICULAR PURPOSE.

    Some states do not allow disclaimers of implied warranties or
    the exclusion or limitation of consequential damages, so the
    above disclaimers and exclusions may not apply to you, and you
    may have other legal rights.

    INDEMNITY
    You will indemnify and hold Michael Hart, the Foundation,
    and its trustees and agents, and any volunteers associated
    with the production and distribution of Project Gutenberg-tm
    texts harmless, from all liability, cost and expense, including
    legal fees, that arise directly or indirectly from any of the
    following that you do or cause:  [1] distribution of this eBook,
    [2] alteration, modification, or addition to the eBook,
    or [3] any Defect.

    DISTRIBUTION UNDER "PROJECT GUTENBERG-tm"
    You may distribute copies of this eBook electronically, or by
    disk, book or any other medium if you either delete this
    "Small Print!" and all other references to Project Gutenberg,
    or:

    [1]  Only give exact copies of it.  Among other things, this
         requires that you do not remove, alter or modify the
         eBook or this "small print!" statement.  You may however,
         if you wish, distribute this eBook in machine readable
         binary, compressed, mark-up, or proprietary form,
         including any form resulting from conversion by word
         processing or hypertext software, but only so long as
         *EITHER*:

         [*]  The eBook, when displayed, is clearly readable, and
              does *not* contain characters other than those
              intended by the author of the work, although tilde
              (~), asterisk (*) and underline (_) characters may
              be used to convey punctuation intended by the
              author, and additional characters may be used to
              indicate hypertext links; OR

         [*]  The eBook may be readily converted by the reader at
              no expense into plain ASCII, EBCDIC or equivalent
              form by the program that displays the eBook (as is
              the case, for instance, with most word processors);
              OR

         [*]  You provide, or agree to also provide on request at
              no additional cost, fee or expense, a copy of the
              eBook in its original plain ASCII form (or in EBCDIC
              or other equivalent proprietary form).

    [2]  Honor the eBook refund and replacement provisions of this
         "Small Print!" statement.

    [3]  Pay a trademark license fee to the Foundation of 20% of the
         gross profits you derive calculated using the method you
         already use to calculate your applicable taxes.  If you
         don't derive profits, no royalty is due.  Royalties are
         payable to "Project Gutenberg Literary Archive Foundation"
         the 60 days following each date you prepare (or were
         legally required to prepare) your annual (or equivalent
         periodic) tax return.  Please contact us beforehand to
         let us know your plans and to work out the details.

    WHAT IF YOU *WANT* TO SEND MONEY EVEN IF YOU DON'T HAVE TO?
    Project Gutenberg is dedicated to increasing the number of
    public domain and licensed works that can be freely distributed
    in machine readable form.

    The Project gratefully accepts contributions of money, time,
    public domain materials, or royalty free copyright licenses.
    Money should be paid to the:
    "Project Gutenberg Literary Archive Foundation."

    If you are interested in contributing scanning equipment or
    software or other items, please contact Michael Hart at:
    hart@pobox.com

    [Portions of this eBook's header and trailer may be reprinted only
    when distributed free of all fees.  Copyright (C) 2001, 2002 by
    Michael S. Hart.  Project Gutenberg is a TradeMark and may not be
    used in any sales of Project Gutenberg eBooks or other materials be
    they hardware or software or any other related product without
    express permission.]

    *END THE SMALL PRINT! FOR PUBLIC DOMAIN EBOOKS*Ver.02/11/02*END*

    */
}
